(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    156507,       3709]*)
(*NotebookOutlinePosition[    236673,       5703]*)
(*  CellTagsIndexPosition[    214979,       5206]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "MathFEMM 1.20\n\n",
  StyleBox["The Mathematica interface to FEMM 4.2", "Subsubtitle"],
  "\n",
  StyleBox["David Meeker\ndmeeker@ieee.org\n\nJanuary 26, 2006", 
    "Subsubtitle"]
}], "Subtitle"],

Cell[CellGroupData[{

Cell["Installation and Setup", "Section"],

Cell["\<\
The MathFEMM package is automatically installed with FEMM 4.2. If you have \
accepted the default install for FEMM (to c:\\Program Files\\femm42) no \
further initialization is required. If you have installed FEMM to a different \
directory, you will need to perform an additional initialization step so that \
MathFEMM can find the FEMM executable:
1) Start up Mathematica.
2) Load the MathFEMM package from the installation directory with the \
command:
<<c:\\progra~1\\femm42\\mathfemm\\mathfemm.m
3) Run the SetPathToFEMM command to specify the path to the FEMM executable:
SetPathToFEMM[\"c:\\\\progra~1\\\\femm42\\\\bin\\\\femm.exe\"]
where you'd replace the above path withe the one to femm.exe in your \
installation.Be sure to use double backslashes in the path specification

USE:To start an MathFEMM session,first load up the MathFEMM package using the \
command:
<<c:\\progra~1\\femm42\\mathfemm\\mathfemm.m
You may need to change the path to mathfemm.m in the above call if you chose \
to install in a directory other than the default one.Then,use the OpenFEMM[] \
to automatically FEMM process and connect to it. Subsequent MathFEMM commands \
are sent to that instance of FEMM.When you are finished sending commands to \
FEMM,you can close down FEMM with the CloseFEMM[] function.There are a number \
of example notebooks of various MathFEMM analyses in the examples \
subdirectory. To run them,simply open up the notebooks and select \
Kernel|Evaluation|Evaluate Notebook off of the Mathematica main menu. The \
included notebook Usage.nb describes all MathFEMM commands in detail.\
\>", "Text",
  FontFamily->"Courier New"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Common Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("OpenFEMM[] starts an external instance of FEMM and establishes an \
associated MathLink connection."\)], "Print",
  CellTags->"Info3347223940-6631621"],

Cell[BoxData[
    \("CloseFEMM[] shuts down the external instance of FEMM and closes the \
associated MathLink connection."\)], "Print",
  CellTags->"Info3347223940-4294206"],

Cell[BoxData[
    \("NewDocument[doctype] creates a new preprocessor document and opens up \
a new preprocessor window in FEMM. Specify doctype to be 0 for a magnetics \
problem, 1 for an electrostatics problem, 2 for a heat flow problem, or 3 for \
a current flow problem. Alternate form is Create[doctype]"\)], "Print",
  CellTags->"Info3347223940-6810511"],

Cell[BoxData[
    \("OpenDocument[\"filename\"] opens a document specified by \
\"filename\"."\)], "Print",
  CellTags->"Info3347223940-7389295"],

Cell[BoxData[
    \("ShowPointProps[] displays the Point Properties dialog"\)], "Print",
  CellTags->"Info3347223940-2382490"],

Cell[BoxData[
    \("HidePointProps[] hides the Point Properties dialog from view"\)], \
"Print",
  CellTags->"Info3347223940-6023529"],

Cell[BoxData[
    \("ShowConsole[] displays the FEMM Lua console"\)], "Print",
  CellTags->"Info3347223940-6503571"],

Cell[BoxData[
    \("HideConsole[] hides the FEMM Lua console from view"\)], "Print",
  CellTags->"Info3347223940-5379615"],

Cell[BoxData[
    \("MessageBox[\"string\"] displays a pop-up messagebox with the message \
\"string\""\)], "Print",
  CellTags->"Info3347223940-1834069"],

Cell[BoxData[
    \("Prompt[\"string\"] displays a pop-up dialog with the message \
\"string\" displayed on it with an edit box.  The return value of the \
funciton is the contents of the edit box."\)], "Print",
  CellTags->"Info3347223940-7924268"],

Cell[BoxData[
    \("MLPut[\"string\"] sends \"string\" to FEMM's Lua interpreter via \
MathLink"\)], "Print",
  CellTags->"Info3347223940-7939632"],

Cell[BoxData[
    \("MLGet[] receives data from FEMM via MathLink.  The data is always in \
the form of a list, but the number of elements in the list is variable.  The \
items in the list could be either numbers or strings"\)], "Print",
  CellTags->"Info3347223940-6833855"],

Cell[BoxData[
    \("AWG[awg] returns the wire diameter in mm for the specified AWG \
gauge"\)], "Print",
  CellTags->"Info3347223940-1189387"],

Cell["MathFEMM`IEC", "Print",
  CellTags->"Info3347223940-1293541"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(IEC[MathFEMM`Private`iec_] := 
                    7.959159641581004`\ MathFEMM`Private`exp\ \
\((\(-0.11519673572274754`\)\ MathFEMM`Private`iec)\)\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "IEC"],
      Editable->False]], "Print",
  CellTags->"Info3347223940-1293541"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrostatics Input Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EIAddBoundProp[\"boundpropname\", Vs,qs,c0,c1,BdryFormat] adds a new \
boundary property with name \"boundpropname\"\n For a \"Fixed Temperature\" \
type boundary condition, set the Vs parameter to the desired voltage and all \
other parameters to zero.\n To obtain a \"Mixed\" type boundary condition, \
set C1 and C0 as required and BdryFormat to 1. Set all other parameters to \
zero.\n To obtain a prescribes surface charge density, set qs to the desired \
charge density in C/m2 and set BdryFormat to 2.\n For a \"Periodic\" boundary \
condition, set BdryFormat to 3 and set all other parameters to zero.\n For an \
\"Anti-Perodic\" boundary condition, set BdryFormat to 4 set all other \
parameters to zero."\)], "Print",
  CellTags->"Info3347223940-8692552"],

Cell[BoxData[
    \("EIAddConductorProp[\"conductorname\",Vc,qc,conductortype] adds a new \
conductor property with name \"conductorname\" with either a prescribed \
voltage or a prescribed total charge. Set the unused property to zero. The \
conductortype parameter is 0 for prescribed charge and 1 for prescribed \
voltage."\)], "Print",
  CellTags->"Info3347223940-9972450"],

Cell[BoxData[
    \("EIAddMaterial[\"materialname\",ex,ey,qv] adds a new material with \
called \"materialname\" with the material properties:\n ex Relative \
permittivity in the x- or r-direction.\n ey Relative permittivity in the y- \
or z-direction.\n qv Volume charge density in units of C/m^3"\)], "Print",
  CellTags->"Info3347223940-4605738"],

Cell[BoxData[
    \("EIAddPointProp[\"pointpropname\",Vp,qp] adds a new point property of \
name \"pointpropname\" with either a specified potential Vp a point charge \
density qp in units of C/m."\)], "Print",
  CellTags->"Info3347223940-4732625"],

Cell[BoxData[
    \("EIModifyBoundProp[\"BdryName\",propnum,value] allows for modification \
of a boundary property. The BC to be modified is specified by \"BdryName\". \
The next parameter is the number of the property to be set. The last number \
is the value to be applied to the specified property. The various properties \
that can be modified are listed below:\n 0 - \"BdryName\" - Name of boundary \
property\n 1 - Vs - Fixed Voltage\n 2 - qs - Prescribed charge density\n 3 - \
c0 - Mixed BC parameter\n 4 - c1 - Mixed BC parameter\n 5 - BdryFormat -  \
Type of boundary condition (0 = Prescribed V; 1 = Mixed; 2 = Surface charge \
density; 3 = Periodic; 4 = Antiperiodic)"\)], "Print",
  CellTags->"Info3347223940-4167237"],

Cell[BoxData[
    \("EIModifyConductorProp[\"ConductorName\",propnum,value] allows for \
modification of a conductor property. The conductor property to be modified \
is specified by \"ConductorName\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\n 0 - \"ConductorName\" - Name of the conductor property\n 1 - Vc - \
Conductor voltage\n 2 - qc - Total conductor charge\n 3 - ConductorType - 0 = \
Prescribed charge, 1 = Prescribed voltage"\)], "Print",
  CellTags->"Info3347223940-9087758"],

Cell[BoxData[
    \("EIModifyMaterial[\"BlockName\",propnum,value] allows for modification \
of a material's properties without redefining the entire material (e.g. so \
that current can be modified from run to run). The material to be modified is \
specified by \"BlockName\". The next parameter is the number of the property \
to be set. The last number is the value to be applied to the specified \
property. The various properties that can be modified are listed below:\n 0 - \
\"BlockName\" - Name of the material 1 - ex - x (or r) direction relative \
permittivity 2 - ey - y (or z) direction relative permittivity 3 - qs - \
Volume charge"\)], "Print",
  CellTags->"Info3347223940-5926772"],

Cell[BoxData[
    \("EIModifyPointProp[\"PointName\",propnum,value] allows for modification \
of a point property. The point property to be modified is specified by \
\"PointName\". The next parameter is the number of the property to be set. \
The last number is the value to be applied to the specified property. The \
various properties that can be modified are listed below:\n 0 - PointName - \
Name of the point property\n 1 - Vp - Prescribed nodal voltage\n 2 - qp - \
Point charge density in C/m"\)], "Print",
  CellTags->"Info3347223940-8501482"],

Cell[BoxData[
    \("EIDeleteBoundProp[\"boundpropname\"] deletes the boundary property \
named \"boundpropname\"."\)], "Print",
  CellTags->"Info3347223940-7144037"],

Cell[BoxData[
    \("EIDeleteConductor[\"conductorname\"] deletes the conductor property \
named \"conductorname\"."\)], "Print",
  CellTags->"Info3347223940-2011507"],

Cell[BoxData[
    \("EIDeleteMaterial[\"materialname\"] deletes the material property named \
\"materialname\"."\)], "Print",
  CellTags->"Info3347223940-6339513"],

Cell[BoxData[
    \("EIDeletePointProp[\"pointpropname\"] deletes the point property named \
\"pointpropname\"."\)], "Print",
  CellTags->"Info3347223940-5174597"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the electrostatics \
input geometry from the point nearst to {x1,y1} to the point nearest to \
{x2,y2}.  The arc spans a number of degrees specified by angle. Since FEMM \
approximates arcs by many line segments, the parameter maxseg specifies the \
maximum number of degrees that is allowed to be spanned by any one segment. \
Equivalent forms are:\n EIAddArc[{x1,y1},{x2,y2},angle,maxseg]\n \
EIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223940-1062849"],

Cell[BoxData[
    \("EIAddBlockLabel[x,y] adds a block label at the point {x,y}.  An \
equivalent form is:\n EIAddBlockLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223940-3542961"],

Cell[BoxData[
    \("EIAddNode[x,y] adds a new node at {x,y}. An equivalent form is:\n \
EIAddNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223940-1600426"],

Cell[BoxData[
    \("EIAddSegment[x1,y1,x2,y2] add a new line segment from node closest to \
{x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\n \
EIAddSegment[{x1,y1},{x2,y2}]\n EIAddSegment[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223940-4337716"],

Cell[BoxData[
    \("EIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the electrostatics \
input geometry by drawing points at {x1,y1} and {x2,y2} and then connecting \
them with an arc segment. The arc spans a number of degrees specified by \
angle. Since FEMM approximates arcs by many line segments, the parameter \
maxseg specifies the maximum number of degrees that is allowed to be spanned \
by any one segment. Equivalent forms are:\n \
EIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\n \
EIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223941-1813366"],

Cell[BoxData[
    \("EIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} and then \
adds a segment connecting these two points.  Equivalent forms are:\n \
EIDrawLine[{x1,y1},{x2,y2}]\n EIDrawLine[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223941-1118594"],

Cell[BoxData[
    \("EIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points at every \
listed point and then draws a closed figure that connects the points"\)], \
"Print",
  CellTags->"Info3347223941-5737972"],

Cell[BoxData[
    \("EIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment line by \
adding each of the points in the list and then adding segments that join the \
listed points."\)], "Print",
  CellTags->"Info3347223941-7410441"],

Cell[BoxData[
    \("EIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, {x1,y2}, {x2,y2} \
and  {x2,y1} and joins them with new segments.  Equivalent forms are:\n \
EIDrawRectangle[{x1,y1},{x2,y2}]\n EIDrawRectangle[{{x1,y1},{x2,y2}}]"\)], \
"Print",
  CellTags->"Info3347223941-8640170"],

Cell[BoxData[
    \("EICreateRadius[x,y,z] turns a corner located at {x,y} into a curve of \
radius r.\n An equivalent form is: EICreateRadius[{x,y},z]"\)], "Print",
  CellTags->"Info3347223941-1951187"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EISelectArcSegment[x,y] selects the arc segment closest to {x,y}.  An \
equivalent form is:\n EISelectArcSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-8197922"],

Cell[BoxData[
    \("EISelectGroup[n] selects the nth group of nodes, segments, arc \
segments and block labels. This function will clear all previously selected \
elements and leave the edit mode in 4 (group)"\)], "Print",
  CellTags->"Info3347223941-2611265"],

Cell[BoxData[
    \("EISelectLabel[x,y] selects the block label closest to {x,y}.  An \
equivalent form is:\n EISelectLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-9442840"],

Cell[BoxData[
    \("EISelectNode[x,y] selects the node closest to {x,y}.  An equivalent \
form is:\n EISelectNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-7245219"],

Cell[BoxData[
    \("EISelectSegment[x,y] selects the segment closest to {x,y}.  An \
equivalent form is:\n EISelectSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-5798128"],

Cell[BoxData[
    \("EISetArcSegmentProp[maxsegdeg, \"propname\", hide, \
groupno,\"inconductor\"] sets the properties associated with the selected arc \
segments\n maxsegdeg specifies that the arcs must be meshed with elements \
that span at most maxsegdeg degrees per element\n \"propname\" specifies the \
boundary property to be associated with the selected arcs\n hide: 0 = not \
hidden in post-processor, 1 == hidden in post processor\n groupno is an \
integer specifying the group number of which the selected arcs are to be \
members.\n \"inconductor\" specifies the name of the conductor property with \
which the selected arcs are to be associated. If the arcs is not to be part \
of a conductor, this parameter can be specified as \"<None>\"."\)], "Print",
  CellTags->"Info3347223941-1459018"],

Cell[BoxData[
    \("EISetBlockProp[\"blockname\",automesh,meshsize,groupno] sets the \
selected block labels to have the properties:\n Block property \"blockname\".\
\n automesh: 0 = mesher defers to mesh size constraint defined in meshsize, 1 \
= mesher automatically chooses the mesh density.\n meshsize: size constraint \
on the mesh in the block marked by this label\n. groupno: make selected \
members of specified group number"\)], "Print",
  CellTags->"Info3347223941-1589458"],

Cell[BoxData[
    \("EISetNodeProp[\"propname\",groupno,\"inconductor\"] sets the selected \
nodes to have the nodal property \"propname\" and group number groupno. The \
\"inconductor\" string specifies which conductor the node belongs to. If the \
node doesn\[CloseCurlyQuote]t belong to a named conductor, this parameter can \
be set to \"<None>\"."\)], "Print",
  CellTags->"Info3347223941-8534708"],

Cell[BoxData[
    \("EISetSegmentProp[\"propname\",elementsize,automesh,hide,groupno,\"\
inconductor\"] sets the select segments to have:\n Boundary property \
\"propname\"\n Local element size along segment no greater than elementsize\n \
automesh: 0 = mesher defers to the element constraint defined by elementsize, \
1 = mesher automatically chooses mesh size along the selected segments\n \
hide: 0 = not hidden in post-processor, 1 == hidden in post processor\n A \
member of group number groupno\n A member of the conductor specified by the \
string \"inconductor\". If the segment is not part of a conductor, this \
parameter can be specified as \"<None>\"."\)], "Print",
  CellTags->"Info3347223941-7553760"],

Cell[BoxData[
    \("EIDeleteSelected[] deletes all selected objects."\)], "Print",
  CellTags->"Info3347223941-9188284"],

Cell[BoxData[
    \("EIDeleteSelectedArcSegments[] deletes all selected arc segments."\)], \
"Print",
  CellTags->"Info3347223941-7542695"],

Cell[BoxData[
    \("EIDeleteSelectedLabels[] deletes all selected block labels."\)], \
"Print",
  CellTags->"Info3347223941-2715154"],

Cell[BoxData[
    \("EIDeleteSelectedNodes[] deletes all selected nodes."\)], "Print",
  CellTags->"Info3347223941-2795720"],

Cell[BoxData[
    \("EIDeleteSelectedSegments[] deletes all selected segments."\)], "Print",\

  CellTags->"Info3347223941-9823357"],

Cell[BoxData[
    \("EIClearSelected[] clear all selected nodes, blocks, segments and arc \
segments."\)], "Print",
  CellTags->"Info3347223941-8020983"],

Cell[BoxData[
    \("EIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric external region \
to be used in conjuction with the Kelvin Transformation method of modeling \
unbounded problems.  The Zo parameter is the z-location of the origin of the \
outer region, the Ro parameter is the radius of the outer region, and the Ri \
parameter is the radius of the inner region (i.e. the region of interest). In \
the exterior region, the permeability varies as a function of distance from \
the origin of the external region.  These parameters are necessary to define \
the permeability variation in the external region."\)], "Print",
  CellTags->"Info3347223941-4999920"],

Cell[BoxData[
    \("EIAttachOuterSpace[] marks all selected block labels as members of the \
external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223941-6637905"],

Cell[BoxData[
    \("EIDetachOuterSpace[] undefines all selected block labels as members of \
the external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223941-9601905"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move, Copy, Scale", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EICopyRotate[bx,by,angle,copies,(editaction)]\n bx, by base point for \
rotation\n angle angle by which the selected objects are incrementally \
shifted to make each copy. This angle is measured in degrees.\n copies number \
of copies to be produced from the selected objects \n editaction 0-nodes, \
1-segments, 2-block labels, 3-arcs, 4-group\n An equivalent form is:\n \
EICopyRotate[{bx,by},angle,copies,(editaction)]"\)], "Print",
  CellTags->"Info3347223941-1464798"],

Cell[BoxData[
    \("EICopyTranslate[dx,dy,copies,(editaction)]\n {dx,dy} represents the \
distance by which the selected objects are to be incrementally shifted.\n \
copies specifies the number of copoies to be produced from the selected \
objects\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\n \
An equivalent form is:\n EICopyTranslate[{dx,dy},copies,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223941-1770110"],

Cell[BoxData[
    \("EIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected objects about \
a line passing through the points (x1,y1) and (x2,y2). Valid editaction \
entries are 0 for nodes, 1 for lines (segments), 2 for block labels, 3 for \
arc segments, and 4 for groups. Equivalent forms are:\n \
EIMirror[{x1,y1},{x2,y2},(editaction)]\n \
EIMirror[{{x1,y1},{x2,y2}},(editaction)]"\)], "Print",
  CellTags->"Info3347223941-2471642"],

Cell[BoxData[
    \("EIMoveRotate[bx,by,shiftangle,(editaction)]\n bx, by \[Dash] base \
point for rotation\n shiftangle \[Dash] angle in degrees by which the \
selected objects are rotated.\n editaction - 0  \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent form is:\n EIMoveRotate[{bx,by},shiftangle,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223941-7586356"],

Cell[BoxData[
    \("EIMoveTranslate[dx,dy,(editaction)]\n dx,dy \[Dash] distance by which \
the selected objects are shifted.\n editaction - 0 \[Dash]nodes, 1 \[Dash] \
lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n \
An equivalent form is:\n EIMoveTranslate[{dx,dy},(editaction)]"\)], "Print",
  CellTags->"Info3347223941-4155620"],

Cell[BoxData[
    \("EIScale[bx,by,scalefactor,(editaction)]\n bx, by \[Dash] base point \
for scaling\n scalefactor \[Dash] a multiplier that determines how much the \
selected objects are scaled\n editaction 0 \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent for is: EIScale[{bx,by},scalefactor,(editaction)]"\)], "Print",
  CellTags->"Info3347223941-3197855"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EISetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the \"type\" parameter \
is set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223941-8920274"],

Cell[BoxData[
    \("EIShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223941-2580618"],

Cell[BoxData[
    \("EIHideGrid[] hides the electrostatics input grid points"\)], "Print",
  CellTags->"Info3347223941-5009207"],

Cell[BoxData[
    \("EIShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223941-1486463"],

Cell[BoxData[
    \("EIPurgeMesh[] clears the mesh out of both the screen and memory."\)], \
"Print",
  CellTags->"Info3347223941-2487122"],

Cell[BoxData[
    \("EIShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223941-6450972"],

Cell[BoxData[
    \("EIHideNames[] stops the names of the materials associated with each \
block label from being displayed"\)], "Print",
  CellTags->"Info3347223941-4162216"],

Cell[BoxData[
    \("EISnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223941-6354640"],

Cell[BoxData[
    \("EISnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223941-5746827"],

Cell[BoxData[
    \("EIZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n EIZoom[{x1,y1},{x2,y2}]\n \
EIZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223941-2691935"],

Cell[BoxData[
    \("EIZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223941-7877067"],

Cell[BoxData[
    \("EIZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223941-7749989"],

Cell[BoxData[
    \("EIZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223941-3231106"],

Cell[BoxData[
    \("EIGetView[] grabs the current electrostatics input view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223941-3377092"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EIAnalyze[(flag)] runs the electrostatics solver. The flag parameter \
controls whether the solver window is visible or minimized. For a visible \
window, either specify no value for flag or specify 0. For a minimized \
window, flag should be set to 1. An equivalent form is:\n \
EIAnalyse[(flag)]"\)], "Print",
  CellTags->"Info3347223941-4876077"],

Cell[BoxData[
    \("EIClose[] closes the preprocessor window and destroys the current \
document."\)], "Print",
  CellTags->"Info3347223941-3439479"],

Cell[BoxData[
    \("EICreateMesh[] runs triangle to create a mesh. Note that this is not a \
necessary precursor of performing an analysis, as EIAnalyze[] will make sure \
the mesh is up to date before running an analysis."\)], "Print",
  CellTags->"Info3347223941-7653090"],

Cell[BoxData[
    \("EILoadSolution[] loads and displays the solution corresponding to the \
current geometry."\)], "Print",
  CellTags->"Info3347223941-7874582"],

Cell[BoxData[
    \("EIProbDef[units,type,precision,depth,minangle] changes the problem \
definition. The units parameter specifies the units used for measuring length \
in the problem domain. Valid \"units\" entries are \"inches\", \
\"millimeters\", \"centimeters\", \"mils\", \"meters\", and \"micrometers\". \
Set problemtype to \"planar\" for a 2-D planar problem, or to \"axi\" for an \
axisymmetric problem. The precision parameter dictates the precision required \
by the solver. For example, specifying 1.E-8 requires the RMS of the residual \
to be less than 10^(-8). The depth parameter, represents the depth of the \
problem in the into-the-page direction for 2-D planar problems. The minangle \
parameter is a constraint for the mesh generator. It specifies the smallest \
permissible angle in triangles that compose the finite element mesh. A good \
value to choose is 30 degrees, but smaller values may be needed for \"tough\" \
geometries that contain small angles."\)], "Print",
  CellTags->"Info3347223941-5235115"],

Cell[BoxData[
    \("EIReadDXF[\"filename\"] reads in geometry information a DXF file \
specified by \"filename\""\)], "Print",
  CellTags->"Info3347223941-7704576"],

Cell[BoxData[
    \("EIRefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223941-4043808"],

Cell[BoxData[
    \("EISaveAs[\"filename\"] saves the file with name \"filename\". Note if \
you use a path you must use two backslashes e.g. \
\"c:\\\\temp\\\\myfemmfile.fem\""\)], "Print",
  CellTags->"Info3347223941-3418109"],

Cell[BoxData[
    \("EISaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the EISaveAs command."\)], "Print",
  CellTags->"Info3347223941-6580237"],

Cell[BoxData[
    \("EISaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the EISaveAs command."\)], \
"Print",
  CellTags->"Info3347223941-6852624"],

Cell[BoxData[
    \("EISetEditMode[\"editmode\"] sets the current editmode to:\n \"nodes\" \
\[Dash] nodes\n \"segments\" - line segments\n \"arcsegments\" - arc segments\
\n \"blocks\" - block labels\n \"group\" - selected group\n This command will \
affect all subsequent uses of the other editing commands, if they are used \
without the editaction parameter."\)], "Print",
  CellTags->"Info3347223941-1422078"],

Cell[BoxData[
    \("EISetFocus[\"documentname\"] switches the electrostatics input file \
upon which scripting commands are to act. If more than one electrostatics \
input file is being edited at a time, this command can be used to switch \
between files so that the mutiple files can be operated upon programmatically \
. \"documentname\" should contain the name of the desired document as it \
appears on the window\[CloseCurlyQuote]s title bar."\)], "Print",
  CellTags->"Info3347223941-2029304"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heat Flow Input Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HIAddBoundProp[\"boundpropname\", BdryFormat, Tset, qs, Tinf, h, beta] \
adds a new boundary property with name \"boundpropname\"\n For a \"Fixed \
Temperature\" type boundary condition, set the Tset parameter to the desired \
temperature and all other parameters to zero.\n To obtain a \"Heat Flux\" \
type boundary condition, set qs to be the heat flux density and BdryFormat to \
1. Set all other parameters to zero.\n To obtain a convection boundary \
condition, set h to the desired heat transfer coefficient and Tinf to the \
desired external temperature and set BdryFormat to 2.\n For a Radiation \
boundary condition, set beta equal to the desired emmissivity and Tinf to the \
 desired external temperature and set BdryFormat to 3.\n For a \"Periodic\" \
boundary condition, set BdryFormat to 4 and set all other parameters to zero.\
\n For an \"Anti-Perodic\" boundary condition, set BdryFormat to 5 set all \
other parameters to zero."\)], "Print",
  CellTags->"Info3347223941-8989917"],

Cell[BoxData[
    \("HIAddConductorProp[\"conductorname\",Tc,qc,conductortype] adds a new \
conductor property with name \"conductorname\" with either a prescribed \
temperature or a prescribed total heat flux. Set the unused property to zero. \
The conductortype parameter is 0 for prescribed charge and 1 for prescribed \
temperature."\)], "Print",
  CellTags->"Info3347223941-3552733"],

Cell[BoxData[
    \("HIAddMaterial[\"materialname\",Kx,Ky,qv] adds a new material with \
called \"materialname\" with the material properties:\n Kx Thermal \
conductivity in the x- or r-direction.\n Ky Thermal conductivity in the y- or \
z-direction.\n qv Volume heat generation density in units of J/m^3"\)], \
"Print",
  CellTags->"Info3347223941-6176457"],

Cell[BoxData[
    \("HIAddPointProp[\"pointpropname\",Tp,qp] adds a new point property of \
name \"pointpropname\" with either a specified temperature Tp or point heat \
generation qp in units of J/m."\)], "Print",
  CellTags->"Info3347223941-8109493"],

Cell[BoxData[
    \("HIModifyBoundProp[\"BdryName\",propnum,value] allows for modification \
of a boundary property. The BC to be modified is specified by \"BdryName\". \
The next parameter is the number of the property to be set. The last number \
is the value to be applied to the specified property. The various properties \
that can be modified are listed below:\n 0 - \"BdryName\" - Name of boundary \
property\n 1 - BdryFormat -  Type of boundary condition (0 = Prescribed \
Temperature; 1 = Heat Flux; 2 = Convection; 3 = Radiation; 4 = Periodic; 5 = \
Antiperiodic) 2 - Tset - Fixed Temperature\n 3 - qs - Prescribed heat flux \
density\n 4 - Tinf - External temperature\n 5 - h - heat transfer coefficient\
\n 6 - beta - emmissivity"\)], "Print",
  CellTags->"Info3347223941-6089851"],

Cell[BoxData[
    \("HIModifyConductorProp[\"ConductorName\",propnum,value] allows for \
modification of a conductor property. The conductor property to be modified \
is specified by \"ConductorName\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\n 0 - \"ConductorName\" - Name of the conductor property\n 1 - Tc - \
Conductor Temperature\n 2 - qc - Total conductor heat flux\n 3 - \
ConductorType - 0 = Prescribed heat flow, 1 = Prescribed temperature"\)], \
"Print",
  CellTags->"Info3347223941-7134049"],

Cell[BoxData[
    \("HIModifyMaterial[\"BlockName\",propnum,value] allows for modification \
of a material's properties without redefining the entire material (e.g. so \
that current can be modified from run to run). The material to be modified is \
specified by \"BlockName\". The next parameter is the number of the property \
to be set. The last number is the value to be applied to the specified \
property. The various properties that can be modified are listed below:\n 0 - \
\"BlockName\" - Name of the material 1 - Kx - x (or r) direction thermal \
conductivity 2 - Ky - y (or z) direction thermal conductivity 3 - qv - Volume \
heat generation"\)], "Print",
  CellTags->"Info3347223941-7244468"],

Cell[BoxData[
    \("HIModifyPointProp[\"PointName\",propnum,value] allows for modification \
of a point property. The point property to be modified is specified by \
\"PointName\". The next parameter is the number of the property to be set. \
The last number is the value to be applied to the specified property. The \
various properties that can be modified are listed below:\n 0 - PointName - \
Name of the point property\n 1 - Tp - Prescribed nodal temperature\n 2 - qp - \
Point heat generation in C/m"\)], "Print",
  CellTags->"Info3347223941-4415755"],

Cell[BoxData[
    \("HIDeleteBoundProp[\"boundpropname\"] deletes the boundary property \
named \"boundpropname\"."\)], "Print",
  CellTags->"Info3347223941-9094170"],

Cell[BoxData[
    \("HIDeleteConductor[\"conductorname\"] deletes the conductor property \
named \"conductorname\"."\)], "Print",
  CellTags->"Info3347223941-3611725"],

Cell[BoxData[
    \("HIDeleteMaterial[\"materialname\"] deletes the material property named \
\"materialname\"."\)], "Print",
  CellTags->"Info3347223941-9967462"],

Cell[BoxData[
    \("HIDeletePointProp[\"pointpropname\"] deletes the point property named \
\"pointpropname\"."\)], "Print",
  CellTags->"Info3347223941-4309295"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the electrostatics \
input geometry from the point nearst to {x1,y1} to the point nearest to \
{x2,y2}.  The arc spans a number of degrees specified by angle. Since FEMM \
approximates arcs by many line segments, the parameter maxseg specifies the \
maximum number of degrees that is allowed to be spanned by any one segment. \
Equivalent forms are:\n HIAddArc[{x1,y1},{x2,y2},angle,maxseg]\n \
HIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223941-8260624"],

Cell[BoxData[
    \("HIAddBlockLabel[x,y] adds a block label at the point {x,y}.  An \
equivalent form is:\n HIAddBlockLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-8492284"],

Cell[BoxData[
    \("HIAddNode[x,y] adds a new node at {x,y}. An equivalent form is:\n \
HIAddNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-8438704"],

Cell[BoxData[
    \("HIAddSegment[x1,y1,x2,y2] add a new line segment from node closest to \
{x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\n \
HIAddSegment[{x1,y1},{x2,y2}]\n HIAddSegment[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223941-3285558"],

Cell[BoxData[
    \("HIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the heat flow input \
geometry by drawing points at {x1,y1} and {x2,y2} and then connecting them \
with an arc segment. The arc spans a number of degrees specified by angle. \
Since FEMM approximates arcs by many line segments, the parameter maxseg \
specifies the maximum number of degrees that is allowed to be spanned by any \
one segment. Equivalent forms are:\n HIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\n\
 HIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223941-1354509"],

Cell[BoxData[
    \("HIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} and then \
adds a segment connecting these two points.  Equivalent forms are:\n \
HIDrawLine[{x1,y1},{x2,y2}]\n HIDrawLine[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223941-1355904"],

Cell[BoxData[
    \("HIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points at every \
listed point and then draws a closed figure that connects the points"\)], \
"Print",
  CellTags->"Info3347223941-8370622"],

Cell[BoxData[
    \("HIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment line by \
adding each of the points in the list and then adding segments that join the \
listed points."\)], "Print",
  CellTags->"Info3347223941-2291614"],

Cell[BoxData[
    \("HIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, {x1,y2}, {x2,y2} \
and  {x2,y1} and joins them with new segments.  Equivalent forms are:\n \
HIDrawRectangle[{x1,y1},{x2,y2}]\n HIDrawRectangle[{{x1,y1},{x2,y2}}]"\)], \
"Print",
  CellTags->"Info3347223941-7771765"],

Cell[BoxData[
    \("EICreateRadius[x,y,z] turns a corner located at {x,y} into a curve of \
radius r.\n An equivalent form is: EICreateRadius[{x,y},z]"\)], "Print",
  CellTags->"Info3347223941-7568170"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HISelectArcSegment[x,y] selects the arc segment closest to {x,y}.  An \
equivalent form is:\n HISelectArcSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-5343679"],

Cell[BoxData[
    \("HISelectGroup[n] selects the nth group of nodes, segments, arc \
segments and block labels. This function will clear all previously selected \
elements and leave the edit mode in 4 (group)"\)], "Print",
  CellTags->"Info3347223941-5864838"],

Cell[BoxData[
    \("HISelectLabel[x,y] selects the block label closest to {x,y}.  An \
equivalent form is:\n HISelectLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-7809650"],

Cell[BoxData[
    \("HISelectNode[x,y] selects the node closest to {x,y}.  An equivalent \
form is:\n HISelectNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-2458221"],

Cell[BoxData[
    \("HISelectSegment[x,y] selects the segment closest to {x,y}.  An \
equivalent form is:\n HISelectSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-1974298"],

Cell[BoxData[
    \("HISetArcSegmentProp[maxsegdeg, \"propname\", hide, \
groupno,\"inconductor\"] sets the properties associated with the selected arc \
segments\n maxsegdeg specifies that the arcs must be meshed with elements \
that span at most maxsegdeg degrees per element\n \"propname\" specifies the \
boundary property to be associated with the selected arcs\n hide: 0 = not \
hidden in post-processor, 1 == hidden in post processor\n groupno is an \
integer specifying the group number of which the selected arcs are to be \
members.\n \"inconductor\" specifies the name of the conductor property with \
which the selected arcs are to be associated. If the arcs is not to be part \
of a conductor, this parameter can be specified as \"<None>\"."\)], "Print",
  CellTags->"Info3347223941-7595909"],

Cell[BoxData[
    \("HISetBlockProp[\"blockname\",automesh,meshsize,groupno] sets the \
selected block labels to have the properties:\n Block property \"blockname\".\
\n automesh: 0 = mesher defers to mesh size constraint defined in meshsize, 1 \
= mesher automatically chooses the mesh density.\n meshsize: size constraint \
on the mesh in the block marked by this label\n. groupno: make selected \
members of specified group number"\)], "Print",
  CellTags->"Info3347223941-2077596"],

Cell[BoxData[
    \("HISetNodeProp[\"propname\",groupno,\"inconductor\"] sets the selected \
nodes to have the nodal property \"propname\" and group number groupno. The \
\"inconductor\" string specifies which conductor the node belongs to. If the \
node doesn\[CloseCurlyQuote]t belong to a named conductor, this parameter can \
be set to \"<None>\"."\)], "Print",
  CellTags->"Info3347223941-6833115"],

Cell[BoxData[
    \("HISetSegmentProp[\"propname\",elementsize,automesh,hide,groupno,\"\
inconductor\"] sets the select segments to have:\n Boundary property \
\"propname\"\n Local element size along segment no greater than elementsize\n \
automesh: 0 = mesher defers to the element constraint defined by elementsize, \
1 = mesher automatically chooses mesh size along the selected segments\n \
hide: 0 = not hidden in post-processor, 1 == hidden in post processor\n A \
member of group number groupno\n A member of the conductor specified by the \
string \"inconductor\". If the segment is not part of a conductor, this \
parameter can be specified as \"<None>\"."\)], "Print",
  CellTags->"Info3347223941-8415350"],

Cell[BoxData[
    \("HIDeleteSelected[] deletes all selected objects."\)], "Print",
  CellTags->"Info3347223941-7920837"],

Cell[BoxData[
    \("HIDeleteSelectedArcSegments[] deletes all selected arc segments."\)], \
"Print",
  CellTags->"Info3347223941-5070483"],

Cell[BoxData[
    \("HIDeleteSelectedLabels[] deletes all selected block labels."\)], \
"Print",
  CellTags->"Info3347223941-1032206"],

Cell[BoxData[
    \("HIDeleteSelectedNodes[] deletes all selected nodes."\)], "Print",
  CellTags->"Info3347223941-1376349"],

Cell[BoxData[
    \("HIDeleteSelectedSegments[] deletes all selected segments."\)], "Print",\

  CellTags->"Info3347223941-7407861"],

Cell[BoxData[
    \("HIClearSelected[] clear all selected nodes, blocks, segments and arc \
segments."\)], "Print",
  CellTags->"Info3347223941-2948475"],

Cell[BoxData[
    \("HIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric external region \
to be used in conjuction with the Kelvin Transformation method of modeling \
unbounded problems.  The Zo parameter is the z-location of the origin of the \
outer region, the Ro parameter is the radius of the outer region, and the Ri \
parameter is the radius of the inner region (i.e. the region of interest). In \
the exterior region, the permeability varies as a function of distance from \
the origin of the external region.  These parameters are necessary to define \
the permeability variation in the external region."\)], "Print",
  CellTags->"Info3347223941-8742318"],

Cell[BoxData[
    \("HIAttachOuterSpace[] marks all selected block labels as members of the \
external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223941-9656730"],

Cell[BoxData[
    \("HIDetachOuterSpace[] undefines all selected block labels as members of \
the external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223941-1145073"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move, Copy, Scale", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HICopyRotate[bx,by,angle,copies,(editaction)]\n bx, by base point for \
rotation\n angle angle by which the selected objects are incrementally \
shifted to make each copy. This angle is measured in degrees.\n copies number \
of copies to be produced from the selected objects \n editaction 0-nodes, \
1-segments, 2-block labels, 3-arcs, 4-group\n An equivalent form is:\n \
HICopyRotate[{bx,by},angle,copies,(editaction)]"\)], "Print",
  CellTags->"Info3347223941-4193583"],

Cell[BoxData[
    \("HICopyTranslate[dx,dy,copies,(editaction)]\n {dx,dy} represents the \
distance by which the selected objects are to be incrementally shifted.\n \
copies specifies the number of copoies to be produced from the selected \
objects\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\n \
An equivalent form is:\n HICopyTranslate[{dx,dy},copies,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223941-6993551"],

Cell[BoxData[
    \("HIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected objects about \
a line passing through the points (x1,y1) and (x2,y2). Valid editaction \
entries are 0 for nodes, 1 for lines (segments), 2 for block labels, 3 for \
arc segments, and 4 for groups. Equivalent forms are:\n \
HIMirror[{x1,y1},{x2,y2},(editaction)]\n \
HIMirror[{{x1,y1},{x2,y2}},(editaction)]"\)], "Print",
  CellTags->"Info3347223941-6453383"],

Cell[BoxData[
    \("HIMoveRotate[bx,by,shiftangle,(editaction)]\n bx, by \[Dash] base \
point for rotation\n shiftangle \[Dash] angle in degrees by which the \
selected objects are rotated.\n editaction - 0  \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent form is:\n HIMoveRotate[{bx,by},shiftangle,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223941-7559587"],

Cell[BoxData[
    \("HIMoveTranslate[dx,dy,(editaction)]\n dx,dy \[Dash] distance by which \
the selected objects are shifted.\n editaction - 0 \[Dash]nodes, 1 \[Dash] \
lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n \
An equivalent form is:\n HIMoveTranslate[{dx,dy},(editaction)]"\)], "Print",
  CellTags->"Info3347223941-5358822"],

Cell[BoxData[
    \("HIScale[bx,by,scalefactor,(editaction)]\n bx, by \[Dash] base point \
for scaling\n scalefactor \[Dash] a multiplier that determines how much the \
selected objects are scaled\n editaction 0 \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent for is: HIScale[{bx,by},scalefactor,(editaction)]"\)], "Print",
  CellTags->"Info3347223941-6682568"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HISetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the \"type\" parameter \
is set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223941-3512651"],

Cell[BoxData[
    \("HIShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223941-8850662"],

Cell[BoxData[
    \("HIHideGrid[] hides the heat flow input grid points"\)], "Print",
  CellTags->"Info3347223941-7730051"],

Cell[BoxData[
    \("HIShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223941-2942451"],

Cell[BoxData[
    \("HIPurgeMesh[] clears the mesh out of both the screen and memory."\)], \
"Print",
  CellTags->"Info3347223941-3089129"],

Cell[BoxData[
    \("HIShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223941-3186031"],

Cell[BoxData[
    \("HIHideNames[] stops the names of the materials associated with each \
block label from being displayed"\)], "Print",
  CellTags->"Info3347223941-4802215"],

Cell[BoxData[
    \("HISnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223941-8163804"],

Cell[BoxData[
    \("HISnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223941-6931229"],

Cell[BoxData[
    \("HIZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n HIZoom[{x1,y1},{x2,y2}]\n \
HIZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223941-9964984"],

Cell[BoxData[
    \("HIZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223941-4270299"],

Cell[BoxData[
    \("HIZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223941-7308454"],

Cell[BoxData[
    \("HIZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223941-7750860"],

Cell[BoxData[
    \("HIGetView[] grabs the current heat flow input view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223941-3895549"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HIAnalyze[(flag)] runs the heat flow solver. The flag parameter \
controls whether the solver window is visible or minimized. For a visible \
window, either specify no value for flag or specify 0. For a minimized \
window, flag should be set to 1. An equivalent form is:\n \
HIAnalyse[(flag)]"\)], "Print",
  CellTags->"Info3347223941-4236356"],

Cell[BoxData[
    \("HIClose[] closes the preprocessor window and destroys the current \
document."\)], "Print",
  CellTags->"Info3347223941-2245144"],

Cell[BoxData[
    \("HICreateMesh[] runs triangle to create a mesh. Note that this is not a \
necessary precursor of performing an analysis, as HIAnalyze[] will make sure \
the mesh is up to date before running an analysis."\)], "Print",
  CellTags->"Info3347223941-8159017"],

Cell[BoxData[
    \("HILoadSolution[] loads and displays the solution corresponding to the \
current geometry."\)], "Print",
  CellTags->"Info3347223941-8125029"],

Cell[BoxData[
    \("HIProbDef[units,type,precision,depth,minangle] changes the problem \
definition. The units parameter specifies the units used for measuring length \
in the problem domain. Valid \"units\" entries are \"inches\", \
\"millimeters\", \"centimeters\", \"mils\", \"meters\", and \"micrometers\". \
Set problemtype to \"planar\" for a 2-D planar problem, or to \"axi\" for an \
axisymmetric problem. The precision parameter dictates the precision required \
by the solver. For example, specifying 1.E-8 requires the RMS of the residual \
to be less than 10^(-8). The depth parameter, represents the depth of the \
problem in the into-the-page direction for 2-D planar problems. The minangle \
parameter is a constraint for the mesh generator. It specifies the smallest \
permissible angle in triangles that compose the finite element mesh. A good \
value to choose is 30 degrees, but smaller values may be needed for \"tough\" \
geometries that contain small angles."\)], "Print",
  CellTags->"Info3347223941-5725470"],

Cell[BoxData[
    \("HIReadDXF[\"filename\"] reads in geometry information a DXF file \
specified by \"filename\""\)], "Print",
  CellTags->"Info3347223941-8114379"],

Cell[BoxData[
    \("HIRefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223941-7760450"],

Cell[BoxData[
    \("HISaveAs[\"filename\"] saves the file with name \"filename\". Note if \
you use a path you must use two backslashes e.g. \
\"c:\\\\temp\\\\myfemmfile.fem\""\)], "Print",
  CellTags->"Info3347223941-7609199"],

Cell[BoxData[
    \("HISaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the HISaveAs command."\)], "Print",
  CellTags->"Info3347223941-8492301"],

Cell[BoxData[
    \("HISaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the HISaveAs command."\)], \
"Print",
  CellTags->"Info3347223941-8350572"],

Cell[BoxData[
    \("HISetEditMode[\"editmode\"] sets the current editmode to:\n \"nodes\" \
\[Dash] nodes\n \"segments\" - line segments\n \"arcsegments\" - arc segments\
\n \"blocks\" - block labels\n \"group\" - selected group\n This command will \
affect all subsequent uses of the other editing commands, if they are used \
without the editaction parameter."\)], "Print",
  CellTags->"Info3347223941-7702967"],

Cell[BoxData[
    \("HISetFocus[\"documentname\"] switches the heat flow input file upon \
which scripting commands are to act. If more than one heat flow input file is \
being edited at a time, this command can be used to switch between files so \
that the mutiple files can be operated upon programmatically . \"documentname\
\" should contain the name of the desired document as it appears on the \
window\[CloseCurlyQuote]s title bar."\)], "Print",
  CellTags->"Info3347223941-7628927"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrostatics Input Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("CIAddBoundProp[\"boundpropname\", Vs, qs, c0, c1, bdryformat] adds a \
new boundary property with name \"boundpropname\"\n For a \"Fixed Voltage\" \
type boundary condition, set the Vs parameter to the desired voltage and all \
other parameters to zero. \n To obtain a \"Mixed\"  type boundary condition, \
set 	exttt{C1} and c0 as required and bdryformat to 1. Set all other \
parameters to zero.\n To obtain a prescribes surface current density, set qs \
to the desired current density in A/m^2 and set bdryformat to 2.\n For a \
\"Periodic\" boundary condition, set bdryformat to 3 and set all other \
parameters to zero.\n For an \"Anti-Perodic\" boundary condition, set \
bdryformat to 4 set all other parameters to zero."\)], "Print",
  CellTags->"Info3347223941-2550021"],

Cell[BoxData[
    \("CIAddConductorProp[\"conductorname\",vc,qc,conductortype] adds a new \
conductor property with name \"conductorname\" with either a prescribed \
voltage or a prescribed total current. Set the unused property to zero. The \
conductortype parameter is 0 for prescribed charge and 1 for prescribed \
voltage."\)], "Print",
  CellTags->"Info3347223941-9246453"],

Cell[BoxData[
    \("CIAddMaterial[\"materialname\",ox,oy,ex,ey,ltx,lty] adds a new \
material with called \"materialname\" with the material properties:\n ox \
Electrical conductivity in the x- or r-direction.\n oy Electrical \
conductivity in the y- or z-direction.\n ex Relative electrical permittivity \
in the x- or r-direction.\n ey Relative electrical permittivity in the y- or \
z-direction.\n ltx Dielectric loss tangent in the x- or r-direction.\n lty \
Dielectric loss tangent in the y- or z-direction."\)], "Print",
  CellTags->"Info3347223941-6719514"],

Cell[BoxData[
    \("CIAddPointProp[\"pointpropname\",vp,qp] adds a new point property of \
name \"pointpropname\" with either a specified voltage vp or point heat \
generation qp in units of J/m."\)], "Print",
  CellTags->"Info3347223941-3075263"],

Cell[BoxData[
    \("CIModifyBoundProp[\"BdryName\",propnum,value] allows for modification \
of a boundary property. The BC to be modified is specified by \"BdryName\". \
The next parameter is the number of the property to be set. The last number \
is the value to be applied to the specified property. The various properties \
that can be modified are listed below:\n 0 - \"BdryName\" - Name of boundary \
property\n 1 - Vs - Fixed Voltage\n 2 - js - Prescribed current density\n 3 - \
c0 - External voltage\n 4 - c1 - heat transfer coefficient\n 5 - BdryFormat - \
 Type of boundary condition (0 = Prescribed Voltage; 1 = Mixed; 2 = Surface \
Current Density; 3 = Periodic; 4 = Antiperiodic)"\)], "Print",
  CellTags->"Info3347223941-1794145"],

Cell[BoxData[
    \("CIModifyConductorProp[\"ConductorName\",propnum,value] allows for \
modification of a conductor property. The conductor property to be modified \
is specified by \"ConductorName\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\n 0 - \"ConductorName\" - Name of the conductor property\n 1 - Vc - \
Conductor Voltage\n 2 - jc - Total conductor current\n 3 - ConductorType - 0 \
= Prescribed current, 1 = Prescribed voltage"\)], "Print",
  CellTags->"Info3347223941-2809827"],

Cell[BoxData[
    \("CIModifyMaterial[\"BlockName\",propnum,value] allows for modification \
of a material's properties without redefining the entire material (e.g. so \
that current can be modified from run to run). The material to be modified is \
specified by \"BlockName\". The next parameter is the number of the property \
to be set. The last number is the value to be applied to the specified \
property. The various properties that can be modified are listed below:\n 0 - \
\"BlockName\" - Name of the material\n 1 - ox - x (or r) direction electrical \
conductivity\n 2 - oy - y (or z) direction electrical conductivity\n 1 - ox - \
x (or r) direction relative electrical permittivity\n 2 - oy - y (or z) \
direction relative electrical permittivity\n 1 - ox - x (or r) direction \
dielectric loss tangent\n 2 - oy - y (or z) direction dielectric loss \
tangent"\)], "Print",
  CellTags->"Info3347223941-3602638"],

Cell[BoxData[
    \("CIModifyPointProp[\"PointName\",propnum,value] allows for modification \
of a point property. The point property to be modified is specified by \
\"PointName\". The next parameter is the number of the property to be set. \
The last number is the value to be applied to the specified property. The \
various properties that can be modified are listed below:\n 0 - PointName - \
Name of the point property\n 1 - Vp - Prescribed nodal voltage\n 2 - jp - \
Point current in A/m"\)], "Print",
  CellTags->"Info3347223941-4062804"],

Cell[BoxData[
    \("CIDeleteBoundProp[\"boundpropname\"] deletes the boundary property \
named \"boundpropname\"."\)], "Print",
  CellTags->"Info3347223941-8484718"],

Cell[BoxData[
    \("CIDeleteConductor[\"conductorname\"] deletes the conductor property \
named \"conductorname\"."\)], "Print",
  CellTags->"Info3347223941-8368394"],

Cell[BoxData[
    \("CIDeleteMaterial[\"materialname\"] deletes the material property named \
\"materialname\"."\)], "Print",
  CellTags->"Info3347223941-5771336"],

Cell[BoxData[
    \("CIDeletePointProp[\"pointpropname\"] deletes the point property named \
\"pointpropname\"."\)], "Print",
  CellTags->"Info3347223941-5718574"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("CIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the electrostatics \
input geometry from the point nearst to {x1,y1} to the point nearest to \
{x2,y2}.  The arc spans a number of degrees specified by angle. Since FEMM \
approximates arcs by many line segments, the parameter maxseg specifies the \
maximum number of degrees that is allowed to be spanned by any one segment. \
Equivalent forms are:\n CIAddArc[{x1,y1},{x2,y2},angle,maxseg]\n \
CIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223941-9029670"],

Cell[BoxData[
    \("CIAddBlockLabel[x,y] adds a block label at the point {x,y}.  An \
equivalent form is:\n CIAddBlockLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-8579298"],

Cell[BoxData[
    \("CIAddNode[x,y] adds a new node at {x,y}. An equivalent form is:\n \
CIAddNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223941-4116126"],

Cell[BoxData[
    \("CIAddSegment[x1,y1,x2,y2] add a new line segment from node closest to \
{x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\n \
CIAddSegment[{x1,y1},{x2,y2}]\n CIAddSegment[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223942-6124645"],

Cell[BoxData[
    \("CIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the current input \
geometry by drawing points at {x1,y1} and {x2,y2} and then connecting them \
with an arc segment. The arc spans a number of degrees specified by angle. \
Since FEMM approximates arcs by many line segments, the parameter maxseg \
specifies the maximum number of degrees that is allowed to be spanned by any \
one segment. Equivalent forms are:\n CIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\n\
 CIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223942-3619064"],

Cell[BoxData[
    \("CIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} and then \
adds a segment connecting these two points.  Equivalent forms are:\n \
CIDrawLine[{x1,y1},{x2,y2}]\n CIDrawLine[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223942-4004828"],

Cell[BoxData[
    \("CIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points at every \
listed point and then draws a closed figure that connects the points"\)], \
"Print",
  CellTags->"Info3347223942-3596063"],

Cell[BoxData[
    \("CIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment line by \
adding each of the points in the list and then adding segments that join the \
listed points."\)], "Print",
  CellTags->"Info3347223942-5797197"],

Cell[BoxData[
    \("CIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, {x1,y2}, {x2,y2} \
and  {x2,y1} and joins them with new segments.  Equivalent forms are:\n \
CIDrawRectangle[{x1,y1},{x2,y2}]\n CIDrawRectangle[{{x1,y1},{x2,y2}}]"\)], \
"Print",
  CellTags->"Info3347223942-2688418"],

Cell[BoxData[
    \("CICreateRadius[x,y,z] turns a corner located at {x,y} into a curve of \
radius r.\n An equivalent form is: CICreateRadius[{x,y},z]"\)], "Print",
  CellTags->"Info3347223942-4889550"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("CISelectArcSegment[x,y] selects the arc segment closest to {x,y}.  An \
equivalent form is:\n CISelectArcSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-4775645"],

Cell[BoxData[
    \("CISelectGroup[n] selects the nth group of nodes, segments, arc \
segments and block labels. This function will clear all previously selected \
elements and leave the edit mode in 4 (group)"\)], "Print",
  CellTags->"Info3347223942-9433219"],

Cell[BoxData[
    \("CISelectLabel[x,y] selects the block label closest to {x,y}.  An \
equivalent form is:\n CISelectLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-1224636"],

Cell[BoxData[
    \("CISelectNode[x,y] selects the node closest to {x,y}.  An equivalent \
form is:\n CISelectNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-4362745"],

Cell[BoxData[
    \("CISelectSegment[x,y] selects the segment closest to {x,y}.  An \
equivalent form is:\n CISelectSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-3956808"],

Cell[BoxData[
    \("CISetArcSegmentProp[maxsegdeg, \"propname\", hide, \
groupno,\"inconductor\"] sets the properties associated with the selected arc \
segments\n maxsegdeg specifies that the arcs must be meshed with elements \
that span at most maxsegdeg degrees per element\n \"propname\" specifies the \
boundary property to be associated with the selected arcs\n hide: 0 = not \
hidden in post-processor, 1 == hidden in post processor\n groupno is an \
integer specifying the group number of which the selected arcs are to be \
members.\n \"inconductor\" specifies the name of the conductor property with \
which the selected arcs are to be associated. If the arcs is not to be part \
of a conductor, this parameter can be specified as \"<None>\"."\)], "Print",
  CellTags->"Info3347223942-7340812"],

Cell[BoxData[
    \("CISetBlockProp[\"blockname\",automesh,meshsize,groupno] sets the \
selected block labels to have the properties:\n Block property \"blockname\".\
\n automesh: 0 = mesher defers to mesh size constraint defined in meshsize, 1 \
= mesher automatically chooses the mesh density.\n meshsize: size constraint \
on the mesh in the block marked by this label\n. groupno: make selected \
members of specified group number"\)], "Print",
  CellTags->"Info3347223942-7747929"],

Cell[BoxData[
    \("CISetNodeProp[\"propname\",groupno,\"inconductor\"] sets the selected \
nodes to have the nodal property \"propname\" and group number groupno. The \
\"inconductor\" string specifies which conductor the node belongs to. If the \
node doesn\[CloseCurlyQuote]t belong to a named conductor, this parameter can \
be set to \"<None>\"."\)], "Print",
  CellTags->"Info3347223942-1072148"],

Cell[BoxData[
    \("CISetSegmentProp[\"propname\",elementsize,automesh,hide,groupno,\"\
inconductor\"] sets the select segments to have:\n Boundary property \
\"propname\"\n Local element size along segment no greater than elementsize\n \
automesh: 0 = mesher defers to the element constraint defined by elementsize, \
1 = mesher automatically chooses mesh size along the selected segments\n \
hide: 0 = not hidden in post-processor, 1 == hidden in post processor\n A \
member of group number groupno\n A member of the conductor specified by the \
string \"inconductor\". If the segment is not part of a conductor, this \
parameter can be specified as \"<None>\"."\)], "Print",
  CellTags->"Info3347223942-4833943"],

Cell[BoxData[
    \("CIDeleteSelected[] deletes all selected objects."\)], "Print",
  CellTags->"Info3347223942-3215298"],

Cell[BoxData[
    \("CIDeleteSelectedArcSegments[] deletes all selected arc segments."\)], \
"Print",
  CellTags->"Info3347223942-3062770"],

Cell[BoxData[
    \("CIDeleteSelectedLabels[] deletes all selected block labels."\)], \
"Print",
  CellTags->"Info3347223942-1478151"],

Cell[BoxData[
    \("CIDeleteSelectedNodes[] deletes all selected nodes."\)], "Print",
  CellTags->"Info3347223942-4873634"],

Cell[BoxData[
    \("CIDeleteSelectedSegments[] deletes all selected segments."\)], "Print",\

  CellTags->"Info3347223942-1405457"],

Cell[BoxData[
    \("CIClearSelected[] clear all selected nodes, blocks, segments and arc \
segments."\)], "Print",
  CellTags->"Info3347223942-3777925"],

Cell[BoxData[
    \("CIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric external region \
to be used in conjuction with the Kelvin Transformation method of modeling \
unbounded problems.  The Zo parameter is the z-location of the origin of the \
outer region, the Ro parameter is the radius of the outer region, and the Ri \
parameter is the radius of the inner region (i.e. the region of interest). In \
the exterior region, the permeability varies as a function of distance from \
the origin of the external region.  These parameters are necessary to define \
the permeability variation in the external region."\)], "Print",
  CellTags->"Info3347223942-2152760"],

Cell[BoxData[
    \("CIAttachOuterSpace[] marks all selected block labels as members of the \
external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223942-5073193"],

Cell[BoxData[
    \("CIDetachOuterSpace[] undefines all selected block labels as members of \
the external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223942-3551327"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move, Copy, Scale", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("CICopyRotate[bx,by,angle,copies,(editaction)]\n bx, by base point for \
rotation\n angle angle by which the selected objects are incrementally \
shifted to make each copy. This angle is measured in degrees.\n copies number \
of copies to be produced from the selected objects \n editaction 0-nodes, \
1-segments, 2-block labels, 3-arcs, 4-group\n An equivalent form is:\n \
CICopyRotate[{bx,by},angle,copies,(editaction)]"\)], "Print",
  CellTags->"Info3347223942-9096541"],

Cell[BoxData[
    \("CICopyTranslate[dx,dy,copies,(editaction)]\n {dx,dy} represents the \
distance by which the selected objects are to be incrementally shifted.\n \
copies specifies the number of copoies to be produced from the selected \
objects\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\n \
An equivalent form is:\n CICopyTranslate[{dx,dy},copies,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223942-2626858"],

Cell[BoxData[
    \("CIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected objects about \
a line passing through the points (x1,y1) and (x2,y2). Valid editaction \
entries are 0 for nodes, 1 for lines (segments), 2 for block labels, 3 for \
arc segments, and 4 for groups. Equivalent forms are:\n \
CIMirror[{x1,y1},{x2,y2},(editaction)]\n \
CIMirror[{{x1,y1},{x2,y2}},(editaction)]"\)], "Print",
  CellTags->"Info3347223942-9568268"],

Cell[BoxData[
    \("CIMoveRotate[bx,by,shiftangle,(editaction)]\n bx, by \[Dash] base \
point for rotation\n shiftangle \[Dash] angle in degrees by which the \
selected objects are rotated.\n editaction - 0  \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent form is:\n CIMoveRotate[{bx,by},shiftangle,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223942-6949674"],

Cell[BoxData[
    \("CIMoveTranslate[dx,dy,(editaction)]\n dx,dy \[Dash] distance by which \
the selected objects are shifted.\n editaction - 0 \[Dash]nodes, 1 \[Dash] \
lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n \
An equivalent form is:\n CIMoveTranslate[{dx,dy},(editaction)]"\)], "Print",
  CellTags->"Info3347223942-3601001"],

Cell[BoxData[
    \("CIScale[bx,by,scalefactor,(editaction)]\n bx, by \[Dash] base point \
for scaling\n scalefactor \[Dash] a multiplier that determines how much the \
selected objects are scaled\n editaction 0 \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent for is: CIScale[{bx,by},scalefactor,(editaction)]"\)], "Print",
  CellTags->"Info3347223942-6609419"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("CISetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the \"type\" parameter \
is set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223942-9958241"],

Cell[BoxData[
    \("CIShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223942-7543440"],

Cell[BoxData[
    \("CIHideGrid[] hides the current input grid points"\)], "Print",
  CellTags->"Info3347223942-5025554"],

Cell[BoxData[
    \("CIShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223942-6965775"],

Cell[BoxData[
    \("CIPurgeMesh[] clears the mesh out of both the screen and memory."\)], \
"Print",
  CellTags->"Info3347223942-3888279"],

Cell[BoxData[
    \("CIShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223942-5334754"],

Cell[BoxData[
    \("CIHideNames[] stops the names of the materials associated with each \
block label from being displayed"\)], "Print",
  CellTags->"Info3347223942-2217087"],

Cell[BoxData[
    \("CISnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223942-6944643"],

Cell[BoxData[
    \("CISnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223942-3967660"],

Cell[BoxData[
    \("CIZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n CIZoom[{x1,y1},{x2,y2}]\n \
CIZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223942-9812128"],

Cell[BoxData[
    \("CIZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223942-9428271"],

Cell[BoxData[
    \("CIZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223942-5196408"],

Cell[BoxData[
    \("CIZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223942-3765753"],

Cell[BoxData[
    \("CIGetView[] grabs the current current input view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223942-7435369"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("CIAnalyze[(flag)] runs the current solver. The flag parameter controls \
whether the solver window is visible or minimized. For a visible window, \
either specify no value for flag or specify 0. For a minimized window, flag \
should be set to 1. An equivalent form is:\n CIAnalyse[(flag)]"\)], "Print",
  CellTags->"Info3347223942-9408926"],

Cell[BoxData[
    \("CIClose[] closes the preprocessor window and destroys the current \
document."\)], "Print",
  CellTags->"Info3347223942-8756152"],

Cell[BoxData[
    \("CICreateMesh[] runs triangle to create a mesh. Note that this is not a \
necessary precursor of performing an analysis, as CIAnalyze[] will make sure \
the mesh is up to date before running an analysis."\)], "Print",
  CellTags->"Info3347223942-5512214"],

Cell[BoxData[
    \("CILoadSolution[] loads and displays the solution corresponding to the \
current geometry."\)], "Print",
  CellTags->"Info3347223942-4592327"],

Cell[BoxData[
    \("CIProbDef[units,type,frequency,precision,depth,minangle] changes the \
problem definition. The units parameter specifies the units used for \
measuring length in the problem domain. Valid \"units\" entries are \
\"inches\", \"millimeters\", \"centimeters\", \"mils\", \"meters\", and \
\"micrometers\". Set problemtype to \"planar\" for a 2-D planar problem, or \
to \"axi\" for an axisymmetric problem. The frequency parameter denotes the \
frequency of the analysis in Hz. The precision parameter dictates the \
precision required by the solver. For example, specifying 1.E-8 requires the \
RMS of the residual to be less than 10^(-8). The depth parameter, represents \
the depth of the problem in the into-the-page direction for 2-D planar \
problems. The minangle parameter is a constraint for the mesh generator. It \
specifies the smallest permissible angle in triangles that compose the finite \
element mesh. A good value to choose is 30 degrees, but smaller values may be \
needed for \"tough\" geometries that contain small angles."\)], "Print",
  CellTags->"Info3347223942-2467846"],

Cell[BoxData[
    \("CIReadDXF[\"filename\"] reads in geometry information a DXF file \
specified by \"filename\""\)], "Print",
  CellTags->"Info3347223942-6619667"],

Cell[BoxData[
    \("CIRefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223942-8743872"],

Cell[BoxData[
    \("CISaveAs[\"filename\"] saves the file with name \"filename\". Note if \
you use a path you must use two backslashes e.g. \
\"c:\\\\temp\\\\myfemmfile.fem\""\)], "Print",
  CellTags->"Info3347223942-7645405"],

Cell[BoxData[
    \("CISaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the CISaveAs command."\)], "Print",
  CellTags->"Info3347223942-9313603"],

Cell[BoxData[
    \("CISaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the CISaveAs command."\)], \
"Print",
  CellTags->"Info3347223942-6658559"],

Cell[BoxData[
    \("CISetEditMode[\"editmode\"] sets the current editmode to:\n \"nodes\" \
\[Dash] nodes\n \"segments\" - line segments\n \"arcsegments\" - arc segments\
\n \"blocks\" - block labels\n \"group\" - selected group\n This command will \
affect all subsequent uses of the other editing commands, if they are used \
without the editaction parameter."\)], "Print",
  CellTags->"Info3347223942-2489674"],

Cell[BoxData[
    \("CISetFocus[\"documentname\"] switches the current input file upon \
which scripting commands are to act. If more than one current input file is \
being edited at a time, this command can be used to switch between files so \
that the mutiple files can be operated upon programmatically . \"documentname\
\" should contain the name of the desired document as it appears on the \
window\[CloseCurlyQuote]s title bar."\)], "Print",
  CellTags->"Info3347223942-2698508"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetics Input Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MIAddBoundProp[\"propname\",A0,A1,A2,Phi,Mu,Sig,c0,c1,BdryFormat] adds \
a new boundary property with name \"propname\" \n \[Dash] For a \"Prescribed \
A\" type boundary condition, set the A0, A1, A2  and Phi parameters as \
required. Set all other parameters to zero.\n \[Dash] For a \"Small Skin \
Depth\" type boundary condtion, set the Mu to the desired relative \
permeability and Sig to the desired conductivity in MS/m. Set BdryFormat to 1 \
and all other parameters to zero. \n \[Dash] To obtain a \"Mixed\" type \
boundary condition, set C1 and C0 as required and BdryFormat to 2. Set all \
other parameters to zero. \n \[Dash] For a \"Strategic dual image\" boundary, \
set BdryFormat to 3 and set all other parameters to zero.\n \[Dash] For a \
\"Periodic\" boundary condition, set BdryFormat to 4 and set all other \
parameters to zero.\n \[Dash] For an \"Anti-Perodic\" boundary condition, set \
BdryFormat to 5 set all other parameters to zero."\)], "Print",
  CellTags->"Info3347223942-1174016"],

Cell[BoxData[
    \("MIAddCircProp[\"circuitname\",i,circuittype] adds a new circuit \
property with name \"circuitname\" with a prescribed current i. It is OK for \
the current to be complex-valued. The circuittype parameter is 0 for a \
parallel-connected circuit and 1 for a series-connected circuit."\)], "Print",\

  CellTags->"Info3347223942-3337860"],

Cell[BoxData[
    \("MIAddMaterial[\"materialname\",mux,muy,Hc,J,Cduct,Lamd,Phihmax,lamfill,\
LamType,Phihx,Phihy,NStrands,WireD]\n adds a new material with called \
\"materialname\" with the material properties:\n - mux - Relative \
permeability in the x- or r-direction (for linear materials)\n - muy - \
Relative permeability in the y- or z-direction (for linear materials)\n - Hc \
- Permanent magnet coercivity in Amps/Meter. \n - J - Applied source current \
density in Amps/mm2. It is OK for J to be complex-valued.\n - Cduct - \
Electrical conductivity of the material in MS/m.\n - Lamd - Lamination \
thickness in millimeters. \n - Phihmax - Hysteresis lag angle in degrees, \
used for nonlinear BH curves.\n - Lamfill - Fraction of the volume occupied \
per lamination that is actually filled with iron (Note that this parameter \
defaults to 1 the FEMM preprocessor dialog box because, by default, iron \
completely fills the volume)\n - Lamtype - Set to 0 for \"Not laminated or \
laminated in plane\";  1 for \"Laminated x or r\"; 2 for \"Laminated y or z\" \
\n - Phihx - Hysteresis lag in degrees in the x-direction for linear \
problems.\n - Phihy - Hysteresis lag in degrees in the y-direction for linear \
problems.\n - NStrands - number of strands per wire if the material is a \
wire.\n - WireD - diameter of each strand in mm if the material is a \
wire."\)], "Print",
  CellTags->"Info3347223942-7875248"],

Cell[BoxData[
    \("MIAddBHPoint[\"materialname\",b,h] adds the point {b,h} to the BH \
curve for the material specified by \"materialname\".  An equivalent form is:\
\n MIAddBHPoint[\"materialname\",{b,h}]"\)], "Print",
  CellTags->"Info3347223942-3565351"],

Cell[BoxData[
    \("MIAddBHPoints[\"materialname\",list] adds all of the points in list to \
the BH curve for the material specified by \"materialname\""\)], "Print",
  CellTags->"Info3347223942-9575072"],

Cell[BoxData[
    \("MIClearBHPoint[\"materialname\"] erases all of the BH points that have \
been defined for the material named \"materialname\""\)], "Print",
  CellTags->"Info3347223942-1161328"],

Cell[BoxData[
    \("MIAddPointProp[\"pointpropname\",A,J] adds a new point property of \
name \"pointpropname\" with either a specified potential A in units of \
Webers/Meter or a point current J in units of Amps. It is OK for either A or \
J to be complex-valued. Set the unused parameter to 0."\)], "Print",
  CellTags->"Info3347223942-6641394"],

Cell[BoxData[
    \("MIModifyBoundProp[\"BdryName\",propnum,value] allows for modification \
of a boundary property. The BC to be modified is specified by \"BdryName\". \
The next parameter is the number of the property to be set. The last number \
is the value to be applied to the specified property. The various properties \
that can be modified are listed below:\n 0 - \"BdryName\" - Name of boundary \
property \n 1 A0 - Prescribed A parameter\n 2 A1 - Prescribed A parameter\n 3 \
A2 - Prescribed A parameter\n 4 phi - Prescribed A phase\n 5 mu -  Small skin \
depth relative permeability \n 6 Cduct -  Small skin depth conductivity, MS/m \
\n 7 c0 - Mixed BC parameter \n 8 c1 - Mixed BC parameter \n 9 - BdryFormat.  \
Valid choices for boundary format include:\n 	0 = Prescribed A\n 	1 = Small \
skin depth\n 	2 = Mixed\n 	3 = Strategic Dual Image\n 	4 = Periodic\n 	5 = \
Antiperiodic"\)], "Print",
  CellTags->"Info3347223942-3253559"],

Cell[BoxData[
    \("MIModifyCircProp[\"circname\",propnum,value] allows for modification \
of a circuit property. The circuit property to be modified is specified by \
\"circname\". The next parameter is the number of the property to be set. The \
last number is the value to be applied to the specified property. The various \
properties that can be modified are listed below:\n 0 - CircName - Name of \
the circuit property\n 1 - i - Total current. It is OK for i to be \
complex-valued\n 2 - CircType -  0 = Parallel, 1 = Series"\)], "Print",
  CellTags->"Info3347223942-5222545"],

Cell[BoxData[
    \("MISetCurrent[\"circname\",i] sets the current of the circuit named \
\"circname\" to the value specified by i.  It is OK for the current to be \
complex-valued."\)], "Print",
  CellTags->"Info3347223942-6345755"],

Cell[BoxData[
    \("MIModifyMaterial[\"BlockName\",propnum,value] allows for modification \
of a material\[CloseCurlyQuote]s properties without redefining the entire \
material. The material to be modified is specified by \"BlockName\". The next \
parameter is the number of the property to be set. The last number is the \
value to be applied to the specified property. The various properties that \
can be modified are listed below:\n 0 - \"BlockName\" - Name of the material \
\n 1 - mux - x (or r) direction relative permeability \n 2 - muy - y (or z) \
direction relative permeability \n 3 - Hc - Coercivity, Amps/Meter \n 4 - J - \
Current density, MA/m2.  OK if J is complex-valued. \n 5 - cduct - Electrical \
conductivity, MS/m \n 6 - dlam - Lamination thickness, mm \n 7 - phihmax - \
Hysteresis lag angle for nonlinear problems, degrees \n 8 - LamFill - Iron \
fill fraction \n 9 - LamType - 0 = None/In plane, 1 = parallel to x, \
2=parallel to y \n 10 - phihx - Hysteresis lag in x-direction for linear \
problems, degrees \n 11 - phihy - Hysteresis lag in y-direction for linear \
problems, degrees"\)], "Print",
  CellTags->"Info3347223942-3683202"],

Cell[BoxData[
    \("MIModifyPointProp[\"PointName\",propnum,value] allows for modification \
of a point property. The point property to be modified is specified by \
\"PointName\". The next parameter is the number of the property to be set. \
The last number is the value to be applied to the specified property. The \
various properties that can be modified are listed below:\n 0 - PointName - \
Name of the point property \n 1 - A - Nodal potential, Weber/Meter\n 2 - J - \
Nodal current, Amps\n It is OK if either A or J are complex-valued."\)], \
"Print",
  CellTags->"Info3347223942-7858990"],

Cell[BoxData[
    \("MIDeleteBoundProp[\"boundpropname\"] deletes the boundary property \
named \"boundpropname\"."\)], "Print",
  CellTags->"Info3347223942-3699623"],

Cell[BoxData[
    \("MIDeleteCircuit[\"circuitname\"] deletes the circuit property named \
\"circuitname\"."\)], "Print",
  CellTags->"Info3347223942-4895320"],

Cell[BoxData[
    \("MIDeleteMaterial[\"materialname\"] deletes the material property named \
\"materialname\"."\)], "Print",
  CellTags->"Info3347223942-9354952"],

Cell[BoxData[
    \("MIDeletePointProp[\"pointpropname\"] deletes the point property named \
\"pointpropname\"."\)], "Print",
  CellTags->"Info3347223942-8866994"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the electrostatics \
input geometry from the point nearst to {x1,y1} to the point nearest to \
{x2,y2}.  The arc spans a number of degrees specified by angle. Since FEMM \
approximates arcs by many line segments, the parameter maxseg specifies the \
maximum number of degrees that is allowed to be spanned by any one segment. \
Equivalent forms are:\n MIAddArc[{x1,y1},{x2,y2},angle,maxseg]\n \
MIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223942-7974690"],

Cell[BoxData[
    \("MIAddBlockLabel[x,y] adds a block label at the point {x,y}.  An \
equivalent form is:\n MIAddBlockLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-7718741"],

Cell[BoxData[
    \("MIAddNode[x,y] adds a new node at {x,y}. An equivalent form is:\n \
MIAddNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-6265237"],

Cell[BoxData[
    \("MIAddSegment[x1,y1,x2,y2] add a new line segment from node closest to \
{x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\n \
MIAddSegment[{x1,y1},{x2,y2}]\n MIAddSegment[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223942-2127838"],

Cell[BoxData[
    \("MIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the electrostatics \
input geometry by drawing points at {x1,y1} and {x2,y2} and then connecting \
them with an arc segment. The arc spans a number of degrees specified by \
angle. Since FEMM approximates arcs by many line segments, the parameter \
maxseg specifies the maximum number of degrees that is allowed to be spanned \
by any one segment. Equivalent forms are:\n \
MIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\n \
MIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]"\)], "Print",
  CellTags->"Info3347223942-8061335"],

Cell[BoxData[
    \("MIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} and then \
adds a segment connecting these two points.  Equivalent forms are:\n \
MIDrawLine[{x1,y1},{x2,y2}]\n MIDrawLine[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223942-2612802"],

Cell[BoxData[
    \("MIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points at every \
listed point and then draws a closed figure that connects the points"\)], \
"Print",
  CellTags->"Info3347223942-3525955"],

Cell[BoxData[
    \("MIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment line by \
adding each of the points in the list and then adding segments that join the \
listed points."\)], "Print",
  CellTags->"Info3347223942-9298280"],

Cell[BoxData[
    \("MIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, {x1,y2}, {x2,y2} \
and  {x2,y1} and joins them with new segments.  Equivalent forms are:\n \
MIDrawRectangle[{x1,y1},{x2,y2}]\n MIDrawRectangle[{{x1,y1},{x2,y2}}]"\)], \
"Print",
  CellTags->"Info3347223942-3205867"],

Cell[BoxData[
    \("MICreateRadius[x,y,z] turns a corner located at {x,y} into a curve of \
radius r.\n An equivalent form is: MICreateRadius[{x,y},z]"\)], "Print",
  CellTags->"Info3347223942-2715408"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MISelectArcSegment[x,y] selects the arc segment closest to {x,y}.  An \
equivalent form is:\n MISelectArcSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-1902193"],

Cell[BoxData[
    \("MISelectGroup[n] selects the nth group of nodes, segments, arc \
segments and block labels. This function will clear all previously selected \
elements and leave the edit mode in 4 (group)"\)], "Print",
  CellTags->"Info3347223942-6712612"],

Cell[BoxData[
    \("MISelectLabel[x,y] selects the block label closest to {x,y}.  An \
equivalent form is:\n MISelectLabel[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-4802586"],

Cell[BoxData[
    \("MISelectNode[x,y] selects the node closest to {x,y}.  An equivalent \
form is:\n MISelectNode[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-6636810"],

Cell[BoxData[
    \("MISelectSegment[x,y] selects the segment closest to {x,y}.  An \
equivalent form is:\n MISelectSegment[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-4840162"],

Cell[BoxData[
    \("MISetArcSegmentProp[maxsegdeg,\"propname\",hide,groupno] sets the \
selected arc segments to:\n \[Dash] Meshed with elements that span at most \
maxsegdeg degrees per element\n \[Dash] Boundary property \"propname\"\n \
\[Dash] hide: 0 = not hidden in post-processor, 1 == hidden in post processor\
\n \[Dash] A member of group number groupno"\)], "Print",
  CellTags->"Info3347223942-7491570"],

Cell[BoxData[
    \("MISetBlockProp[\"blockname\",automesh,meshsize,\"incircuit\", \
magdirection,group,turns]\n sets the selected block labels to have the \
properties:\n \[Dash] Block property \"blockname\".\n \[Dash] automesh: 0 = \
mesher defers to mesh size constraint defined in meshsize, 1 = mesher \
automatically chooses the mesh density.\n \[Dash] meshsize: size constraint \
on the mesh in the block marked by this label.\n \[Dash] Block is a member of \
the circuit named \"incircuit\" \n \[Dash] The magnetization is directed \
along an angle in measured in degrees denoted by the parameter magdirection\n \
\[Dash] A member of group number group\n \[Dash] The number of turns \
associated with this label is denoted by turns."\)], "Print",
  CellTags->"Info3347223942-1473756"],

Cell[BoxData[
    \("MISetNodeProp[\"propname\",groupno] set the selected nodes to have the \
nodal property \"propname\" and group number groupno."\)], "Print",
  CellTags->"Info3347223942-1735460"],

Cell[BoxData[
    \("MISetSegmentProp[\"propname\",elementsize,automesh,hide,group] sets \
the selected segments to have:\n \[Dash] Boundary property \"propname\" \n \
\[Dash] Local element size along segment no greater than elementsize \n \
\[Dash] automesh: 0 = mesher defers to the element constraint defined by \
elementsize, 1 = mesher automatically chooses mesh size along the selected \
segments \n \[Dash] hide: 0 = not hidden in post-processor, 1 == hidden in \
post processor\n \[Dash] A member of group number group"\)], "Print",
  CellTags->"Info3347223942-2227327"],

Cell[BoxData[
    \("MIDeleteSelected[] deletes all selected objects."\)], "Print",
  CellTags->"Info3347223942-4747170"],

Cell[BoxData[
    \("MIDeleteSelectedArcSegments[] deletes all selected arc segments."\)], \
"Print",
  CellTags->"Info3347223942-2286321"],

Cell[BoxData[
    \("MIDeleteSelectedLabels[] deletes all selected block labels."\)], \
"Print",
  CellTags->"Info3347223942-8963834"],

Cell[BoxData[
    \("MIDeleteSelectedNodes[] deletes all selected nodes."\)], "Print",
  CellTags->"Info3347223942-9305092"],

Cell[BoxData[
    \("MIDeleteSelectedSegments[] deletes all selected segments."\)], "Print",\

  CellTags->"Info3347223942-6456408"],

Cell[BoxData[
    \("MIClearSelected[] clear all selected nodes, blocks, segments and arc \
segments."\)], "Print",
  CellTags->"Info3347223942-3630767"],

Cell[BoxData[
    \("MIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric external region \
to be used in conjuction with the Kelvin Transformation method of modeling \
unbounded problems.  The Zo parameter is the z-location of the origin of the \
outer region, the Ro parameter is the radius of the outer region, and the Ri \
parameter is the radius of the inner region (i.e. the region of interest). In \
the exterior region, the permeability varies as a function of distance from \
the origin of the external region.  These parameters are necessary to define \
the permeability variation in the external region."\)], "Print",
  CellTags->"Info3347223942-8451424"],

Cell[BoxData[
    \("MIAttachOuterSpace[] marks all selected block labels as members of the \
external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223942-9036334"],

Cell[BoxData[
    \("MIDetachOuterSpace[] undefines all selected block labels as members of \
the external region used for modeling unbounded axisymmetric problems via the \
Kelvin Transformation."\)], "Print",
  CellTags->"Info3347223942-8833736"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move/Copy/Scale", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MICopyRotate[bx,by,angle,copies,(editaction)]\n bx, by base point for \
rotation\n angle angle by which the selected objects are incrementally \
shifted to make each copy. This angle is measured in degrees.\n copies number \
of copies to be produced from the selected objects \n editaction 0-nodes, \
1-segments, 2-block labels, 3-arcs, 4-group\n An equivalent form is:\n \
MICopyRotate[{bx,by},angle,copies,(editaction)]"\)], "Print",
  CellTags->"Info3347223942-7130020"],

Cell[BoxData[
    \("MICopyTranslate[dx,dy,copies,(editaction)]\n {dx,dy} represents the \
distance by which the selected objects are to be incrementally shifted.\n \
copies specifies the number of copoies to be produced from the selected \
objects\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\n \
An equivalent form is:\n MICopyTranslate[{dx,dy},copies,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223942-7499705"],

Cell[BoxData[
    \("MIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected objects about \
a line passing through the points (x1,y1) and (x2,y2). Valid editaction \
entries are 0 for nodes, 1 for lines (segments), 2 for block labels, 3 for \
arc segments, and 4 for groups. Equivalent forms are:\n \
MIMirror[{x1,y1},{x2,y2},(editaction)]\n \
MIMirror[{{x1,y1},{x2,y2}},(editaction)]"\)], "Print",
  CellTags->"Info3347223942-7334860"],

Cell[BoxData[
    \("MIMoveRotate[bx,by,shiftangle,(editaction)]\n bx, by \[Dash] base \
point for rotation\n shiftangle \[Dash] angle in degrees by which the \
selected objects are rotated.\n editaction - 0  \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent form is:\n MIMoveRotate[{bx,by},shiftangle,(editaction)]"\)], \
"Print",
  CellTags->"Info3347223942-3929142"],

Cell[BoxData[
    \("MIMoveTranslate[dx,dy,(editaction)]\n dx,dy \[Dash] distance by which \
the selected objects are shifted.\n editaction - 0 \[Dash]nodes, 1 \[Dash] \
lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n \
An equivalent form is:\n MIMoveTranslate[{dx,dy},(editaction)]"\)], "Print",
  CellTags->"Info3347223942-4675478"],

Cell[BoxData[
    \("MIScale[bx,by,scalefactor,(editaction)]\n bx, by \[Dash] base point \
for scaling\n scalefactor \[Dash] a multiplier that determines how much the \
selected objects are scaled\n editaction 0 \[Dash]nodes, 1 \[Dash] lines \
(segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- group\n An \
equivalent for is: MIScale[{bx,by},scalefactor,(editaction)]"\)], "Print",
  CellTags->"Info3347223942-6544225"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MISetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the \"type\" parameter \
is set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223942-4841605"],

Cell[BoxData[
    \("MIShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223942-6260931"],

Cell[BoxData[
    \("MIHideGrid[] hides the electrostatics input grid points"\)], "Print",
  CellTags->"Info3347223942-2933636"],

Cell[BoxData[
    \("MIShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223942-6299238"],

Cell[BoxData[
    \("MIPurgeMesh[] clears the mesh out of both the screen and memory."\)], \
"Print",
  CellTags->"Info3347223942-8455083"],

Cell[BoxData[
    \("MIShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223942-2761304"],

Cell[BoxData[
    \("MIHideNames[] stops the names of the materials associated with each \
block label from being displayed"\)], "Print",
  CellTags->"Info3347223942-7582796"],

Cell[BoxData[
    \("MISnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223942-3568316"],

Cell[BoxData[
    \("MISnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223942-8381002"],

Cell[BoxData[
    \("MIZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n MIZoom[{x1,y1},{x2,y2}]\n \
MIZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223942-6455526"],

Cell[BoxData[
    \("MIZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223942-4808313"],

Cell[BoxData[
    \("MIZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223942-2972084"],

Cell[BoxData[
    \("MIZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223942-3404091"],

Cell[BoxData[
    \("MIGetView[] grabs the current electrostatics input view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223942-5570118"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MIAnalyze[(flag)] runs the magnetics solver. The flag parameter \
controls whether the solver window is visible or minimized. For a visible \
window, either specify no value for flag or specify 0. For a minimized \
window, flag should be set to 1. An equivalent form is:\n \
MIAnalyse[(flag)]"\)], "Print",
  CellTags->"Info3347223942-9710485"],

Cell[BoxData[
    \("MIClose[] closes the preprocessor window and destroys the current \
document."\)], "Print",
  CellTags->"Info3347223942-3212477"],

Cell[BoxData[
    \("MICreateMesh[] runs triangle to create a mesh. Note that this is not a \
necessary precursor of performing an analysis, as MIAnalyze[] will make sure \
the mesh is up to date before running an analysis."\)], "Print",
  CellTags->"Info3347223942-7052201"],

Cell[BoxData[
    \("MILoadSolution[] loads and displays the solution corresponding to the \
current geometry."\)], "Print",
  CellTags->"Info3347223942-1274397"],

Cell[BoxData[
    \("MIProbDef[freq,units,type,precision,depth,minangle] changes the \
problem definition. The freq parameter specifies the frequency at which the \
analysis is performed in Hz. The units parameter specifies the units used for \
measuring length in the problem domain. Valid \"units\" entries are \
\"inches\", \"millimeters\", \"centimeters\", \"mils\", \"meters\", and \
\"micrometers\". Set problemtype to \"planar\" for a 2-D planar problem, or \
to \"axi\" for an axisymmetric problem. The precision parameter dictates the \
precision required by the solver. For example, specifying 1.E-8 requires the \
RMS of the residual to be less than 10^(-8). The depth parameter, represents \
the depth of the problem in the into-the-page direction for 2-D planar \
problems. The minangle parameter is a constraint for the mesh generator. It \
specifies the smallest permissible angle in triangles that compose the finite \
element mesh. A good value to choose is 30 degrees, but smaller values may be \
needed for \"tough\" geometries that contain small angles."\)], "Print",
  CellTags->"Info3347223942-6291660"],

Cell[BoxData[
    \("MIReadDXF[\"filename\"] reads in geometry information a DXF file \
specified by \"filename\""\)], "Print",
  CellTags->"Info3347223942-1780589"],

Cell[BoxData[
    \("MIRefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223942-7289647"],

Cell[BoxData[
    \("MISaveAs[\"filename\"] saves the file with name \"filename\". Note if \
you use a path you must use two backslashes e.g. \
\"c:\\\\temp\\\\myfemmfile.fem\""\)], "Print",
  CellTags->"Info3347223942-3206676"],

Cell[BoxData[
    \("MISaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the MISaveAs command."\)], "Print",
  CellTags->"Info3347223942-9428676"],

Cell[BoxData[
    \("MISaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the MISaveAs command."\)], \
"Print",
  CellTags->"Info3347223942-7629229"],

Cell[BoxData[
    \("MISetEditMode[\"editmode\"] sets the current editmode to:\n \"nodes\" \
\[Dash] nodes\n \"segments\" - line segments\n \"arcsegments\" - arc segments\
\n \"blocks\" - block labels\n \"group\" - selected group\n This command will \
affect all subsequent uses of the other editing commands, if they are used \
without the editaction parameter."\)], "Print",
  CellTags->"Info3347223942-1442542"],

Cell[BoxData[
    \("MISetFocus[\"documentname\"] switches the electrostatics input file \
upon which scripting commands are to act. If more than one electrostatics \
input file is being edited at a time, this command can be used to switch \
between files so that the mutiple files can be operated upon programmatically \
. \"documentname\" should contain the name of the desired document as it \
appears on the window\[CloseCurlyQuote]s title bar."\)], "Print",
  CellTags->"Info3347223942-1702933"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrostatics Output Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EOAddContour[x,y] adds the point {x,y} to the contour that is used for \
plotting values along lines and for computing line integrals.  An equivalent \
form is:\n EOAddContour[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-5078785"],

Cell[BoxData[
    \("EOBendContour[angle,anglestep] replaces the straight line formed by \
the last two points in the contour by an arc that spans angle degrees. The \
arc is actually composed of many straight lines, each of which is constrained \
to span no more than anglestep degrees. The angle parameter can take on \
values from -180 to 180 degrees. The anglestep parameter must be greater than \
zero. If there are less than two points defined in the contour, this command \
is ignored."\)], "Print",
  CellTags->"Info3347223942-1556017"],

Cell[BoxData[
    \("EOClearContour[] clears the current contour selection"\)], "Print",
  CellTags->"Info3347223942-3937423"],

Cell[BoxData[
    \("EOSelectBlock[x,y] select the block that contains point {x,y}.  An \
equivalent form is:\n EOSelectBlock[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-1584120"],

Cell[BoxData[
    \("EOSelectPoint[x,y] adds a contour point at the closest input point to \
{x,y}. If the selected point and a previous selected points lie at the ends \
of an arcsegment, a contour is added that traces along the arcsegment. The \
selectpoint command has the same functionality as the left-button-click \
contour point selection when the program is running in interactive mode. An \
equivalent form is:\n EOSelectPoint[{x,y}]"\)], "Print",
  CellTags->"Info3347223942-8122127"],

Cell[BoxData[
    \("EOGroupSelectBlock[n] selects all of the blocks that are labeled by \
block labels that are members of group n. If no number is specified (i.e. \
EOGroupSelectBlock[]), all blocks are selected."\)], "Print",
  CellTags->"Info3347223942-6550982"],

Cell[BoxData[
    \("EOClearBlock[] clears the current block selection"\)], "Print",
  CellTags->"Info3347223942-4006352"],

Cell[BoxData[
    \("EOBlockIntegral[type] calculate a block integral for the selected \
blocks. The type parameter can take on the following values:\n 0 - Stored \
Energy\n 1 - Block Cross-section\n 2 - Block Volume\n 3 - Average D over the \
block\n 4 - Average E over the block\n 5 - Weighted Stress Tensor Force\n 6 - \
Weighted Stress Tensor Torque\n returns either a single value or a list of \
two values, depending on the specified type"\)], "Print",
  CellTags->"Info3347223943-7268328"],

Cell[BoxData[
    \("EOLineIntegral[type] calculate the line integral for the defined \
contour. Valid type selections include:\n 0 - E \[CenterDot]t \n 1 - D\
\[CenterDot]n \n 2 - Contour length \n 3 - Force from stress tensor \n 4 - \
Torque from stress tensor \n This integral returns either one value or a list \
of two values, depending on the type of integral"\)], "Print",
  CellTags->"Info3347223943-9145937"],

Cell[BoxData[
    \("EOMakePlot[PlotType,NumPoints,Filename,FileFormat]\n This function \
allows programmatic access to FEMM's X-Y plot routines. If only PlotType or \
only PlotType and NumPoints are specified, the command is interpreted as a \
request to plot the requested plot type to the screen. If, in addition, the \
Filename parameter is specified, the plot is instead written to disk to the \
specified file name as an extended metafile. If the FileFormat parameter is \
also, the command is instead interpreted as a command to write the data to \
disk to the specfied file name, rather than display it to make a graphical \
plot. Valid entries for PlotType are: \n 0 - V (Voltage)\n 1 - |D| (Magnitude \
of flux density)\n 2 - D . n (Normal flux density)\n 3 - D . t (Tangential \
flux density)\n 4 - |E| (Magnitude of field intensity)\n 5 - E . n (Normal \
field intensity)\n 6 - E . t (Tangential field intensity)"\)], "Print",
  CellTags->"Info3347223943-9840448"],

Cell[BoxData[
    \("EOGetConductorProperties[\"conductor\"] returns properties for the \
conductor property named \"conductor\". A list with two values is returned: \
The voltage of the specified conductor, and the charge carried on the \
specified conductor."\)], "Print",
  CellTags->"Info3347223943-7986648"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EOGetPointValues[x,y] returns the various field values associated with \
the point at {x,y}. The return values, in order, are:\n V - Voltage \n Dx - \
x- or r- direction component of displacement \n Dy - y- or z- direction \
component of displacement \n Ex - x- or r- direction component of electric \
field intensity \n Ey - y- or z- direction component of electric field \
intensity \n ex - x- or r- direction component of permittivity \n ey - y- or \
z- direction component of permittivity \n nrg - electric field energy density \
\n An equivalent form is: \n EOGetPointValues[x,y]"\)], "Print",
  CellTags->"Info3347223943-7429312"],

Cell[BoxData[
    \("EOGetV[x,y] returns the voltage at point {x,y}. An equivalent form is:\
\n EOGetV[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-7412679"],

Cell[BoxData[
    \("EOGetD[x,y] returns a list with two elements containing the electric \
flux density at point {x,y}.  An equivalent form is:\n EOGetD[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223943-4063720"],

Cell[BoxData[
    \("EOGetE[x,y] returns a list with two elements containing the electric \
field intensity at point {x,y}.  An equivalent form is:\n EOGetE[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223943-2445563"],

Cell[BoxData[
    \("EOGetEnergyDensity[x,y] returns the energy density, (E.D)/2, at point \
{x,y}.  An equivalent form is:\n EOGetEnergyDensity[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-6984034"],

Cell[BoxData[
    \("EOGetPerm[x,y] returns a list with two elements containing the \
permittivity at point {x,y}. An equivalent form is:\n EOGetPerm[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223943-7106080"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EOShowContourPlot[numcontours,lowerV,upperV] shows the V contour plot \
with options:\n numcontours - Number of equipotential lines to be plotted.\n \
upperV - Upper limit for contours.\n lowerV - Lower limit for contours.\n If \
numcontours is -1 all parameters are ignored and default values are used"\)], \
"Print",
  CellTags->"Info3347223943-3775443"],

Cell[BoxData[
    \("EOHideContourPlot[] hides the currently displayed contour plot"\)], \
"Print",
  CellTags->"Info3347223943-8151160"],

Cell[BoxData[
    \("EOShowDensityPlot[legend,gscale,upperD,lowerD,type]\n Shows the flux \
density plot with options:\n legend - Set to 0 to hide the plot legend or 1 \
to show the plot legend.\n gscale - Set to 0 for a colour density plot or 1 \
for a grey scale density plot.\n upperD - Sets the upper display limit for \
the density plot.\n lowerD - Sets the lower display limit for the density \
plot.\n type - Sets the type of density plot. A value of 0 plots voltage, 1 \
plots the magnitude of D, and 2 plots the magnitude of E"\)], "Print",
  CellTags->"Info3347223943-8563191"],

Cell[BoxData[
    \("EOHideDensityPlot[] hides the currently displayed density plot"\)], \
"Print",
  CellTags->"Info3347223943-7693835"],

Cell[BoxData[
    \("EOSetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the type parameter is \
set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223943-2142348"],

Cell[BoxData[
    \("EOShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223943-4698659"],

Cell[BoxData[
    \("EOHideGrid[] hides the grid points from view in the electrostatics \
output window"\)], "Print",
  CellTags->"Info3347223943-1610739"],

Cell[BoxData[
    \("EOShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223943-4515092"],

Cell[BoxData[
    \("EOHideMesh[] hides the finite element mesh from in the electrostatics \
output view"\)], "Print",
  CellTags->"Info3347223943-2547445"],

Cell[BoxData[
    \("EOShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223943-5690018"],

Cell[BoxData[
    \("EOHideNames[] hides material names associated with block labels from \
view in the electrostatics output window"\)], "Print",
  CellTags->"Info3347223943-2070076"],

Cell[BoxData[
    \("EOShowPoints[] displays the input node point as part of the output \
geometry"\)], "Print",
  CellTags->"Info3347223943-5398885"],

Cell[BoxData[
    \("EOHidePoints[] inhibits the display of input node points in the \
electrostatics output window"\)], "Print",
  CellTags->"Info3347223943-3534432"],

Cell[BoxData[
    \("EOSmoothOn[] turns on smoothing of the D and E fields.  The D and E \
fields are then displayed using a linear interpolation of the field from \
nodal values"\)], "Print",
  CellTags->"Info3347223943-2811507"],

Cell[BoxData[
    \("EOSmoothOff[] turns off smoothing of the D and E fields.  The D and E \
fields are then displayed using values that are piecewise constant over each \
element."\)], "Print",
  CellTags->"Info3347223943-3089526"],

Cell[BoxData[
    \("EOSnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223943-4050909"],

Cell[BoxData[
    \("EOSnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223943-2256146"],

Cell[BoxData[
    \("EOZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n EOZoom[{x1,y1},{x2,y2}]\n \
EOZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223943-2578274"],

Cell[BoxData[
    \("EOZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223943-1967258"],

Cell[BoxData[
    \("EOZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223943-3803042"],

Cell[BoxData[
    \("EOZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223943-8980657"],

Cell[BoxData[
    \("EORefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223943-4021916"],

Cell[BoxData[
    \("EOGetView[] grabs the current electrostatics output view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223943-4519082"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("EOClose[] close the current postprocessor document and window"\)], \
"Print",
  CellTags->"Info3347223943-1421647"],

Cell[BoxData[
    \("EOGetProblemInfo[] returns a list with two values: the Problem Type (0 \
for planar and 1 for axisymmetric) and the depth assumed for planar problems \
in units of meters."\)], "Print",
  CellTags->"Info3347223943-4876034"],

Cell[BoxData[
    \("EOReload[] reloads the current electrostatics output file."\)], "Print",\

  CellTags->"Info3347223943-4053978"],

Cell[BoxData[
    \("EOSaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the EISaveAs command."\)], "Print",
  CellTags->"Info3347223943-8562188"],

Cell[BoxData[
    \("EOSaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the EISaveAs command."\)], \
"Print",
  CellTags->"Info3347223943-7158326"],

Cell[BoxData[
    \("EOSetEditMode[\"mode\"] sets the mode of the postprocessor to point, \
contour, or area mode. Valid entries for mode are \"point\", \"contour\", and \
\"area\"."\)], "Print",
  CellTags->"Info3347223943-1889904"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heat Flow Output Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HOAddContour[x,y] adds the point {x,y} to the contour that is used for \
plotting values along lines and for computing line integrals.  An equivalent \
form is:\n HOAddContour[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-5722087"],

Cell[BoxData[
    \("HOBendContour[angle,anglestep] replaces the straight line formed by \
the last two points in the contour by an arc that spans angle degrees. The \
arc is actually composed of many straight lines, each of which is constrained \
to span no more than anglestep degrees. The angle parameter can take on \
values from -180 to 180 degrees. The anglestep parameter must be greater than \
zero. If there are less than two points defined in the contour, this command \
is ignored."\)], "Print",
  CellTags->"Info3347223943-6066732"],

Cell[BoxData[
    \("HOClearContour[] clears the current contour selection"\)], "Print",
  CellTags->"Info3347223943-7540695"],

Cell[BoxData[
    \("HOSelectBlock[x,y] select the block that contains point {x,y}.  An \
equivalent form is:\n HOSelectBlock[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-8356363"],

Cell[BoxData[
    \("HOSelectPoint[x,y] adds a contour point at the closest input point to \
{x,y}. If the selected point and a previous selected points lie at the ends \
of an arcsegment, a contour is added that traces along the arcsegment. The \
selectpoint command has the same functionality as the left-button-click \
contour point selection when the program is running in interactive mode. An \
equivalent form is:\n HOSelectPoint[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-2610039"],

Cell[BoxData[
    \("HOGroupSelectBlock[n] selects all of the blocks that are labeled by \
block labels that are members of group n. If no number is specified (i.e. \
HOGroupSelectBlock[]), all blocks are selected."\)], "Print",
  CellTags->"Info3347223943-9333251"],

Cell[BoxData[
    \("HOClearBlock[] clears the current block selection"\)], "Print",
  CellTags->"Info3347223943-5741528"],

Cell[BoxData[
    \("HOBlockIntegral[type] calculate a block integral for the selected \
blocks. The type parameter can take on the following values:\n 0 - Average \
Temperature\n 1 - Block Cross-section\n 2 - Block Volume\n 3 - Average F over \
the block\n 4 - Average G over the block\n returns either a single value or a \
list of two values, depending on the specified type"\)], "Print",
  CellTags->"Info3347223943-2058617"],

Cell[BoxData[
    \("HOLineIntegral[type] calculate the line integral for the defined \
contour. Valid type selections include:\n 0 - Temperature Difference (G\
\[CenterDot]t) \n 1 - Heat Flux (F\[CenterDot]n) \n 2 - Contour length \n 3 - \
Average temperature \n This integral returns either one value or a list of \
two values, depending on the type of integral"\)], "Print",
  CellTags->"Info3347223943-6061612"],

Cell[BoxData[
    \("HOMakePlot[PlotType,NumPoints,Filename,FileFormat]\n This function \
allows programmatic access to FEMM's X-Y plot routines. If only PlotType or \
only PlotType and NumPoints are specified, the command is interpreted as a \
request to plot the requested plot type to the screen. If, in addition, the \
Filename parameter is specified, the plot is instead written to disk to the \
specified file name as an extended metafile. If the FileFormat parameter is \
also, the command is instead interpreted as a command to write the data to \
disk to the specfied file name, rather than display it to make a graphical \
plot. Valid entries for PlotType are: \n 0 - T (temperature)\n 1 - |F| \
(Magnitude of heat flux density)\n 2 - F . n (Normal heat flux density)\n 3 - \
F . t (Tangential heat flux density)\n 4 - |G| (Magnitude of field intensity)\
\n 5 - G . n (Normal temperature gradient)\n 6 - G . t (Tangential \
temperature gradient)"\)], "Print",
  CellTags->"Info3347223943-5839947"],

Cell[BoxData[
    \("HOGetConductorProperties[\"conductor\"] returns properties for the \
conductor property named \"conductor\". A list with two values is returned: \
The temperature of the specified conductor, and the total heat flux from the \
specified conductor."\)], "Print",
  CellTags->"Info3347223943-6964670"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HOGetPointValues[x,y] returns the various field values associated with \
the point at {x,y}. The return values, in order, are:\n T - temperature \n Fx \
- x- or r- direction component of heat flux density \n Fy - y- or z- \
direction component of heat flux density \n Gx - x- or r- direction component \
of temperature gradient \n Gy - y- or z- direction component of temperature \
gradient \n Kx - x- or r- direction component of thermal conductivity \n Ky - \
y- or z- direction component of thermal conductivity \n An equivalent form \
is: \n HOGetPointValues[x,y]"\)], "Print",
  CellTags->"Info3347223943-7045062"],

Cell[BoxData[
    \("HOGetT[x,y] returns the temperature at point {x,y}. An equivalent form \
is:\n HOGetT[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-3156769"],

Cell[BoxData[
    \("HOGetK[x,y] returns a list with two elements containing the thermal \
conductivity at point {x,y}. An equivalent form is:\n HOGetK[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223943-6001645"],

Cell[BoxData[
    \("HOGetD[x,y] returns a list with two elements containing the heat flux \
density at point {x,y}.  An equivalent form is:\n HOGetF[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-4852106"],

Cell[BoxData[
    \("HOGetE[x,y] returns a list with two elements containing the \
temperature gradient at point {x,y}.  An equivalent form is:\n HOGetG[{x,y}]"\
\)], "Print",
  CellTags->"Info3347223943-2532118"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HOShowContourPlot[numcontours,lowerV,upperV] shows the V contour plot \
with options:\n numcontours - Number of equipotential lines to be plotted.\n \
upperV - Upper limit for contours.\n lowerV - Lower limit for contours.\n If \
numcontours is -1 all parameters are ignored and default values are used"\)], \
"Print",
  CellTags->"Info3347223943-7067293"],

Cell[BoxData[
    \("HOHideContourPlot[] hides the currently displayed contour plot"\)], \
"Print",
  CellTags->"Info3347223943-9641375"],

Cell[BoxData[
    \("HOShowDensityPlot[legend,gscale,upperD,lowerD,type]\n Shows the flux \
density plot with options:\n legend - Set to 0 to hide the plot legend or 1 \
to show the plot legend.\n gscale - Set to 0 for a colour density plot or 1 \
for a grey scale density plot.\n upperD - Sets the upper display limit for \
the density plot.\n lowerD - Sets the lower display limit for the density \
plot.\n type - Sets the type of density plot. A value of 0 plots temperature, \
1 plots the magnitude of D, and 2 plots the magnitude of E"\)], "Print",
  CellTags->"Info3347223943-7839447"],

Cell[BoxData[
    \("HOHideDensityPlot[] hides the currently displayed density plot"\)], \
"Print",
  CellTags->"Info3347223943-3277276"],

Cell[BoxData[
    \("HOSetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the type parameter is \
set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223943-1779400"],

Cell[BoxData[
    \("HOShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223943-8626447"],

Cell[BoxData[
    \("HOHideGrid[] hides the grid points from view in the heat flow output \
window"\)], "Print",
  CellTags->"Info3347223943-1614004"],

Cell[BoxData[
    \("HOShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223943-1756910"],

Cell[BoxData[
    \("HOHideMesh[] hides the finite element mesh from in the heat flow \
output view"\)], "Print",
  CellTags->"Info3347223943-7953603"],

Cell[BoxData[
    \("HOShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223943-7285242"],

Cell[BoxData[
    \("HOHideNames[] hides material names associated with block labels from \
view in the heat flow output window"\)], "Print",
  CellTags->"Info3347223943-3710641"],

Cell[BoxData[
    \("HOShowPoints[] displays the input node point as part of the output \
geometry"\)], "Print",
  CellTags->"Info3347223943-6496722"],

Cell[BoxData[
    \("HOHidePoints[] inhibits the display of input node points in the heat \
flow output window"\)], "Print",
  CellTags->"Info3347223943-4583684"],

Cell[BoxData[
    \("HOSmoothOn[] turns on smoothing of the D and E fields.  The D and E \
fields are then displayed using a linear interpolation of the field from \
nodal values"\)], "Print",
  CellTags->"Info3347223943-5150566"],

Cell[BoxData[
    \("HOSmoothOff[] turns off smoothing of the D and E fields.  The D and E \
fields are then displayed using values that are piecewise constant over each \
element."\)], "Print",
  CellTags->"Info3347223943-5115022"],

Cell[BoxData[
    \("HOSnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223943-6296956"],

Cell[BoxData[
    \("HOSnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223943-1006138"],

Cell[BoxData[
    \("HOZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n HOZoom[{x1,y1},{x2,y2}]\n \
HOZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223943-3228834"],

Cell[BoxData[
    \("HOZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223943-1888747"],

Cell[BoxData[
    \("HOZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223943-7381528"],

Cell[BoxData[
    \("HOZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223943-8122874"],

Cell[BoxData[
    \("HORefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223943-6416613"],

Cell[BoxData[
    \("HOGetView[] grabs the current heat flow output view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223943-1079780"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("HOClose[] close the current postprocessor document and window"\)], \
"Print",
  CellTags->"Info3347223943-5972664"],

Cell[BoxData[
    \("HOGetProblemInfo[] returns a list with two values: the Problem Type (0 \
for planar and 1 for axisymmetric) and the depth assumed for planar problems \
in units of meters."\)], "Print",
  CellTags->"Info3347223943-4112961"],

Cell[BoxData[
    \("HOReload[] reloads the current heat flow output file."\)], "Print",
  CellTags->"Info3347223943-2709084"],

Cell[BoxData[
    \("HOSaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the HISaveAs command."\)], "Print",
  CellTags->"Info3347223943-8970379"],

Cell[BoxData[
    \("HOSaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the HISaveAs command."\)], \
"Print",
  CellTags->"Info3347223943-7602098"],

Cell[BoxData[
    \("HOSetEditMode[\"mode\"] sets the mode of the postprocessor to point, \
contour, or area mode. Valid entries for mode are \"point\", \"contour\", and \
\"area\"."\)], "Print",
  CellTags->"Info3347223943-2781622"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Current Flow Output Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("COAddContour[x,y] adds the point {x,y} to the contour that is used for \
plotting values along lines and for computing line integrals.  An equivalent \
form is:\n COAddContour[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-1412650"],

Cell[BoxData[
    \("COBendContour[angle,anglestep] replaces the straight line formed by \
the last two points in the contour by an arc that spans angle degrees. The \
arc is actually composed of many straight lines, each of which is constrained \
to span no more than anglestep degrees. The angle parameter can take on \
values from -180 to 180 degrees. The anglestep parameter must be greater than \
zero. If there are less than two points defined in the contour, this command \
is ignored."\)], "Print",
  CellTags->"Info3347223943-9876552"],

Cell[BoxData[
    \("COClearContour[] clears the current contour selection"\)], "Print",
  CellTags->"Info3347223943-9911280"],

Cell[BoxData[
    \("COSelectBlock[x,y] select the block that contains point {x,y}.  An \
equivalent form is:\n COSelectBlock[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-6335135"],

Cell[BoxData[
    \("COSelectPoint[x,y] adds a contour point at the closest input point to \
{x,y}. If the selected point and a previous selected points lie at the ends \
of an arcsegment, a contour is added that traces along the arcsegment. The \
selectpoint command has the same functionality as the left-button-click \
contour point selection when the program is running in interactive mode. An \
equivalent form is:\n COSelectPoint[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-9595876"],

Cell[BoxData[
    \("COGroupSelectBlock[n] selects all of the blocks that are labeled by \
block labels that are members of group n. If no number is specified (i.e. \
COGroupSelectBlock[]), all blocks are selected."\)], "Print",
  CellTags->"Info3347223943-5396991"],

Cell[BoxData[
    \("COClearBlock[] clears the current block selection"\)], "Print",
  CellTags->"Info3347223943-6581954"],

Cell[BoxData[
    \("COBlockIntegral[type] calculate a block integral for the selected \
blocks. The type parameter can take on the following values:\n      0   Real \
Power \n      1   Reactive Power \n      2   Apparent Power \n      3   \
Time-Average Stored Energy \n      4   Block cross-section area \n      5   \
Block volume \n      6   x (or r) direction Weighted Stress Tensor force, DC \
component \n      7   y (or z) direction Weighted Stress Tensor force, DC \
component \n      8   x (or r) direction Weighted Stress Tensor force, 2x \
frequency component \n      9   y (or z) direction Weighted Stress Tensor \
force, 2x frequency component \n      10  Weighted Stress Tensor torque, DC \
component \n      11  Weighted Stress Tensor torque, 2x frequency component \n\
 Returns either a single value or a list of two values, depending on the \
specified type"\)], "Print",
  CellTags->"Info3347223943-8464511"],

Cell[BoxData[
    \("COLineIntegral[type] calculate the line integral for the defined \
contour. Valid type selections include:\n  0  E.t \n  1  J.n \n  2  Contour \
length \n  3  Average voltage over contour \n  4  Force from stress tensor \n \
 5  Torque from stress tensor \n This integral returns either one value or a \
list of two values, depending on the type of integral"\)], "Print",
  CellTags->"Info3347223943-4874601"],

Cell[BoxData[
    \("COMakePlot[PlotType,NumPoints,Filename,FileFormat]\n This function \
allows programmatic access to FEMM's X-Y plot routines. If only PlotType or \
only PlotType and NumPoints are specified, the command is interpreted as a \
request to plot the requested plot type to the screen. If, in addition, the \
Filename parameter is specified, the plot is instead written to disk to the \
specified file name as an extended metafile. If the FileFormat parameter is \
also, the command is instead interpreted as a command to write the data to \
disk to the specfied file name, rather than display it to make a graphical \
plot. Valid entries for PlotType are: \n  0   V (Voltage) \n  1   |J| \
(Magnitude of current density) \n  2   J.n (Normal current density) \n  3   \
J.t (Tangential current density) \n  4   |E (Magnitude of field intensity) \n \
 5   E.n (Normal field intensity) \n  6   E.t (Tangential field intensity) \n \
 7   |Jc| (Magnitude of conduction current density) \n  8   Jc.n (Normal \
conduction current density) \n  9   Jc.t (Tangential conduction current \
density)} \n  10  |Jd| (Magnitude of displacement current density) \n  11  \
Jd.n (Normal displacement current density) \n  12  Jd.t (Tangential \
displacement current density)"\)], "Print",
  CellTags->"Info3347223943-5629661"],

Cell[BoxData[
    \("COGetConductorProperties[\"conductor\"] returns properties for the \
conductor property named \"conductor\". A list with two values is returned: \
The voltage of the specified conductor, and the total current from the \
specified conductor."\)], "Print",
  CellTags->"Info3347223943-4925532"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("COGetPointValues[x,y] returns the various field values associated with \
the point at {x,y}. The return values, in order, are:\n V   & Voltage \n Jx  \
& x- or r- direction component of current density \n Jy  & y- or z- direction \
component of current density \n Kx  & x- or r- direction component of AC \
conductivity \n Ky  & y- or z- direction component of AC conductivity \n Ex  \
& x- or r- direction component of electric field intensity \n Ey  & y- or z- \
direction component of electric field intensity \n ex  & x- or r- direction \
component of permittivity \n ey  & y- or z- direction component of \
permittivity \n Jdx & x- or r- direction component of displacement current \
density \n Jdy & y- or z- direction component of displacement current density \
\n ox  & x- or r- direction component of permittivity \n oy  & y- or z- \
direction component of permittivity \n Jcx & x- or r- direction component of \
conduction current density \n Jcy & y- or z- direction component of \
conduction current density \n An equivalent form is: \n \
COGetPointValues[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-5246270"],

Cell[BoxData[
    \("COGetV[x,y] returns the voltage at point {x,y}. An equivalent form is:\
\n COGetV[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-1445452"],

Cell[BoxData[
    \("COGetJ[x,y] returns a list with two elements containing the current \
density at point {x,y}.  An equivalent form is:\n COGetJ[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-4450436"],

Cell[BoxData[
    \("COGetK[x,y] returns a list with two elements containing the ac \
conductivity at point {x,y}.  An equivalent form is:\n COGetK[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223943-3881981"],

Cell[BoxData[
    \("COGetE[x,y] returns a list with two elements containing the  electric \
field intensity at point {x,y}. An equivalent form is:\n COGetE[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223943-7228078"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("COShowContourPlot[numcontours,lowerV,upperV] shows the V contour plot \
with options:\n numcontours - Number of equipotential lines to be plotted.\n \
upperV - Upper limit for contours.\n lowerV - Lower limit for contours.\n If \
numcontours is -1 all parameters are ignored and default values are used"\)], \
"Print",
  CellTags->"Info3347223943-4602624"],

Cell[BoxData[
    \("COHideContourPlot[] hides the currently displayed contour plot"\)], \
"Print",
  CellTags->"Info3347223943-8450963"],

Cell[BoxData[
    \("COShowDensityPlot[legend,gscale,upper,lower,type]\n Shows the flux \
density plot with options:\n legend - Set to 0 to hide the plot legend or 1 \
to show the plot legend.\n gscale - Set to 0 for a colour density plot or 1 \
for a grey scale density plot.\n upper - Sets the upper display limit for the \
density plot.\n lower - Sets the lower display limit for the density plot.\n \
type - Sets the type of density plot. Plot types include:\n 0  |V|\n 1  \
|Re(V)|   \n 2  |Im(V)|   \n 3  |J|       \n 4  |Re(J)|    \n 5  |Im(J)|    \n\
 6  |E|       \n 7  |Re(E)|    \n 8  |Im(E)|"\)], "Print",
  CellTags->"Info3347223943-6220742"],

Cell[BoxData[
    \("COHideDensityPlot[] hides the currently displayed density plot"\)], \
"Print",
  CellTags->"Info3347223943-7000860"],

Cell[BoxData[
    \("COSetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the type parameter is \
set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223943-5567665"],

Cell[BoxData[
    \("COShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223943-5586590"],

Cell[BoxData[
    \("COHideGrid[] hides the grid points from view in the current output \
window"\)], "Print",
  CellTags->"Info3347223943-2736516"],

Cell[BoxData[
    \("COShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223943-4561819"],

Cell[BoxData[
    \("COHideMesh[] hides the finite element mesh from in the current output \
view"\)], "Print",
  CellTags->"Info3347223943-9200808"],

Cell[BoxData[
    \("COShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223943-4835101"],

Cell[BoxData[
    \("COHideNames[] hides material names associated with block labels from \
view in the current output window"\)], "Print",
  CellTags->"Info3347223943-7355272"],

Cell[BoxData[
    \("COShowPoints[] displays the input node point as part of the output \
geometry"\)], "Print",
  CellTags->"Info3347223943-1181112"],

Cell[BoxData[
    \("COHidePoints[] inhibits the display of input node points in the \
current output window"\)], "Print",
  CellTags->"Info3347223943-2215272"],

Cell[BoxData[
    \("COSmoothOn[] turns on smoothing of the D and E fields.  The D and E \
fields are then displayed using a linear interpolation of the field from \
nodal values"\)], "Print",
  CellTags->"Info3347223943-1923535"],

Cell[BoxData[
    \("COSmoothOff[] turns off smoothing of the D and E fields.  The D and E \
fields are then displayed using values that are piecewise constant over each \
element."\)], "Print",
  CellTags->"Info3347223943-8093696"],

Cell[BoxData[
    \("COSnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223943-6910008"],

Cell[BoxData[
    \("COSnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223943-1493678"],

Cell[BoxData[
    \("COZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n COZoom[{x1,y1},{x2,y2}]\n \
COZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223943-3117515"],

Cell[BoxData[
    \("COZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223943-4832411"],

Cell[BoxData[
    \("COZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223943-8404433"],

Cell[BoxData[
    \("COZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223943-7328827"],

Cell[BoxData[
    \("CORefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223943-4746551"],

Cell[BoxData[
    \("COGetView[] grabs the current output view and returns a bitmapped \
graphics object.  This object can subsequently be displayed using the Show[] \
command"\)], "Print",
  CellTags->"Info3347223943-8409741"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("COClose[] close the current postprocessor document and window"\)], \
"Print",
  CellTags->"Info3347223943-8817053"],

Cell[BoxData[
    \("COGetProblemInfo[] returns a list with two values: the Problem Type (0 \
for planar and 1 for axisymmetric) and the depth assumed for planar problems \
in units of meters."\)], "Print",
  CellTags->"Info3347223943-3716282"],

Cell[BoxData[
    \("COReload[] reloads the current output file."\)], "Print",
  CellTags->"Info3347223943-8999170"],

Cell[BoxData[
    \("COSaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the CISaveAs command."\)], "Print",
  CellTags->"Info3347223943-5709094"],

Cell[BoxData[
    \("COSaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the CISaveAs command."\)], \
"Print",
  CellTags->"Info3347223943-3657880"],

Cell[BoxData[
    \("COSetEditMode[\"mode\"] sets the mode of the postprocessor to point, \
contour, or area mode. Valid entries for mode are \"point\", \"contour\", and \
\"area\"."\)], "Print",
  CellTags->"Info3347223943-6348310"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetics Output Commands", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MOAddContour[x,y] adds the point {x,y} to the contour that is used for \
plotting values along lines and for computinlocatedg line integrals.  An \
equivalent form is:\n MOAddContour[{x,y}]"\)], "Print",
  CellTags->"Info3347223943-5622619"],

Cell[BoxData[
    \("MOBendContour[angle,anglestep] replaces the straight line formed by \
the last two points in curvethe contour by an arc that spans angle degrees. \
The arc is actually composed of many straight lines, each of which is \
constrained to span no more than anglestep degrees. The angle parameter can \
take on values from -180 to 180 degrees. The anglestep parameter must be \
greater than zero. If there are less than two points defined in the contour, \
this command is ignored."\)], "Print",
  CellTags->"Info3347223943-3212639"],

Cell[BoxData[
    \("MOClearContour[] clears the current contour selection"\)], "Print",
  CellTags->"Info3347223944-7593278"],

Cell[BoxData[
    \("MOSelectBlock[x,y] select the block that contains point {x,y}.  An \
equivalent form is:\n MOSelectBlock[{x,y}]"\)], "Print",
  CellTags->"Info3347223944-1223543"],

Cell[BoxData[
    \("MOSelectPoint[x,y] adds a contour point at the closest input point to \
{x,y}. If the selected point and a previous selected points lie at the ends \
of an arcsegment, a contour is added that traces along the arcsegment. The \
selectpoint command has the same functionality as the left-button-click \
contour point selection when the program is running in interactive mode. An \
equivalent form is:\n MOSelectPoint[{x,y}]"\)], "Print",
  CellTags->"Info3347223944-6433330"],

Cell[BoxData[
    \("MOGroupSelectBlock[n] selects all of the blocks that are labeled by \
block labels that are members of group n. If no number is specified (i.e. \
MOGroupSelectBlock[]), all blocks are selected."\)], "Print",
  CellTags->"Info3347223944-8548286"],

Cell[BoxData[
    \("MOClearBlock[] clears the current block selection"\)], "Print",
  CellTags->"Info3347223944-5636726"],

Cell[BoxData[
    \("MOBlockIntegral[type] calculates a block integral over the selected \
blocks.  There is a single (possibly complex) return value. Valid type \
specifications are:\n 0 - A\[CenterDot]J \n 1 - A \n 2 - Magnetic field \
energy \n 3 - Hysteresis and/or lamination losses \n 4 - Resistive losses \n \
5 - Block cross-section area \n 6 - Total losses \n 7 - Total current \n 8 - \
Integral of Bx (or Br) over block \n 9 - Integral of By (or Bz) over block \n \
10 - Block volume \n 11 - x (or r) part of steady-state Lorentz force \n 12 - \
y (or z) part of steady-state Lorentz force \n 13 - x (or r) part of 2X \
Lorentz force \n 14 - y (or z) part of 2X Lorentz force \n 15 - Steady-state \
Lorentz torque \n 16 - 2X component of Lorentz torque \n 17 - Magnetic field \
coenergy \n 18 - x (or r) part of steady-state weighted stress tensor force \n\
 19 - y (or z) part of steady-state weighted stress tensor force \n 20 - x \
(or r) part of 2X weighted stress tensor force \n 21 - y (or z) part of 2X \
weighted stress tensor force \n 22 - Steady-state weighted stress tensor \
torque \n 23 - 2X component of weighted stress tensor torque \n 24 - R^2 \
(i.e. moment of inertia / density"\)], "Print",
  CellTags->"Info3347223944-6212195"],

Cell[BoxData[
    \("MOLineIntegral[type] calculates the line integral for the defined \
contour.  The following types of line integral and the return values are as \
follows:\n 0 - total B.n, average B.n over the contour \n 1 - total H.t, \
average H.t over the contour \n 2 - Contour length, surface area \n 3 - \
Stress Tensor Force: DC r/x force, DC y/z force, 2X r/x force, 2X y/z force\n \
4 - Stress Tensor Torque: DC torque, 2X torque \n 5 - total (B.n)^2, average \
(B.n)^2 \n Typically returns two (possibly complex) values as results. \
However, the Stress Tensor Force integral returns four values."\)], "Print",
  CellTags->"Info3347223944-2446185"],

Cell[BoxData[
    \("MOMakePlot[PlotType,NumPoints,Filename,FileFormat]\n This function \
allows programmatic access to FEMM's X-Y plot routines. If only PlotType or \
only PlotType and NumPoints are specified, the command is interpreted as a \
request to plot the requested plot type to the screen. If, in addition, the \
Filename parameter is specified, the plot is instead written to disk to the \
specified file name as an extended metafile. If the FileFormat parameter is \
also, the command is instead interpreted as a command to write the data to \
disk to the specfied file name, rather than display it to make a graphical \
plot. Valid entries for PlotType are: \n 0 - Potential \n 1 - |B| \n 2 B\
\[CenterDot]n \n 3 - B\[CenterDot]t \n 4 - |H| \n 5 - H \[CenterDot]n \n 6 - \
H \[CenterDot]t \n 7 - Jeddy \n 8 - Jsource+Jeddy"\)], "Print",
  CellTags->"Info3347223944-4819550"],

Cell[BoxData[
    \("MOGetCircuitProperties[\"circuit\"] is used primarily to obtain \
impedance information associated with circuit properties. Properties are \
returned for the circuit property named \"circuit\". A list of three values \
is returned by the function. In order, the elements of this list are:\n \
current -  the current carried by the circuit.\n volts - the voltage drop \
across the circuit in the circuit.\n flux - the circuit\[CloseCurlyQuote]s \
flux linkage\n Any of these entries could possibly be complex-valued."\)], \
"Print",
  CellTags->"Info3347223944-6414604"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MOGetPointValues[x,y] get the field values at {x,y}.  The function \
returns a list of values which represent:\n A - vector potential A, \
flux=2*Pi*r*A if axisymmetric\n B1 - Bx if planar, Br if axisymmetric\n B2 - \
By if planar, Bz if axisymmetric\n Sig - conductivity\n E - stored energy \
density\n H1 - Hx if planar, Hr if axisymmetric\n H2 - Hy if planar, Hz if \
axisymmetric\n Je - Eddy current contribution to current density\n Js - \
Source current contribution to current density\n Mu1 - mux if planar, mur if \
axisymmetric\n Mu2 - muy if planar, muz if axisymmetric\n Pe - Power density \
dissipated through ohmic losses\n Ph - Power density dissipated by hysteresis\
\n ff - Winding fill factor"\)], "Print",
  CellTags->"Info3347223944-6619072"],

Cell[BoxData[
    \("MOGetA[x,y] returns the vector potential, A, for 2D planar problems, \
and it returns flux, 2*Pi*r*A, for axisymmetric problems.  The return value \
is possbly complex-valued. An equivalent form is:\n MOGetA[{x,y}]"\)], "Print",\

  CellTags->"Info3347223944-4082389"],

Cell[BoxData[
    \("MOGetB[x,y] returns a list with two elements containing the magnetic \
flux density at point {x,y}.  An equivalent form is:\n MOGetB[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223944-3243349"],

Cell[BoxData[
    \("MOGetH[x,y] returns a list with two elements containing the magnetic \
field intensity at point {x,y}.  An equivalent form is:\n MOGetB[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223944-9833440"],

Cell[BoxData[
    \("MOGetJ[x,y] returns the electric current density at point {x,y}. An \
equivalent form is:\n MOGetJ[{x,y}]"\)], "Print",
  CellTags->"Info3347223944-9033299"],

Cell[BoxData[
    \("MOGetMu[x,y] returns a list with two elements containing the magnetic \
permeability at point {x,y}.  An equivalent form is:\n MOGetMu[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223944-7106424"],

Cell[BoxData[
    \("MOGetPe[x,y] returns the electrical (ohmic) loss density at point \
{x,y}. An equivalent form is:\n MOGetMu[{x,y}]"\)], "Print",
  CellTags->"Info3347223944-2091162"],

Cell[BoxData[
    \("MOGetPh[x,y] returns the hysteresis and/or laminated eddy current loss \
density at point {x,y}. An equivalent form is:\n MOGetPh[{x,y}]"\)], "Print",
  CellTags->"Info3347223944-1590385"],

Cell[BoxData[
    \("MOGetConductivity[x,y] returns the electrical conductivity at point \
{x,y}. An equivalent form is:\n MOGetConductivity[{x,y}]"\)], "Print",
  CellTags->"Info3347223944-5449929"],

Cell[BoxData[
    \("MOGetEnergyDensity[x,y] returns the energy density in the magnetic \
field at point {x,y}. An equivalent form is:\n MOGetEnergyDensity[{x,y}]"\)], \
"Print",
  CellTags->"Info3347223944-5484391"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MOShowContourPlot[numcontours,lowerA,upperA,type] shows the A contour \
plot with options:\n numcontours - Number of A equipotential lines to be \
plotted. \n upperA - Upper limit for A contours. \n lowerA - Lower limit for \
A contours. \n type - Choice of \"real\", \"imag\", or \"both\" to show \
either the real, imaginary of both real and imaginary components of A.\n If \
numcontours is -1, all parameters are ignored and default values are \
used"\)], "Print",
  CellTags->"Info3347223944-8026549"],

Cell[BoxData[
    \("MOHideContourPlot[] hides the currently displayed contour plot"\)], \
"Print",
  CellTags->"Info3347223944-6509291"],

Cell[BoxData[
    \("MOShowDensityPlot[legend,gscale,upperB,lowerB,type]\n shows the flux \
density plot with the options: \n legend - Set to 0 to hide the plot legend \
or 1 to show the plot legend.\n gscale - Set to 0 for a colour density plot \
or 1 for a grey scaledensity plot.\n upperB - Sets the upper display limit \
for the density plot.\n lowerB - Sets the lower display limit for the density \
plot.\n type - Type of density plot to display. Valid entries are \"mag\", \
\"real\", and \"imag\" for magnitude, real component, and imaginary component \
of B, respectively. Alternatively, current density can be displayed by \
specifying \"jmag\", \"jreal\", and \"jimag\" for magnitude, real component, \
and imaginary component of J, respectively.\n If legend is set to -1 all \
parameters are ignored and default values are used"\)], "Print",
  CellTags->"Info3347223944-9854803"],

Cell[BoxData[
    \("MOHideDensityPlot[] hides the currently displayed density plot"\)], \
"Print",
  CellTags->"Info3347223944-4587203"],

Cell[BoxData[
    \("MOSetGrid[density,\"type\"] changes the grid spacing. The density \
parameter specifies the space between grid points, and the type parameter is \
set to \"cart\" for Cartesian coordinates or \"polar\" for polar \
coordinates."\)], "Print",
  CellTags->"Info3347223944-6627152"],

Cell[BoxData[
    \("MOShowGrid[] displays the grid points"\)], "Print",
  CellTags->"Info3347223944-9677027"],

Cell[BoxData[
    \("MOHideGrid[] hides the grid points from view in the electrostatics \
output window"\)], "Print",
  CellTags->"Info3347223944-7882672"],

Cell[BoxData[
    \("MOShowMesh[] displays the mesh"\)], "Print",
  CellTags->"Info3347223944-5172316"],

Cell[BoxData[
    \("MOHideMesh[] hides the finite element mesh from in the electrostatics \
output view"\)], "Print",
  CellTags->"Info3347223944-1205732"],

Cell[BoxData[
    \("MOShowNames[] displays the material names associated with each block \
label"\)], "Print",
  CellTags->"Info3347223944-8443384"],

Cell[BoxData[
    \("MOHideNames[] hides material names associated with block labels from \
view in the electrostatics output window"\)], "Print",
  CellTags->"Info3347223944-8424884"],

Cell[BoxData[
    \("MOShowPoints[] displays the input node point as part of the output \
geometry"\)], "Print",
  CellTags->"Info3347223944-9112071"],

Cell[BoxData[
    \("MOHidePoints[] inhibits the display of input node points in the \
electrostatics output window"\)], "Print",
  CellTags->"Info3347223944-5725100"],

Cell[BoxData[
    \("MOSmoothOn[] turns on smoothing of the D and E fields.  The D and E \
fields are then displayed using a linear interpolation of the field from \
nodal values"\)], "Print",
  CellTags->"Info3347223944-3763668"],

Cell[BoxData[
    \("MOSmoothOff[] turns off smoothing of the D and E fields.  The D and E \
fields are then displayed using values that are piecewise constant over each \
element."\)], "Print",
  CellTags->"Info3347223944-5023528"],

Cell[BoxData[
    \("MOSnapGridOn[] turns on snap-to-grid"\)], "Print",
  CellTags->"Info3347223944-6332496"],

Cell[BoxData[
    \("MOSnapGridOff[] turns off snap-to-grid"\)], "Print",
  CellTags->"Info3347223944-1601766"],

Cell[BoxData[
    \("MOZoom[x1,y1,x2,y2] Set the display area to be from the bottom left \
corner specified by {x1,y1} to the top right corner specified by {x2,y2}. \
Equivalent forms are:\n MOZoom[{x1,y1},{x2,y2}]\n \
MOZoom[{{x1,y1},{x2,y2}}]"\)], "Print",
  CellTags->"Info3347223944-9984544"],

Cell[BoxData[
    \("MOZoomIn[] zooms out by a factor of 200%."\)], "Print",
  CellTags->"Info3347223944-8912656"],

Cell[BoxData[
    \("MOZoomNatural[] zooms to a \"natural\" view with sensible \
extents."\)], "Print",
  CellTags->"Info3347223944-6144805"],

Cell[BoxData[
    \("MOZoomOut[] zooms out by a factor of 50%."\)], "Print",
  CellTags->"Info3347223944-4339604"],

Cell[BoxData[
    \("MORefreshView[] Redraws the current view."\)], "Print",
  CellTags->"Info3347223944-7164196"],

Cell[BoxData[
    \("MOGetView[] grabs the current electrostatics output view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command"\)], "Print",
  CellTags->"Info3347223944-7748027"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \("MOClose[] close the current postprocessor document and window"\)], \
"Print",
  CellTags->"Info3347223944-7495296"],

Cell[BoxData[
    \("MOGetProblemInfo[] returns a list of two values: the problem type (0 \
for planar, 1 for axisymmetric) and the analysis frequency in Hz."\)], "Print",\

  CellTags->"Info3347223944-8982714"],

Cell[BoxData[
    \("MOReload[] reloads the current electrostatics output file."\)], "Print",\

  CellTags->"Info3347223944-8993898"],

Cell[BoxData[
    \("MOSaveBitmap[\"filename\"] saves a bitmapped screenshot of the current \
view to the file specified by \"filename\", subject to the printf-type \
formatting explained previously for the EISaveAs command."\)], "Print",
  CellTags->"Info3347223944-1732994"],

Cell[BoxData[
    \("MOSaveMetafile[\"filename\"] saves an extended metafile screenshot of \
the current view to the file specified by \"filename\", subject to the \
printf-type formatting explained previously for the EISaveAs command."\)], \
"Print",
  CellTags->"Info3347223944-1385772"],

Cell[BoxData[
    \("MOSetEditMode[\"mode\"] sets the mode of the postprocessor to point, \
contour, or area mode. Valid entries for mode are \"point\", \"contour\", and \
\"area\"."\)], "Print",
  CellTags->"Info3347223944-8600115"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{727, 741},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3347223940-6631621"->{
    Cell[3834, 102, 172, 3, 44, "Print",
      CellTags->"Info3347223940-6631621"]},
  "Info3347223940-4294206"->{
    Cell[4009, 107, 174, 3, 44, "Print",
      CellTags->"Info3347223940-4294206"]},
  "Info3347223940-6810511"->{
    Cell[4186, 112, 359, 5, 82, "Print",
      CellTags->"Info3347223940-6810511"]},
  "Info3347223940-7389295"->{
    Cell[4548, 119, 145, 3, 25, "Print",
      CellTags->"Info3347223940-7389295"]},
  "Info3347223940-2382490"->{
    Cell[4696, 124, 126, 2, 25, "Print",
      CellTags->"Info3347223940-2382490"]},
  "Info3347223940-6023529"->{
    Cell[4825, 128, 135, 3, 25, "Print",
      CellTags->"Info3347223940-6023529"]},
  "Info3347223940-6503571"->{
    Cell[4963, 133, 116, 2, 25, "Print",
      CellTags->"Info3347223940-6503571"]},
  "Info3347223940-5379615"->{
    Cell[5082, 137, 123, 2, 25, "Print",
      CellTags->"Info3347223940-5379615"]},
  "Info3347223940-1834069"->{
    Cell[5208, 141, 154, 3, 25, "Print",
      CellTags->"Info3347223940-1834069"]},
  "Info3347223940-7924268"->{
    Cell[5365, 146, 249, 4, 44, "Print",
      CellTags->"Info3347223940-7924268"]},
  "Info3347223940-7939632"->{
    Cell[5617, 152, 148, 3, 25, "Print",
      CellTags->"Info3347223940-7939632"]},
  "Info3347223940-6833855"->{
    Cell[5768, 157, 275, 4, 63, "Print",
      CellTags->"Info3347223940-6833855"]},
  "Info3347223940-1189387"->{
    Cell[6046, 163, 143, 3, 25, "Print",
      CellTags->"Info3347223940-1189387"]},
  "Info3347223940-1293541"->{
    Cell[6192, 168, 67, 1, 25, "Print",
      CellTags->"Info3347223940-1293541"],
    Cell[6262, 171, 568, 15, 25, "Print",
      CellTags->"Info3347223940-1293541"]},
  "Info3347223940-8692552"->{
    Cell[7101, 201, 786, 11, 234, "Print",
      CellTags->"Info3347223940-8692552"]},
  "Info3347223940-9972450"->{
    Cell[7890, 214, 377, 6, 82, "Print",
      CellTags->"Info3347223940-9972450"]},
  "Info3347223940-4605738"->{
    Cell[8270, 222, 349, 5, 101, "Print",
      CellTags->"Info3347223940-4605738"]},
  "Info3347223940-4732625"->{
    Cell[8622, 229, 248, 4, 63, "Print",
      CellTags->"Info3347223940-4732625"]},
  "Info3347223940-4167237"->{
    Cell[8873, 235, 732, 10, 215, "Print",
      CellTags->"Info3347223940-4167237"]},
  "Info3347223940-9087758"->{
    Cell[9608, 247, 643, 9, 177, "Print",
      CellTags->"Info3347223940-9087758"]},
  "Info3347223940-5926772"->{
    Cell[10254, 258, 697, 10, 158, "Print",
      CellTags->"Info3347223940-5926772"]},
  "Info3347223940-8501482"->{
    Cell[10954, 270, 553, 8, 139, "Print",
      CellTags->"Info3347223940-8501482"]},
  "Info3347223940-7144037"->{
    Cell[11510, 280, 166, 3, 25, "Print",
      CellTags->"Info3347223940-7144037"]},
  "Info3347223940-2011507"->{
    Cell[11679, 285, 167, 3, 44, "Print",
      CellTags->"Info3347223940-2011507"]},
  "Info3347223940-6339513"->{
    Cell[11849, 290, 163, 3, 25, "Print",
      CellTags->"Info3347223940-6339513"]},
  "Info3347223940-5174597"->{
    Cell[12015, 295, 163, 3, 25, "Print",
      CellTags->"Info3347223940-5174597"]},
  "Info3347223940-1062849"->{
    Cell[12313, 307, 558, 8, 139, "Print",
      CellTags->"Info3347223940-1062849"]},
  "Info3347223940-3542961"->{
    Cell[12874, 317, 183, 3, 44, "Print",
      CellTags->"Info3347223940-3542961"]},
  "Info3347223940-1600426"->{
    Cell[13060, 322, 157, 3, 44, "Print",
      CellTags->"Info3347223940-1600426"]},
  "Info3347223940-4337716"->{
    Cell[13220, 327, 271, 4, 82, "Print",
      CellTags->"Info3347223940-4337716"]},
  "Info3347223941-1813366"->{
    Cell[13494, 333, 583, 9, 158, "Print",
      CellTags->"Info3347223941-1813366"]},
  "Info3347223941-1118594"->{
    Cell[14080, 344, 273, 4, 82, "Print",
      CellTags->"Info3347223941-1118594"]},
  "Info3347223941-5737972"->{
    Cell[14356, 350, 212, 4, 44, "Print",
      CellTags->"Info3347223941-5737972"]},
  "Info3347223941-7410441"->{
    Cell[14571, 356, 236, 4, 44, "Print",
      CellTags->"Info3347223941-7410441"]},
  "Info3347223941-8640170"->{
    Cell[14810, 362, 289, 5, 82, "Print",
      CellTags->"Info3347223941-8640170"]},
  "Info3347223941-1951187"->{
    Cell[15102, 369, 203, 3, 44, "Print",
      CellTags->"Info3347223941-1951187"]},
  "Info3347223941-8197922"->{
    Cell[15450, 381, 192, 3, 63, "Print",
      CellTags->"Info3347223941-8197922"]},
  "Info3347223941-2611265"->{
    Cell[15645, 386, 261, 4, 63, "Print",
      CellTags->"Info3347223941-2611265"]},
  "Info3347223941-9442840"->{
    Cell[15909, 392, 182, 3, 44, "Print",
      CellTags->"Info3347223941-9442840"]},
  "Info3347223941-7245219"->{
    Cell[16094, 397, 173, 3, 44, "Print",
      CellTags->"Info3347223941-7245219"]},
  "Info3347223941-5798128"->{
    Cell[16270, 402, 182, 3, 44, "Print",
      CellTags->"Info3347223941-5798128"]},
  "Info3347223941-1459018"->{
    Cell[16455, 407, 805, 11, 215, "Print",
      CellTags->"Info3347223941-1459018"]},
  "Info3347223941-1589458"->{
    Cell[17263, 420, 485, 7, 139, "Print",
      CellTags->"Info3347223941-1589458"]},
  "Info3347223941-8534708"->{
    Cell[17751, 429, 403, 6, 82, "Print",
      CellTags->"Info3347223941-8534708"]},
  "Info3347223941-7553760"->{
    Cell[18157, 437, 716, 10, 196, "Print",
      CellTags->"Info3347223941-7553760"]},
  "Info3347223941-9188284"->{
    Cell[18876, 449, 121, 2, 25, "Print",
      CellTags->"Info3347223941-9188284"]},
  "Info3347223941-7542695"->{
    Cell[19000, 453, 139, 3, 25, "Print",
      CellTags->"Info3347223941-7542695"]},
  "Info3347223941-2715154"->{
    Cell[19142, 458, 134, 3, 25, "Print",
      CellTags->"Info3347223941-2715154"]},
  "Info3347223941-2795720"->{
    Cell[19279, 463, 124, 2, 25, "Print",
      CellTags->"Info3347223941-2795720"]},
  "Info3347223941-9823357"->{
    Cell[19406, 467, 132, 3, 25, "Print",
      CellTags->"Info3347223941-9823357"]},
  "Info3347223941-8020983"->{
    Cell[19541, 472, 153, 3, 25, "Print",
      CellTags->"Info3347223941-8020983"]},
  "Info3347223941-4999920"->{
    Cell[19697, 477, 666, 9, 158, "Print",
      CellTags->"Info3347223941-4999920"]},
  "Info3347223941-6637905"->{
    Cell[20366, 488, 244, 4, 44, "Print",
      CellTags->"Info3347223941-6637905"]},
  "Info3347223941-9601905"->{
    Cell[20613, 494, 248, 4, 63, "Print",
      CellTags->"Info3347223941-9601905"]},
  "Info3347223941-1464798"->{
    Cell[20990, 507, 494, 7, 158, "Print",
      CellTags->"Info3347223941-1464798"]},
  "Info3347223941-1770110"->{
    Cell[21487, 516, 442, 7, 139, "Print",
      CellTags->"Info3347223941-1770110"]},
  "Info3347223941-2471642"->{
    Cell[21932, 525, 437, 7, 120, "Print",
      CellTags->"Info3347223941-2471642"]},
  "Info3347223941-7586356"->{
    Cell[22372, 534, 437, 7, 139, "Print",
      CellTags->"Info3347223941-7586356"]},
  "Info3347223941-4155620"->{
    Cell[22812, 543, 362, 5, 120, "Print",
      CellTags->"Info3347223941-4155620"]},
  "Info3347223941-3197855"->{
    Cell[23177, 550, 431, 6, 120, "Print",
      CellTags->"Info3347223941-3197855"]},
  "Info3347223941-8920274"->{
    Cell[23737, 565, 303, 5, 63, "Print",
      CellTags->"Info3347223941-8920274"]},
  "Info3347223941-2580618"->{
    Cell[24043, 572, 110, 2, 25, "Print",
      CellTags->"Info3347223941-2580618"]},
  "Info3347223941-5009207"->{
    Cell[24156, 576, 128, 2, 25, "Print",
      CellTags->"Info3347223941-5009207"]},
  "Info3347223941-1486463"->{
    Cell[24287, 580, 103, 2, 25, "Print",
      CellTags->"Info3347223941-1486463"]},
  "Info3347223941-2487122"->{
    Cell[24393, 584, 139, 3, 25, "Print",
      CellTags->"Info3347223941-2487122"]},
  "Info3347223941-6450972"->{
    Cell[24535, 589, 149, 3, 25, "Print",
      CellTags->"Info3347223941-6450972"]},
  "Info3347223941-4162216"->{
    Cell[24687, 594, 175, 3, 44, "Print",
      CellTags->"Info3347223941-4162216"]},
  "Info3347223941-6354640"->{
    Cell[24865, 599, 109, 2, 25, "Print",
      CellTags->"Info3347223941-6354640"]},
  "Info3347223941-5746827"->{
    Cell[24977, 603, 111, 2, 25, "Print",
      CellTags->"Info3347223941-5746827"]},
  "Info3347223941-2691935"->{
    Cell[25091, 607, 296, 5, 82, "Print",
      CellTags->"Info3347223941-2691935"]},
  "Info3347223941-7877067"->{
    Cell[25390, 614, 114, 2, 25, "Print",
      CellTags->"Info3347223941-7877067"]},
  "Info3347223941-7749989"->{
    Cell[25507, 618, 141, 3, 25, "Print",
      CellTags->"Info3347223941-7749989"]},
  "Info3347223941-3231106"->{
    Cell[25651, 623, 114, 2, 25, "Print",
      CellTags->"Info3347223941-3231106"]},
  "Info3347223941-3377092"->{
    Cell[25768, 627, 241, 4, 44, "Print",
      CellTags->"Info3347223941-3377092"]},
  "Info3347223941-4876077"->{
    Cell[26137, 640, 370, 6, 101, "Print",
      CellTags->"Info3347223941-4876077"]},
  "Info3347223941-3439479"->{
    Cell[26510, 648, 150, 3, 25, "Print",
      CellTags->"Info3347223941-3439479"]},
  "Info3347223941-7653090"->{
    Cell[26663, 653, 275, 4, 63, "Print",
      CellTags->"Info3347223941-7653090"]},
  "Info3347223941-7874582"->{
    Cell[26941, 659, 162, 3, 25, "Print",
      CellTags->"Info3347223941-7874582"]},
  "Info3347223941-5235115"->{
    Cell[27106, 664, 1033, 14, 234, "Print",
      CellTags->"Info3347223941-5235115"]},
  "Info3347223941-7704576"->{
    Cell[28142, 680, 165, 3, 25, "Print",
      CellTags->"Info3347223941-7704576"]},
  "Info3347223941-4043808"->{
    Cell[28310, 685, 114, 2, 25, "Print",
      CellTags->"Info3347223941-4043808"]},
  "Info3347223941-3418109"->{
    Cell[28427, 689, 228, 4, 44, "Print",
      CellTags->"Info3347223941-3418109"]},
  "Info3347223941-6580237"->{
    Cell[28658, 695, 276, 4, 63, "Print",
      CellTags->"Info3347223941-6580237"]},
  "Info3347223941-6852624"->{
    Cell[28937, 701, 289, 5, 63, "Print",
      CellTags->"Info3347223941-6852624"]},
  "Info3347223941-1422078"->{
    Cell[29229, 708, 414, 6, 158, "Print",
      CellTags->"Info3347223941-1422078"]},
  "Info3347223941-2029304"->{
    Cell[29646, 716, 500, 7, 101, "Print",
      CellTags->"Info3347223941-2029304"]},
  "Info3347223941-8989917"->{
    Cell[30424, 739, 1018, 14, 272, "Print",
      CellTags->"Info3347223941-8989917"]},
  "Info3347223941-3552733"->{
    Cell[31445, 755, 388, 6, 82, "Print",
      CellTags->"Info3347223941-3552733"]},
  "Info3347223941-6176457"->{
    Cell[31836, 763, 358, 6, 101, "Print",
      CellTags->"Info3347223941-6176457"]},
  "Info3347223941-8109493"->{
    Cell[32197, 771, 252, 4, 63, "Print",
      CellTags->"Info3347223941-8109493"]},
  "Info3347223941-6089851"->{
    Cell[32452, 777, 793, 11, 253, "Print",
      CellTags->"Info3347223941-6089851"]},
  "Info3347223941-7134049"->{
    Cell[33248, 790, 659, 10, 177, "Print",
      CellTags->"Info3347223941-7134049"]},
  "Info3347223941-7244468"->{
    Cell[33910, 802, 704, 10, 177, "Print",
      CellTags->"Info3347223941-7244468"]},
  "Info3347223941-4415755"->{
    Cell[34617, 814, 558, 8, 158, "Print",
      CellTags->"Info3347223941-4415755"]},
  "Info3347223941-9094170"->{
    Cell[35178, 824, 166, 3, 25, "Print",
      CellTags->"Info3347223941-9094170"]},
  "Info3347223941-3611725"->{
    Cell[35347, 829, 167, 3, 44, "Print",
      CellTags->"Info3347223941-3611725"]},
  "Info3347223941-9967462"->{
    Cell[35517, 834, 163, 3, 25, "Print",
      CellTags->"Info3347223941-9967462"]},
  "Info3347223941-4309295"->{
    Cell[35683, 839, 163, 3, 25, "Print",
      CellTags->"Info3347223941-4309295"]},
  "Info3347223941-8260624"->{
    Cell[35981, 851, 558, 8, 139, "Print",
      CellTags->"Info3347223941-8260624"]},
  "Info3347223941-8492284"->{
    Cell[36542, 861, 183, 3, 44, "Print",
      CellTags->"Info3347223941-8492284"]},
  "Info3347223941-8438704"->{
    Cell[36728, 866, 157, 3, 44, "Print",
      CellTags->"Info3347223941-8438704"]},
  "Info3347223941-3285558"->{
    Cell[36888, 871, 271, 4, 82, "Print",
      CellTags->"Info3347223941-3285558"]},
  "Info3347223941-1354509"->{
    Cell[37162, 877, 576, 8, 139, "Print",
      CellTags->"Info3347223941-1354509"]},
  "Info3347223941-1355904"->{
    Cell[37741, 887, 273, 4, 82, "Print",
      CellTags->"Info3347223941-1355904"]},
  "Info3347223941-8370622"->{
    Cell[38017, 893, 212, 4, 44, "Print",
      CellTags->"Info3347223941-8370622"]},
  "Info3347223941-2291614"->{
    Cell[38232, 899, 236, 4, 44, "Print",
      CellTags->"Info3347223941-2291614"]},
  "Info3347223941-7771765"->{
    Cell[38471, 905, 289, 5, 82, "Print",
      CellTags->"Info3347223941-7771765"]},
  "Info3347223941-7568170"->{
    Cell[38763, 912, 203, 3, 44, "Print",
      CellTags->"Info3347223941-7568170"]},
  "Info3347223941-5343679"->{
    Cell[39111, 924, 192, 3, 63, "Print",
      CellTags->"Info3347223941-5343679"]},
  "Info3347223941-5864838"->{
    Cell[39306, 929, 261, 4, 63, "Print",
      CellTags->"Info3347223941-5864838"]},
  "Info3347223941-7809650"->{
    Cell[39570, 935, 182, 3, 44, "Print",
      CellTags->"Info3347223941-7809650"]},
  "Info3347223941-2458221"->{
    Cell[39755, 940, 173, 3, 44, "Print",
      CellTags->"Info3347223941-2458221"]},
  "Info3347223941-1974298"->{
    Cell[39931, 945, 182, 3, 44, "Print",
      CellTags->"Info3347223941-1974298"]},
  "Info3347223941-7595909"->{
    Cell[40116, 950, 805, 11, 215, "Print",
      CellTags->"Info3347223941-7595909"]},
  "Info3347223941-2077596"->{
    Cell[40924, 963, 485, 7, 139, "Print",
      CellTags->"Info3347223941-2077596"]},
  "Info3347223941-6833115"->{
    Cell[41412, 972, 403, 6, 82, "Print",
      CellTags->"Info3347223941-6833115"]},
  "Info3347223941-8415350"->{
    Cell[41818, 980, 716, 10, 196, "Print",
      CellTags->"Info3347223941-8415350"]},
  "Info3347223941-7920837"->{
    Cell[42537, 992, 121, 2, 25, "Print",
      CellTags->"Info3347223941-7920837"]},
  "Info3347223941-5070483"->{
    Cell[42661, 996, 139, 3, 25, "Print",
      CellTags->"Info3347223941-5070483"]},
  "Info3347223941-1032206"->{
    Cell[42803, 1001, 134, 3, 25, "Print",
      CellTags->"Info3347223941-1032206"]},
  "Info3347223941-1376349"->{
    Cell[42940, 1006, 124, 2, 25, "Print",
      CellTags->"Info3347223941-1376349"]},
  "Info3347223941-7407861"->{
    Cell[43067, 1010, 132, 3, 25, "Print",
      CellTags->"Info3347223941-7407861"]},
  "Info3347223941-2948475"->{
    Cell[43202, 1015, 153, 3, 25, "Print",
      CellTags->"Info3347223941-2948475"]},
  "Info3347223941-8742318"->{
    Cell[43358, 1020, 666, 9, 158, "Print",
      CellTags->"Info3347223941-8742318"]},
  "Info3347223941-9656730"->{
    Cell[44027, 1031, 244, 4, 44, "Print",
      CellTags->"Info3347223941-9656730"]},
  "Info3347223941-1145073"->{
    Cell[44274, 1037, 248, 4, 63, "Print",
      CellTags->"Info3347223941-1145073"]},
  "Info3347223941-4193583"->{
    Cell[44651, 1050, 494, 7, 158, "Print",
      CellTags->"Info3347223941-4193583"]},
  "Info3347223941-6993551"->{
    Cell[45148, 1059, 442, 7, 139, "Print",
      CellTags->"Info3347223941-6993551"]},
  "Info3347223941-6453383"->{
    Cell[45593, 1068, 437, 7, 120, "Print",
      CellTags->"Info3347223941-6453383"]},
  "Info3347223941-7559587"->{
    Cell[46033, 1077, 437, 7, 139, "Print",
      CellTags->"Info3347223941-7559587"]},
  "Info3347223941-5358822"->{
    Cell[46473, 1086, 362, 5, 120, "Print",
      CellTags->"Info3347223941-5358822"]},
  "Info3347223941-6682568"->{
    Cell[46838, 1093, 431, 6, 120, "Print",
      CellTags->"Info3347223941-6682568"]},
  "Info3347223941-3512651"->{
    Cell[47398, 1108, 303, 5, 63, "Print",
      CellTags->"Info3347223941-3512651"]},
  "Info3347223941-8850662"->{
    Cell[47704, 1115, 110, 2, 25, "Print",
      CellTags->"Info3347223941-8850662"]},
  "Info3347223941-7730051"->{
    Cell[47817, 1119, 123, 2, 25, "Print",
      CellTags->"Info3347223941-7730051"]},
  "Info3347223941-2942451"->{
    Cell[47943, 1123, 103, 2, 25, "Print",
      CellTags->"Info3347223941-2942451"]},
  "Info3347223941-3089129"->{
    Cell[48049, 1127, 139, 3, 25, "Print",
      CellTags->"Info3347223941-3089129"]},
  "Info3347223941-3186031"->{
    Cell[48191, 1132, 149, 3, 25, "Print",
      CellTags->"Info3347223941-3186031"]},
  "Info3347223941-4802215"->{
    Cell[48343, 1137, 175, 3, 44, "Print",
      CellTags->"Info3347223941-4802215"]},
  "Info3347223941-8163804"->{
    Cell[48521, 1142, 109, 2, 25, "Print",
      CellTags->"Info3347223941-8163804"]},
  "Info3347223941-6931229"->{
    Cell[48633, 1146, 111, 2, 25, "Print",
      CellTags->"Info3347223941-6931229"]},
  "Info3347223941-9964984"->{
    Cell[48747, 1150, 296, 5, 82, "Print",
      CellTags->"Info3347223941-9964984"]},
  "Info3347223941-4270299"->{
    Cell[49046, 1157, 114, 2, 25, "Print",
      CellTags->"Info3347223941-4270299"]},
  "Info3347223941-7308454"->{
    Cell[49163, 1161, 141, 3, 25, "Print",
      CellTags->"Info3347223941-7308454"]},
  "Info3347223941-7750860"->{
    Cell[49307, 1166, 114, 2, 25, "Print",
      CellTags->"Info3347223941-7750860"]},
  "Info3347223941-3895549"->{
    Cell[49424, 1170, 236, 4, 44, "Print",
      CellTags->"Info3347223941-3895549"]},
  "Info3347223941-4236356"->{
    Cell[49788, 1183, 365, 6, 101, "Print",
      CellTags->"Info3347223941-4236356"]},
  "Info3347223941-2245144"->{
    Cell[50156, 1191, 150, 3, 25, "Print",
      CellTags->"Info3347223941-2245144"]},
  "Info3347223941-8159017"->{
    Cell[50309, 1196, 275, 4, 63, "Print",
      CellTags->"Info3347223941-8159017"]},
  "Info3347223941-8125029"->{
    Cell[50587, 1202, 162, 3, 25, "Print",
      CellTags->"Info3347223941-8125029"]},
  "Info3347223941-5725470"->{
    Cell[50752, 1207, 1033, 14, 234, "Print",
      CellTags->"Info3347223941-5725470"]},
  "Info3347223941-8114379"->{
    Cell[51788, 1223, 165, 3, 25, "Print",
      CellTags->"Info3347223941-8114379"]},
  "Info3347223941-7760450"->{
    Cell[51956, 1228, 114, 2, 25, "Print",
      CellTags->"Info3347223941-7760450"]},
  "Info3347223941-7609199"->{
    Cell[52073, 1232, 228, 4, 44, "Print",
      CellTags->"Info3347223941-7609199"]},
  "Info3347223941-8492301"->{
    Cell[52304, 1238, 276, 4, 63, "Print",
      CellTags->"Info3347223941-8492301"]},
  "Info3347223941-8350572"->{
    Cell[52583, 1244, 289, 5, 63, "Print",
      CellTags->"Info3347223941-8350572"]},
  "Info3347223941-7702967"->{
    Cell[52875, 1251, 414, 6, 158, "Print",
      CellTags->"Info3347223941-7702967"]},
  "Info3347223941-7628927"->{
    Cell[53292, 1259, 490, 7, 101, "Print",
      CellTags->"Info3347223941-7628927"]},
  "Info3347223941-2550021"->{
    Cell[54065, 1282, 799, 11, 234, "Print",
      CellTags->"Info3347223941-2550021"]},
  "Info3347223941-9246453"->{
    Cell[54867, 1295, 378, 6, 82, "Print",
      CellTags->"Info3347223941-9246453"]},
  "Info3347223941-6719514"->{
    Cell[55248, 1303, 565, 8, 158, "Print",
      CellTags->"Info3347223941-6719514"]},
  "Info3347223941-3075263"->{
    Cell[55816, 1313, 248, 4, 63, "Print",
      CellTags->"Info3347223941-3075263"]},
  "Info3347223941-1794145"->{
    Cell[56067, 1319, 745, 10, 234, "Print",
      CellTags->"Info3347223941-1794145"]},
  "Info3347223941-2809827"->{
    Cell[56815, 1331, 645, 9, 177, "Print",
      CellTags->"Info3347223941-2809827"]},
  "Info3347223941-3602638"->{
    Cell[57463, 1342, 922, 13, 253, "Print",
      CellTags->"Info3347223941-3602638"]},
  "Info3347223941-4062804"->{
    Cell[58388, 1357, 546, 8, 158, "Print",
      CellTags->"Info3347223941-4062804"]},
  "Info3347223941-8484718"->{
    Cell[58937, 1367, 166, 3, 25, "Print",
      CellTags->"Info3347223941-8484718"]},
  "Info3347223941-8368394"->{
    Cell[59106, 1372, 167, 3, 44, "Print",
      CellTags->"Info3347223941-8368394"]},
  "Info3347223941-5771336"->{
    Cell[59276, 1377, 163, 3, 25, "Print",
      CellTags->"Info3347223941-5771336"]},
  "Info3347223941-5718574"->{
    Cell[59442, 1382, 163, 3, 25, "Print",
      CellTags->"Info3347223941-5718574"]},
  "Info3347223941-9029670"->{
    Cell[59740, 1394, 558, 8, 139, "Print",
      CellTags->"Info3347223941-9029670"]},
  "Info3347223941-8579298"->{
    Cell[60301, 1404, 183, 3, 44, "Print",
      CellTags->"Info3347223941-8579298"]},
  "Info3347223941-4116126"->{
    Cell[60487, 1409, 157, 3, 44, "Print",
      CellTags->"Info3347223941-4116126"]},
  "Info3347223942-6124645"->{
    Cell[60647, 1414, 271, 4, 82, "Print",
      CellTags->"Info3347223942-6124645"]},
  "Info3347223942-3619064"->{
    Cell[60921, 1420, 574, 8, 139, "Print",
      CellTags->"Info3347223942-3619064"]},
  "Info3347223942-4004828"->{
    Cell[61498, 1430, 273, 4, 82, "Print",
      CellTags->"Info3347223942-4004828"]},
  "Info3347223942-3596063"->{
    Cell[61774, 1436, 212, 4, 44, "Print",
      CellTags->"Info3347223942-3596063"]},
  "Info3347223942-5797197"->{
    Cell[61989, 1442, 236, 4, 44, "Print",
      CellTags->"Info3347223942-5797197"]},
  "Info3347223942-2688418"->{
    Cell[62228, 1448, 289, 5, 82, "Print",
      CellTags->"Info3347223942-2688418"]},
  "Info3347223942-4889550"->{
    Cell[62520, 1455, 203, 3, 44, "Print",
      CellTags->"Info3347223942-4889550"]},
  "Info3347223942-4775645"->{
    Cell[62868, 1467, 192, 3, 63, "Print",
      CellTags->"Info3347223942-4775645"]},
  "Info3347223942-9433219"->{
    Cell[63063, 1472, 261, 4, 63, "Print",
      CellTags->"Info3347223942-9433219"]},
  "Info3347223942-1224636"->{
    Cell[63327, 1478, 182, 3, 44, "Print",
      CellTags->"Info3347223942-1224636"]},
  "Info3347223942-4362745"->{
    Cell[63512, 1483, 173, 3, 44, "Print",
      CellTags->"Info3347223942-4362745"]},
  "Info3347223942-3956808"->{
    Cell[63688, 1488, 182, 3, 44, "Print",
      CellTags->"Info3347223942-3956808"]},
  "Info3347223942-7340812"->{
    Cell[63873, 1493, 805, 11, 215, "Print",
      CellTags->"Info3347223942-7340812"]},
  "Info3347223942-7747929"->{
    Cell[64681, 1506, 485, 7, 139, "Print",
      CellTags->"Info3347223942-7747929"]},
  "Info3347223942-1072148"->{
    Cell[65169, 1515, 403, 6, 82, "Print",
      CellTags->"Info3347223942-1072148"]},
  "Info3347223942-4833943"->{
    Cell[65575, 1523, 716, 10, 196, "Print",
      CellTags->"Info3347223942-4833943"]},
  "Info3347223942-3215298"->{
    Cell[66294, 1535, 121, 2, 25, "Print",
      CellTags->"Info3347223942-3215298"]},
  "Info3347223942-3062770"->{
    Cell[66418, 1539, 139, 3, 25, "Print",
      CellTags->"Info3347223942-3062770"]},
  "Info3347223942-1478151"->{
    Cell[66560, 1544, 134, 3, 25, "Print",
      CellTags->"Info3347223942-1478151"]},
  "Info3347223942-4873634"->{
    Cell[66697, 1549, 124, 2, 25, "Print",
      CellTags->"Info3347223942-4873634"]},
  "Info3347223942-1405457"->{
    Cell[66824, 1553, 132, 3, 25, "Print",
      CellTags->"Info3347223942-1405457"]},
  "Info3347223942-3777925"->{
    Cell[66959, 1558, 153, 3, 25, "Print",
      CellTags->"Info3347223942-3777925"]},
  "Info3347223942-2152760"->{
    Cell[67115, 1563, 666, 9, 158, "Print",
      CellTags->"Info3347223942-2152760"]},
  "Info3347223942-5073193"->{
    Cell[67784, 1574, 244, 4, 44, "Print",
      CellTags->"Info3347223942-5073193"]},
  "Info3347223942-3551327"->{
    Cell[68031, 1580, 248, 4, 63, "Print",
      CellTags->"Info3347223942-3551327"]},
  "Info3347223942-9096541"->{
    Cell[68408, 1593, 494, 7, 158, "Print",
      CellTags->"Info3347223942-9096541"]},
  "Info3347223942-2626858"->{
    Cell[68905, 1602, 442, 7, 139, "Print",
      CellTags->"Info3347223942-2626858"]},
  "Info3347223942-9568268"->{
    Cell[69350, 1611, 437, 7, 120, "Print",
      CellTags->"Info3347223942-9568268"]},
  "Info3347223942-6949674"->{
    Cell[69790, 1620, 437, 7, 139, "Print",
      CellTags->"Info3347223942-6949674"]},
  "Info3347223942-3601001"->{
    Cell[70230, 1629, 362, 5, 120, "Print",
      CellTags->"Info3347223942-3601001"]},
  "Info3347223942-6609419"->{
    Cell[70595, 1636, 431, 6, 120, "Print",
      CellTags->"Info3347223942-6609419"]},
  "Info3347223942-9958241"->{
    Cell[71155, 1651, 303, 5, 63, "Print",
      CellTags->"Info3347223942-9958241"]},
  "Info3347223942-7543440"->{
    Cell[71461, 1658, 110, 2, 25, "Print",
      CellTags->"Info3347223942-7543440"]},
  "Info3347223942-5025554"->{
    Cell[71574, 1662, 121, 2, 25, "Print",
      CellTags->"Info3347223942-5025554"]},
  "Info3347223942-6965775"->{
    Cell[71698, 1666, 103, 2, 25, "Print",
      CellTags->"Info3347223942-6965775"]},
  "Info3347223942-3888279"->{
    Cell[71804, 1670, 139, 3, 25, "Print",
      CellTags->"Info3347223942-3888279"]},
  "Info3347223942-5334754"->{
    Cell[71946, 1675, 149, 3, 25, "Print",
      CellTags->"Info3347223942-5334754"]},
  "Info3347223942-2217087"->{
    Cell[72098, 1680, 175, 3, 44, "Print",
      CellTags->"Info3347223942-2217087"]},
  "Info3347223942-6944643"->{
    Cell[72276, 1685, 109, 2, 25, "Print",
      CellTags->"Info3347223942-6944643"]},
  "Info3347223942-3967660"->{
    Cell[72388, 1689, 111, 2, 25, "Print",
      CellTags->"Info3347223942-3967660"]},
  "Info3347223942-9812128"->{
    Cell[72502, 1693, 296, 5, 82, "Print",
      CellTags->"Info3347223942-9812128"]},
  "Info3347223942-9428271"->{
    Cell[72801, 1700, 114, 2, 25, "Print",
      CellTags->"Info3347223942-9428271"]},
  "Info3347223942-5196408"->{
    Cell[72918, 1704, 141, 3, 25, "Print",
      CellTags->"Info3347223942-5196408"]},
  "Info3347223942-3765753"->{
    Cell[73062, 1709, 114, 2, 25, "Print",
      CellTags->"Info3347223942-3765753"]},
  "Info3347223942-7435369"->{
    Cell[73179, 1713, 234, 4, 44, "Print",
      CellTags->"Info3347223942-7435369"]},
  "Info3347223942-9408926"->{
    Cell[73541, 1726, 361, 5, 101, "Print",
      CellTags->"Info3347223942-9408926"]},
  "Info3347223942-8756152"->{
    Cell[73905, 1733, 150, 3, 25, "Print",
      CellTags->"Info3347223942-8756152"]},
  "Info3347223942-5512214"->{
    Cell[74058, 1738, 275, 4, 63, "Print",
      CellTags->"Info3347223942-5512214"]},
  "Info3347223942-4592327"->{
    Cell[74336, 1744, 162, 3, 25, "Print",
      CellTags->"Info3347223942-4592327"]},
  "Info3347223942-2467846"->{
    Cell[74501, 1749, 1114, 15, 253, "Print",
      CellTags->"Info3347223942-2467846"]},
  "Info3347223942-6619667"->{
    Cell[75618, 1766, 165, 3, 25, "Print",
      CellTags->"Info3347223942-6619667"]},
  "Info3347223942-8743872"->{
    Cell[75786, 1771, 114, 2, 25, "Print",
      CellTags->"Info3347223942-8743872"]},
  "Info3347223942-7645405"->{
    Cell[75903, 1775, 228, 4, 44, "Print",
      CellTags->"Info3347223942-7645405"]},
  "Info3347223942-9313603"->{
    Cell[76134, 1781, 276, 4, 63, "Print",
      CellTags->"Info3347223942-9313603"]},
  "Info3347223942-6658559"->{
    Cell[76413, 1787, 289, 5, 63, "Print",
      CellTags->"Info3347223942-6658559"]},
  "Info3347223942-2489674"->{
    Cell[76705, 1794, 414, 6, 158, "Print",
      CellTags->"Info3347223942-2489674"]},
  "Info3347223942-2698508"->{
    Cell[77122, 1802, 486, 7, 101, "Print",
      CellTags->"Info3347223942-2698508"]},
  "Info3347223942-1174016"->{
    Cell[77886, 1825, 1031, 14, 291, "Print",
      CellTags->"Info3347223942-1174016"]},
  "Info3347223942-3337860"->{
    Cell[78920, 1841, 357, 6, 82, "Print",
      CellTags->"Info3347223942-3337860"]},
  "Info3347223942-7875248"->{
    Cell[79280, 1849, 1427, 20, 386, "Print",
      CellTags->"Info3347223942-7875248"]},
  "Info3347223942-3565351"->{
    Cell[80710, 1871, 259, 4, 63, "Print",
      CellTags->"Info3347223942-3565351"]},
  "Info3347223942-9575072"->{
    Cell[80972, 1877, 205, 3, 44, "Print",
      CellTags->"Info3347223942-9575072"]},
  "Info3347223942-1161328"->{
    Cell[81180, 1882, 198, 3, 44, "Print",
      CellTags->"Info3347223942-1161328"]},
  "Info3347223942-6641394"->{
    Cell[81381, 1887, 348, 5, 82, "Print",
      CellTags->"Info3347223942-6641394"]},
  "Info3347223942-3253559"->{
    Cell[81732, 1894, 946, 13, 405, "Print",
      CellTags->"Info3347223942-3253559"]},
  "Info3347223942-5222545"->{
    Cell[82681, 1909, 584, 8, 158, "Print",
      CellTags->"Info3347223942-5222545"]},
  "Info3347223942-6345755"->{
    Cell[83268, 1919, 233, 4, 44, "Print",
      CellTags->"Info3347223942-6345755"]},
  "Info3347223942-3683202"->{
    Cell[83504, 1925, 1165, 16, 329, "Print",
      CellTags->"Info3347223942-3683202"]},
  "Info3347223942-7858990"->{
    Cell[84672, 1943, 598, 9, 177, "Print",
      CellTags->"Info3347223942-7858990"]},
  "Info3347223942-3699623"->{
    Cell[85273, 1954, 166, 3, 25, "Print",
      CellTags->"Info3347223942-3699623"]},
  "Info3347223942-4895320"->{
    Cell[85442, 1959, 159, 3, 25, "Print",
      CellTags->"Info3347223942-4895320"]},
  "Info3347223942-9354952"->{
    Cell[85604, 1964, 163, 3, 25, "Print",
      CellTags->"Info3347223942-9354952"]},
  "Info3347223942-8866994"->{
    Cell[85770, 1969, 163, 3, 25, "Print",
      CellTags->"Info3347223942-8866994"]},
  "Info3347223942-7974690"->{
    Cell[86068, 1981, 558, 8, 139, "Print",
      CellTags->"Info3347223942-7974690"]},
  "Info3347223942-7718741"->{
    Cell[86629, 1991, 183, 3, 44, "Print",
      CellTags->"Info3347223942-7718741"]},
  "Info3347223942-6265237"->{
    Cell[86815, 1996, 157, 3, 44, "Print",
      CellTags->"Info3347223942-6265237"]},
  "Info3347223942-2127838"->{
    Cell[86975, 2001, 271, 4, 82, "Print",
      CellTags->"Info3347223942-2127838"]},
  "Info3347223942-8061335"->{
    Cell[87249, 2007, 583, 9, 158, "Print",
      CellTags->"Info3347223942-8061335"]},
  "Info3347223942-2612802"->{
    Cell[87835, 2018, 273, 4, 82, "Print",
      CellTags->"Info3347223942-2612802"]},
  "Info3347223942-3525955"->{
    Cell[88111, 2024, 212, 4, 44, "Print",
      CellTags->"Info3347223942-3525955"]},
  "Info3347223942-9298280"->{
    Cell[88326, 2030, 236, 4, 44, "Print",
      CellTags->"Info3347223942-9298280"]},
  "Info3347223942-3205867"->{
    Cell[88565, 2036, 289, 5, 82, "Print",
      CellTags->"Info3347223942-3205867"]},
  "Info3347223942-2715408"->{
    Cell[88857, 2043, 203, 3, 44, "Print",
      CellTags->"Info3347223942-2715408"]},
  "Info3347223942-1902193"->{
    Cell[89205, 2055, 192, 3, 63, "Print",
      CellTags->"Info3347223942-1902193"]},
  "Info3347223942-6712612"->{
    Cell[89400, 2060, 261, 4, 63, "Print",
      CellTags->"Info3347223942-6712612"]},
  "Info3347223942-4802586"->{
    Cell[89664, 2066, 182, 3, 44, "Print",
      CellTags->"Info3347223942-4802586"]},
  "Info3347223942-6636810"->{
    Cell[89849, 2071, 173, 3, 44, "Print",
      CellTags->"Info3347223942-6636810"]},
  "Info3347223942-4840162"->{
    Cell[90025, 2076, 182, 3, 44, "Print",
      CellTags->"Info3347223942-4840162"]},
  "Info3347223942-7491570"->{
    Cell[90210, 2081, 415, 6, 120, "Print",
      CellTags->"Info3347223942-7491570"]},
  "Info3347223942-1473756"->{
    Cell[90628, 2089, 791, 11, 215, "Print",
      CellTags->"Info3347223942-1473756"]},
  "Info3347223942-1735460"->{
    Cell[91422, 2102, 199, 3, 44, "Print",
      CellTags->"Info3347223942-1735460"]},
  "Info3347223942-2227327"->{
    Cell[91624, 2107, 578, 8, 158, "Print",
      CellTags->"Info3347223942-2227327"]},
  "Info3347223942-4747170"->{
    Cell[92205, 2117, 121, 2, 25, "Print",
      CellTags->"Info3347223942-4747170"]},
  "Info3347223942-2286321"->{
    Cell[92329, 2121, 139, 3, 25, "Print",
      CellTags->"Info3347223942-2286321"]},
  "Info3347223942-8963834"->{
    Cell[92471, 2126, 134, 3, 25, "Print",
      CellTags->"Info3347223942-8963834"]},
  "Info3347223942-9305092"->{
    Cell[92608, 2131, 124, 2, 25, "Print",
      CellTags->"Info3347223942-9305092"]},
  "Info3347223942-6456408"->{
    Cell[92735, 2135, 132, 3, 25, "Print",
      CellTags->"Info3347223942-6456408"]},
  "Info3347223942-3630767"->{
    Cell[92870, 2140, 153, 3, 25, "Print",
      CellTags->"Info3347223942-3630767"]},
  "Info3347223942-8451424"->{
    Cell[93026, 2145, 666, 9, 158, "Print",
      CellTags->"Info3347223942-8451424"]},
  "Info3347223942-9036334"->{
    Cell[93695, 2156, 244, 4, 44, "Print",
      CellTags->"Info3347223942-9036334"]},
  "Info3347223942-8833736"->{
    Cell[93942, 2162, 248, 4, 63, "Print",
      CellTags->"Info3347223942-8833736"]},
  "Info3347223942-7130020"->{
    Cell[94317, 2175, 494, 7, 158, "Print",
      CellTags->"Info3347223942-7130020"]},
  "Info3347223942-7499705"->{
    Cell[94814, 2184, 442, 7, 139, "Print",
      CellTags->"Info3347223942-7499705"]},
  "Info3347223942-7334860"->{
    Cell[95259, 2193, 437, 7, 120, "Print",
      CellTags->"Info3347223942-7334860"]},
  "Info3347223942-3929142"->{
    Cell[95699, 2202, 437, 7, 139, "Print",
      CellTags->"Info3347223942-3929142"]},
  "Info3347223942-4675478"->{
    Cell[96139, 2211, 362, 5, 120, "Print",
      CellTags->"Info3347223942-4675478"]},
  "Info3347223942-6544225"->{
    Cell[96504, 2218, 431, 6, 120, "Print",
      CellTags->"Info3347223942-6544225"]},
  "Info3347223942-4841605"->{
    Cell[97064, 2233, 303, 5, 63, "Print",
      CellTags->"Info3347223942-4841605"]},
  "Info3347223942-6260931"->{
    Cell[97370, 2240, 110, 2, 25, "Print",
      CellTags->"Info3347223942-6260931"]},
  "Info3347223942-2933636"->{
    Cell[97483, 2244, 128, 2, 25, "Print",
      CellTags->"Info3347223942-2933636"]},
  "Info3347223942-6299238"->{
    Cell[97614, 2248, 103, 2, 25, "Print",
      CellTags->"Info3347223942-6299238"]},
  "Info3347223942-8455083"->{
    Cell[97720, 2252, 139, 3, 25, "Print",
      CellTags->"Info3347223942-8455083"]},
  "Info3347223942-2761304"->{
    Cell[97862, 2257, 149, 3, 25, "Print",
      CellTags->"Info3347223942-2761304"]},
  "Info3347223942-7582796"->{
    Cell[98014, 2262, 175, 3, 44, "Print",
      CellTags->"Info3347223942-7582796"]},
  "Info3347223942-3568316"->{
    Cell[98192, 2267, 109, 2, 25, "Print",
      CellTags->"Info3347223942-3568316"]},
  "Info3347223942-8381002"->{
    Cell[98304, 2271, 111, 2, 25, "Print",
      CellTags->"Info3347223942-8381002"]},
  "Info3347223942-6455526"->{
    Cell[98418, 2275, 296, 5, 82, "Print",
      CellTags->"Info3347223942-6455526"]},
  "Info3347223942-4808313"->{
    Cell[98717, 2282, 114, 2, 25, "Print",
      CellTags->"Info3347223942-4808313"]},
  "Info3347223942-2972084"->{
    Cell[98834, 2286, 141, 3, 25, "Print",
      CellTags->"Info3347223942-2972084"]},
  "Info3347223942-3404091"->{
    Cell[98978, 2291, 114, 2, 25, "Print",
      CellTags->"Info3347223942-3404091"]},
  "Info3347223942-5570118"->{
    Cell[99095, 2295, 241, 4, 44, "Print",
      CellTags->"Info3347223942-5570118"]},
  "Info3347223942-9710485"->{
    Cell[99464, 2308, 365, 6, 101, "Print",
      CellTags->"Info3347223942-9710485"]},
  "Info3347223942-3212477"->{
    Cell[99832, 2316, 150, 3, 25, "Print",
      CellTags->"Info3347223942-3212477"]},
  "Info3347223942-7052201"->{
    Cell[99985, 2321, 275, 4, 63, "Print",
      CellTags->"Info3347223942-7052201"]},
  "Info3347223942-1274397"->{
    Cell[100263, 2327, 162, 3, 25, "Print",
      CellTags->"Info3347223942-1274397"]},
  "Info3347223942-6291660"->{
    Cell[100428, 2332, 1125, 15, 272, "Print",
      CellTags->"Info3347223942-6291660"]},
  "Info3347223942-1780589"->{
    Cell[101556, 2349, 165, 3, 25, "Print",
      CellTags->"Info3347223942-1780589"]},
  "Info3347223942-7289647"->{
    Cell[101724, 2354, 114, 2, 25, "Print",
      CellTags->"Info3347223942-7289647"]},
  "Info3347223942-3206676"->{
    Cell[101841, 2358, 228, 4, 44, "Print",
      CellTags->"Info3347223942-3206676"]},
  "Info3347223942-9428676"->{
    Cell[102072, 2364, 276, 4, 63, "Print",
      CellTags->"Info3347223942-9428676"]},
  "Info3347223942-7629229"->{
    Cell[102351, 2370, 289, 5, 63, "Print",
      CellTags->"Info3347223942-7629229"]},
  "Info3347223942-1442542"->{
    Cell[102643, 2377, 414, 6, 158, "Print",
      CellTags->"Info3347223942-1442542"]},
  "Info3347223942-1702933"->{
    Cell[103060, 2385, 500, 7, 101, "Print",
      CellTags->"Info3347223942-1702933"]},
  "Info3347223942-5078785"->{
    Cell[103840, 2408, 255, 4, 63, "Print",
      CellTags->"Info3347223942-5078785"]},
  "Info3347223942-1556017"->{
    Cell[104098, 2414, 544, 8, 120, "Print",
      CellTags->"Info3347223942-1556017"]},
  "Info3347223942-3937423"->{
    Cell[104645, 2424, 126, 2, 25, "Print",
      CellTags->"Info3347223942-3937423"]},
  "Info3347223942-1584120"->{
    Cell[104774, 2428, 184, 3, 44, "Print",
      CellTags->"Info3347223942-1584120"]},
  "Info3347223942-8122127"->{
    Cell[104961, 2433, 494, 7, 120, "Print",
      CellTags->"Info3347223942-8122127"]},
  "Info3347223942-6550982"->{
    Cell[105458, 2442, 266, 4, 63, "Print",
      CellTags->"Info3347223942-6550982"]},
  "Info3347223942-4006352"->{
    Cell[105727, 2448, 122, 2, 25, "Print",
      CellTags->"Info3347223942-4006352"]},
  "Info3347223943-7268328"->{
    Cell[105852, 2452, 496, 7, 215, "Print",
      CellTags->"Info3347223943-7268328"]},
  "Info3347223943-9145937"->{
    Cell[106351, 2461, 417, 6, 177, "Print",
      CellTags->"Info3347223943-9145937"]},
  "Info3347223943-9840448"->{
    Cell[106771, 2469, 976, 13, 310, "Print",
      CellTags->"Info3347223943-9840448"]},
  "Info3347223943-7986648"->{
    Cell[107750, 2484, 312, 5, 63, "Print",
      CellTags->"Info3347223943-7986648"]},
  "Info3347223943-7429312"->{
    Cell[108186, 2498, 657, 9, 234, "Print",
      CellTags->"Info3347223943-7429312"]},
  "Info3347223943-7412679"->{
    Cell[108846, 2509, 161, 3, 44, "Print",
      CellTags->"Info3347223943-7412679"]},
  "Info3347223943-4063720"->{
    Cell[109010, 2514, 214, 4, 63, "Print",
      CellTags->"Info3347223943-4063720"]},
  "Info3347223943-2445563"->{
    Cell[109227, 2520, 217, 4, 63, "Print",
      CellTags->"Info3347223943-2445563"]},
  "Info3347223943-6984034"->{
    Cell[109447, 2526, 203, 3, 63, "Print",
      CellTags->"Info3347223943-6984034"]},
  "Info3347223943-7106080"->{
    Cell[109653, 2531, 210, 4, 63, "Print",
      CellTags->"Info3347223943-7106080"]},
  "Info3347223943-3775443"->{
    Cell[109992, 2544, 377, 6, 101, "Print",
      CellTags->"Info3347223943-3775443"]},
  "Info3347223943-8151160"->{
    Cell[110372, 2552, 137, 3, 25, "Print",
      CellTags->"Info3347223943-8151160"]},
  "Info3347223943-8563191"->{
    Cell[110512, 2557, 587, 8, 158, "Print",
      CellTags->"Info3347223943-8563191"]},
  "Info3347223943-7693835"->{
    Cell[111102, 2567, 137, 3, 25, "Print",
      CellTags->"Info3347223943-7693835"]},
  "Info3347223943-2142348"->{
    Cell[111242, 2572, 299, 5, 63, "Print",
      CellTags->"Info3347223943-2142348"]},
  "Info3347223943-4698659"->{
    Cell[111544, 2579, 110, 2, 25, "Print",
      CellTags->"Info3347223943-4698659"]},
  "Info3347223943-1610739"->{
    Cell[111657, 2583, 155, 3, 25, "Print",
      CellTags->"Info3347223943-1610739"]},
  "Info3347223943-4515092"->{
    Cell[111815, 2588, 103, 2, 25, "Print",
      CellTags->"Info3347223943-4515092"]},
  "Info3347223943-2547445"->{
    Cell[111921, 2592, 156, 3, 25, "Print",
      CellTags->"Info3347223943-2547445"]},
  "Info3347223943-5690018"->{
    Cell[112080, 2597, 149, 3, 25, "Print",
      CellTags->"Info3347223943-5690018"]},
  "Info3347223943-2070076"->{
    Cell[112232, 2602, 184, 3, 44, "Print",
      CellTags->"Info3347223943-2070076"]},
  "Info3347223943-5398885"->{
    Cell[112419, 2607, 150, 3, 25, "Print",
      CellTags->"Info3347223943-5398885"]},
  "Info3347223943-3534432"->{
    Cell[112572, 2612, 167, 3, 44, "Print",
      CellTags->"Info3347223943-3534432"]},
  "Info3347223943-2811507"->{
    Cell[112742, 2617, 230, 4, 44, "Print",
      CellTags->"Info3347223943-2811507"]},
  "Info3347223943-3089526"->{
    Cell[112975, 2623, 232, 4, 44, "Print",
      CellTags->"Info3347223943-3089526"]},
  "Info3347223943-4050909"->{
    Cell[113210, 2629, 109, 2, 25, "Print",
      CellTags->"Info3347223943-4050909"]},
  "Info3347223943-2256146"->{
    Cell[113322, 2633, 111, 2, 25, "Print",
      CellTags->"Info3347223943-2256146"]},
  "Info3347223943-2578274"->{
    Cell[113436, 2637, 296, 5, 82, "Print",
      CellTags->"Info3347223943-2578274"]},
  "Info3347223943-1967258"->{
    Cell[113735, 2644, 114, 2, 25, "Print",
      CellTags->"Info3347223943-1967258"]},
  "Info3347223943-3803042"->{
    Cell[113852, 2648, 141, 3, 25, "Print",
      CellTags->"Info3347223943-3803042"]},
  "Info3347223943-8980657"->{
    Cell[113996, 2653, 114, 2, 25, "Print",
      CellTags->"Info3347223943-8980657"]},
  "Info3347223943-4021916"->{
    Cell[114113, 2657, 114, 2, 25, "Print",
      CellTags->"Info3347223943-4021916"]},
  "Info3347223943-4519082"->{
    Cell[114230, 2661, 242, 4, 44, "Print",
      CellTags->"Info3347223943-4519082"]},
  "Info3347223943-1421647"->{
    Cell[114597, 2674, 136, 3, 25, "Print",
      CellTags->"Info3347223943-1421647"]},
  "Info3347223943-4876034"->{
    Cell[114736, 2679, 244, 4, 44, "Print",
      CellTags->"Info3347223943-4876034"]},
  "Info3347223943-4053978"->{
    Cell[114983, 2685, 133, 3, 25, "Print",
      CellTags->"Info3347223943-4053978"]},
  "Info3347223943-8562188"->{
    Cell[115119, 2690, 276, 4, 63, "Print",
      CellTags->"Info3347223943-8562188"]},
  "Info3347223943-7158326"->{
    Cell[115398, 2696, 289, 5, 63, "Print",
      CellTags->"Info3347223943-7158326"]},
  "Info3347223943-1889904"->{
    Cell[115690, 2703, 233, 4, 44, "Print",
      CellTags->"Info3347223943-1889904"]},
  "Info3347223943-5722087"->{
    Cell[116198, 2723, 255, 4, 63, "Print",
      CellTags->"Info3347223943-5722087"]},
  "Info3347223943-6066732"->{
    Cell[116456, 2729, 544, 8, 120, "Print",
      CellTags->"Info3347223943-6066732"]},
  "Info3347223943-7540695"->{
    Cell[117003, 2739, 126, 2, 25, "Print",
      CellTags->"Info3347223943-7540695"]},
  "Info3347223943-8356363"->{
    Cell[117132, 2743, 184, 3, 44, "Print",
      CellTags->"Info3347223943-8356363"]},
  "Info3347223943-2610039"->{
    Cell[117319, 2748, 494, 7, 120, "Print",
      CellTags->"Info3347223943-2610039"]},
  "Info3347223943-9333251"->{
    Cell[117816, 2757, 266, 4, 63, "Print",
      CellTags->"Info3347223943-9333251"]},
  "Info3347223943-5741528"->{
    Cell[118085, 2763, 122, 2, 25, "Print",
      CellTags->"Info3347223943-5741528"]},
  "Info3347223943-2058617"->{
    Cell[118210, 2767, 429, 6, 177, "Print",
      CellTags->"Info3347223943-2058617"]},
  "Info3347223943-6061612"->{
    Cell[118642, 2775, 415, 6, 158, "Print",
      CellTags->"Info3347223943-6061612"]},
  "Info3347223943-5839947"->{
    Cell[119060, 2783, 1007, 14, 310, "Print",
      CellTags->"Info3347223943-5839947"]},
  "Info3347223943-6964670"->{
    Cell[120070, 2799, 319, 5, 63, "Print",
      CellTags->"Info3347223943-6964670"]},
  "Info3347223943-7045062"->{
    Cell[120513, 2813, 640, 9, 215, "Print",
      CellTags->"Info3347223943-7045062"]},
  "Info3347223943-3156769"->{
    Cell[121156, 2824, 165, 3, 44, "Print",
      CellTags->"Info3347223943-3156769"]},
  "Info3347223943-6001645"->{
    Cell[121324, 2829, 212, 4, 63, "Print",
      CellTags->"Info3347223943-6001645"]},
  "Info3347223943-4852106"->{
    Cell[121539, 2835, 208, 3, 63, "Print",
      CellTags->"Info3347223943-4852106"]},
  "Info3347223943-2532118"->{
    Cell[121750, 2840, 213, 4, 63, "Print",
      CellTags->"Info3347223943-2532118"]},
  "Info3347223943-7067293"->{
    Cell[122092, 2853, 377, 6, 101, "Print",
      CellTags->"Info3347223943-7067293"]},
  "Info3347223943-9641375"->{
    Cell[122472, 2861, 137, 3, 25, "Print",
      CellTags->"Info3347223943-9641375"]},
  "Info3347223943-7839447"->{
    Cell[122612, 2866, 591, 8, 158, "Print",
      CellTags->"Info3347223943-7839447"]},
  "Info3347223943-3277276"->{
    Cell[123206, 2876, 137, 3, 25, "Print",
      CellTags->"Info3347223943-3277276"]},
  "Info3347223943-1779400"->{
    Cell[123346, 2881, 299, 5, 63, "Print",
      CellTags->"Info3347223943-1779400"]},
  "Info3347223943-8626447"->{
    Cell[123648, 2888, 110, 2, 25, "Print",
      CellTags->"Info3347223943-8626447"]},
  "Info3347223943-1614004"->{
    Cell[123761, 2892, 150, 3, 25, "Print",
      CellTags->"Info3347223943-1614004"]},
  "Info3347223943-1756910"->{
    Cell[123914, 2897, 103, 2, 25, "Print",
      CellTags->"Info3347223943-1756910"]},
  "Info3347223943-7953603"->{
    Cell[124020, 2901, 151, 3, 25, "Print",
      CellTags->"Info3347223943-7953603"]},
  "Info3347223943-7285242"->{
    Cell[124174, 2906, 149, 3, 25, "Print",
      CellTags->"Info3347223943-7285242"]},
  "Info3347223943-3710641"->{
    Cell[124326, 2911, 179, 3, 44, "Print",
      CellTags->"Info3347223943-3710641"]},
  "Info3347223943-6496722"->{
    Cell[124508, 2916, 150, 3, 25, "Print",
      CellTags->"Info3347223943-6496722"]},
  "Info3347223943-4583684"->{
    Cell[124661, 2921, 162, 3, 25, "Print",
      CellTags->"Info3347223943-4583684"]},
  "Info3347223943-5150566"->{
    Cell[124826, 2926, 230, 4, 44, "Print",
      CellTags->"Info3347223943-5150566"]},
  "Info3347223943-5115022"->{
    Cell[125059, 2932, 232, 4, 44, "Print",
      CellTags->"Info3347223943-5115022"]},
  "Info3347223943-6296956"->{
    Cell[125294, 2938, 109, 2, 25, "Print",
      CellTags->"Info3347223943-6296956"]},
  "Info3347223943-1006138"->{
    Cell[125406, 2942, 111, 2, 25, "Print",
      CellTags->"Info3347223943-1006138"]},
  "Info3347223943-3228834"->{
    Cell[125520, 2946, 296, 5, 82, "Print",
      CellTags->"Info3347223943-3228834"]},
  "Info3347223943-1888747"->{
    Cell[125819, 2953, 114, 2, 25, "Print",
      CellTags->"Info3347223943-1888747"]},
  "Info3347223943-7381528"->{
    Cell[125936, 2957, 141, 3, 25, "Print",
      CellTags->"Info3347223943-7381528"]},
  "Info3347223943-8122874"->{
    Cell[126080, 2962, 114, 2, 25, "Print",
      CellTags->"Info3347223943-8122874"]},
  "Info3347223943-6416613"->{
    Cell[126197, 2966, 114, 2, 25, "Print",
      CellTags->"Info3347223943-6416613"]},
  "Info3347223943-1079780"->{
    Cell[126314, 2970, 237, 4, 44, "Print",
      CellTags->"Info3347223943-1079780"]},
  "Info3347223943-5972664"->{
    Cell[126676, 2983, 136, 3, 25, "Print",
      CellTags->"Info3347223943-5972664"]},
  "Info3347223943-4112961"->{
    Cell[126815, 2988, 244, 4, 44, "Print",
      CellTags->"Info3347223943-4112961"]},
  "Info3347223943-2709084"->{
    Cell[127062, 2994, 126, 2, 25, "Print",
      CellTags->"Info3347223943-2709084"]},
  "Info3347223943-8970379"->{
    Cell[127191, 2998, 276, 4, 63, "Print",
      CellTags->"Info3347223943-8970379"]},
  "Info3347223943-7602098"->{
    Cell[127470, 3004, 289, 5, 63, "Print",
      CellTags->"Info3347223943-7602098"]},
  "Info3347223943-2781622"->{
    Cell[127762, 3011, 233, 4, 44, "Print",
      CellTags->"Info3347223943-2781622"]},
  "Info3347223943-1412650"->{
    Cell[128273, 3031, 255, 4, 63, "Print",
      CellTags->"Info3347223943-1412650"]},
  "Info3347223943-9876552"->{
    Cell[128531, 3037, 544, 8, 120, "Print",
      CellTags->"Info3347223943-9876552"]},
  "Info3347223943-9911280"->{
    Cell[129078, 3047, 126, 2, 25, "Print",
      CellTags->"Info3347223943-9911280"]},
  "Info3347223943-6335135"->{
    Cell[129207, 3051, 184, 3, 44, "Print",
      CellTags->"Info3347223943-6335135"]},
  "Info3347223943-9595876"->{
    Cell[129394, 3056, 494, 7, 120, "Print",
      CellTags->"Info3347223943-9595876"]},
  "Info3347223943-5396991"->{
    Cell[129891, 3065, 266, 4, 63, "Print",
      CellTags->"Info3347223943-5396991"]},
  "Info3347223943-6581954"->{
    Cell[130160, 3071, 122, 2, 25, "Print",
      CellTags->"Info3347223943-6581954"]},
  "Info3347223943-8464511"->{
    Cell[130285, 3075, 926, 13, 310, "Print",
      CellTags->"Info3347223943-8464511"]},
  "Info3347223943-4874601"->{
    Cell[131214, 3090, 430, 6, 196, "Print",
      CellTags->"Info3347223943-4874601"]},
  "Info3347223943-5629661"->{
    Cell[131647, 3098, 1320, 18, 424, "Print",
      CellTags->"Info3347223943-5629661"]},
  "Info3347223943-4925532"->{
    Cell[132970, 3118, 313, 5, 63, "Print",
      CellTags->"Info3347223943-4925532"]},
  "Info3347223943-5246270"->{
    Cell[133407, 3132, 1146, 16, 367, "Print",
      CellTags->"Info3347223943-5246270"]},
  "Info3347223943-1445452"->{
    Cell[134556, 3150, 161, 3, 44, "Print",
      CellTags->"Info3347223943-1445452"]},
  "Info3347223943-4450436"->{
    Cell[134720, 3155, 206, 3, 63, "Print",
      CellTags->"Info3347223943-4450436"]},
  "Info3347223943-3881981"->{
    Cell[134929, 3160, 208, 4, 63, "Print",
      CellTags->"Info3347223943-3881981"]},
  "Info3347223943-7228078"->{
    Cell[135140, 3166, 217, 4, 63, "Print",
      CellTags->"Info3347223943-7228078"]},
  "Info3347223943-4602624"->{
    Cell[135486, 3179, 377, 6, 101, "Print",
      CellTags->"Info3347223943-4602624"]},
  "Info3347223943-8450963"->{
    Cell[135866, 3187, 137, 3, 25, "Print",
      CellTags->"Info3347223943-8450963"]},
  "Info3347223943-6220742"->{
    Cell[136006, 3192, 655, 9, 310, "Print",
      CellTags->"Info3347223943-6220742"]},
  "Info3347223943-7000860"->{
    Cell[136664, 3203, 137, 3, 25, "Print",
      CellTags->"Info3347223943-7000860"]},
  "Info3347223943-5567665"->{
    Cell[136804, 3208, 299, 5, 63, "Print",
      CellTags->"Info3347223943-5567665"]},
  "Info3347223943-5586590"->{
    Cell[137106, 3215, 110, 2, 25, "Print",
      CellTags->"Info3347223943-5586590"]},
  "Info3347223943-2736516"->{
    Cell[137219, 3219, 148, 3, 25, "Print",
      CellTags->"Info3347223943-2736516"]},
  "Info3347223943-4561819"->{
    Cell[137370, 3224, 103, 2, 25, "Print",
      CellTags->"Info3347223943-4561819"]},
  "Info3347223943-9200808"->{
    Cell[137476, 3228, 149, 3, 25, "Print",
      CellTags->"Info3347223943-9200808"]},
  "Info3347223943-4835101"->{
    Cell[137628, 3233, 149, 3, 25, "Print",
      CellTags->"Info3347223943-4835101"]},
  "Info3347223943-7355272"->{
    Cell[137780, 3238, 177, 3, 44, "Print",
      CellTags->"Info3347223943-7355272"]},
  "Info3347223943-1181112"->{
    Cell[137960, 3243, 150, 3, 25, "Print",
      CellTags->"Info3347223943-1181112"]},
  "Info3347223943-2215272"->{
    Cell[138113, 3248, 160, 3, 25, "Print",
      CellTags->"Info3347223943-2215272"]},
  "Info3347223943-1923535"->{
    Cell[138276, 3253, 230, 4, 44, "Print",
      CellTags->"Info3347223943-1923535"]},
  "Info3347223943-8093696"->{
    Cell[138509, 3259, 232, 4, 44, "Print",
      CellTags->"Info3347223943-8093696"]},
  "Info3347223943-6910008"->{
    Cell[138744, 3265, 109, 2, 25, "Print",
      CellTags->"Info3347223943-6910008"]},
  "Info3347223943-1493678"->{
    Cell[138856, 3269, 111, 2, 25, "Print",
      CellTags->"Info3347223943-1493678"]},
  "Info3347223943-3117515"->{
    Cell[138970, 3273, 296, 5, 82, "Print",
      CellTags->"Info3347223943-3117515"]},
  "Info3347223943-4832411"->{
    Cell[139269, 3280, 114, 2, 25, "Print",
      CellTags->"Info3347223943-4832411"]},
  "Info3347223943-8404433"->{
    Cell[139386, 3284, 141, 3, 25, "Print",
      CellTags->"Info3347223943-8404433"]},
  "Info3347223943-7328827"->{
    Cell[139530, 3289, 114, 2, 25, "Print",
      CellTags->"Info3347223943-7328827"]},
  "Info3347223943-4746551"->{
    Cell[139647, 3293, 114, 2, 25, "Print",
      CellTags->"Info3347223943-4746551"]},
  "Info3347223943-8409741"->{
    Cell[139764, 3297, 227, 4, 44, "Print",
      CellTags->"Info3347223943-8409741"]},
  "Info3347223943-8817053"->{
    Cell[140116, 3310, 136, 3, 25, "Print",
      CellTags->"Info3347223943-8817053"]},
  "Info3347223943-3716282"->{
    Cell[140255, 3315, 244, 4, 44, "Print",
      CellTags->"Info3347223943-3716282"]},
  "Info3347223943-8999170"->{
    Cell[140502, 3321, 116, 2, 25, "Print",
      CellTags->"Info3347223943-8999170"]},
  "Info3347223943-5709094"->{
    Cell[140621, 3325, 276, 4, 63, "Print",
      CellTags->"Info3347223943-5709094"]},
  "Info3347223943-3657880"->{
    Cell[140900, 3331, 289, 5, 63, "Print",
      CellTags->"Info3347223943-3657880"]},
  "Info3347223943-6348310"->{
    Cell[141192, 3338, 233, 4, 44, "Print",
      CellTags->"Info3347223943-6348310"]},
  "Info3347223943-5622619"->{
    Cell[141700, 3358, 262, 4, 63, "Print",
      CellTags->"Info3347223943-5622619"]},
  "Info3347223943-3212639"->{
    Cell[141965, 3364, 549, 8, 120, "Print",
      CellTags->"Info3347223943-3212639"]},
  "Info3347223944-7593278"->{
    Cell[142517, 3374, 126, 2, 25, "Print",
      CellTags->"Info3347223944-7593278"]},
  "Info3347223944-1223543"->{
    Cell[142646, 3378, 184, 3, 44, "Print",
      CellTags->"Info3347223944-1223543"]},
  "Info3347223944-6433330"->{
    Cell[142833, 3383, 494, 7, 120, "Print",
      CellTags->"Info3347223944-6433330"]},
  "Info3347223944-8548286"->{
    Cell[143330, 3392, 266, 4, 63, "Print",
      CellTags->"Info3347223944-8548286"]},
  "Info3347223944-5636726"->{
    Cell[143599, 3398, 122, 2, 25, "Print",
      CellTags->"Info3347223944-5636726"]},
  "Info3347223944-6212195"->{
    Cell[143724, 3402, 1257, 17, 519, "Print",
      CellTags->"Info3347223944-6212195"]},
  "Info3347223944-2446185"->{
    Cell[144984, 3421, 662, 9, 196, "Print",
      CellTags->"Info3347223944-2446185"]},
  "Info3347223944-4819550"->{
    Cell[145649, 3432, 887, 12, 348, "Print",
      CellTags->"Info3347223944-4819550"]},
  "Info3347223944-6414604"->{
    Cell[146539, 3446, 590, 9, 158, "Print",
      CellTags->"Info3347223944-6414604"]},
  "Info3347223944-6619072"->{
    Cell[147253, 3464, 782, 11, 310, "Print",
      CellTags->"Info3347223944-6619072"]},
  "Info3347223944-4082389"->{
    Cell[148038, 3477, 289, 5, 82, "Print",
      CellTags->"Info3347223944-4082389"]},
  "Info3347223944-3243349"->{
    Cell[148330, 3484, 214, 4, 63, "Print",
      CellTags->"Info3347223944-3243349"]},
  "Info3347223944-9833440"->{
    Cell[148547, 3490, 217, 4, 63, "Print",
      CellTags->"Info3347223944-9833440"]},
  "Info3347223944-9033299"->{
    Cell[148767, 3496, 178, 3, 63, "Print",
      CellTags->"Info3347223944-9033299"]},
  "Info3347223944-7106424"->{
    Cell[148948, 3501, 216, 4, 63, "Print",
      CellTags->"Info3347223944-7106424"]},
  "Info3347223944-2091162"->{
    Cell[149167, 3507, 187, 3, 63, "Print",
      CellTags->"Info3347223944-2091162"]},
  "Info3347223944-1590385"->{
    Cell[149357, 3512, 209, 3, 63, "Print",
      CellTags->"Info3347223944-1590385"]},
  "Info3347223944-5449929"->{
    Cell[149569, 3517, 199, 3, 63, "Print",
      CellTags->"Info3347223944-5449929"]},
  "Info3347223944-5484391"->{
    Cell[149771, 3522, 216, 4, 63, "Print",
      CellTags->"Info3347223944-5484391"]},
  "Info3347223944-8026549"->{
    Cell[150116, 3535, 526, 8, 158, "Print",
      CellTags->"Info3347223944-8026549"]},
  "Info3347223944-6509291"->{
    Cell[150645, 3545, 137, 3, 25, "Print",
      CellTags->"Info3347223944-6509291"]},
  "Info3347223944-9854803"->{
    Cell[150785, 3550, 891, 12, 234, "Print",
      CellTags->"Info3347223944-9854803"]},
  "Info3347223944-4587203"->{
    Cell[151679, 3564, 137, 3, 25, "Print",
      CellTags->"Info3347223944-4587203"]},
  "Info3347223944-6627152"->{
    Cell[151819, 3569, 299, 5, 63, "Print",
      CellTags->"Info3347223944-6627152"]},
  "Info3347223944-9677027"->{
    Cell[152121, 3576, 110, 2, 25, "Print",
      CellTags->"Info3347223944-9677027"]},
  "Info3347223944-7882672"->{
    Cell[152234, 3580, 155, 3, 25, "Print",
      CellTags->"Info3347223944-7882672"]},
  "Info3347223944-5172316"->{
    Cell[152392, 3585, 103, 2, 25, "Print",
      CellTags->"Info3347223944-5172316"]},
  "Info3347223944-1205732"->{
    Cell[152498, 3589, 156, 3, 25, "Print",
      CellTags->"Info3347223944-1205732"]},
  "Info3347223944-8443384"->{
    Cell[152657, 3594, 149, 3, 25, "Print",
      CellTags->"Info3347223944-8443384"]},
  "Info3347223944-8424884"->{
    Cell[152809, 3599, 184, 3, 44, "Print",
      CellTags->"Info3347223944-8424884"]},
  "Info3347223944-9112071"->{
    Cell[152996, 3604, 150, 3, 25, "Print",
      CellTags->"Info3347223944-9112071"]},
  "Info3347223944-5725100"->{
    Cell[153149, 3609, 167, 3, 44, "Print",
      CellTags->"Info3347223944-5725100"]},
  "Info3347223944-3763668"->{
    Cell[153319, 3614, 230, 4, 44, "Print",
      CellTags->"Info3347223944-3763668"]},
  "Info3347223944-5023528"->{
    Cell[153552, 3620, 232, 4, 44, "Print",
      CellTags->"Info3347223944-5023528"]},
  "Info3347223944-6332496"->{
    Cell[153787, 3626, 109, 2, 25, "Print",
      CellTags->"Info3347223944-6332496"]},
  "Info3347223944-1601766"->{
    Cell[153899, 3630, 111, 2, 25, "Print",
      CellTags->"Info3347223944-1601766"]},
  "Info3347223944-9984544"->{
    Cell[154013, 3634, 296, 5, 82, "Print",
      CellTags->"Info3347223944-9984544"]},
  "Info3347223944-8912656"->{
    Cell[154312, 3641, 114, 2, 25, "Print",
      CellTags->"Info3347223944-8912656"]},
  "Info3347223944-6144805"->{
    Cell[154429, 3645, 141, 3, 25, "Print",
      CellTags->"Info3347223944-6144805"]},
  "Info3347223944-4339604"->{
    Cell[154573, 3650, 114, 2, 25, "Print",
      CellTags->"Info3347223944-4339604"]},
  "Info3347223944-7164196"->{
    Cell[154690, 3654, 114, 2, 25, "Print",
      CellTags->"Info3347223944-7164196"]},
  "Info3347223944-7748027"->{
    Cell[154807, 3658, 242, 4, 44, "Print",
      CellTags->"Info3347223944-7748027"]},
  "Info3347223944-7495296"->{
    Cell[155174, 3671, 136, 3, 25, "Print",
      CellTags->"Info3347223944-7495296"]},
  "Info3347223944-8982714"->{
    Cell[155313, 3676, 211, 4, 44, "Print",
      CellTags->"Info3347223944-8982714"]},
  "Info3347223944-8993898"->{
    Cell[155527, 3682, 133, 3, 25, "Print",
      CellTags->"Info3347223944-8993898"]},
  "Info3347223944-1732994"->{
    Cell[155663, 3687, 276, 4, 63, "Print",
      CellTags->"Info3347223944-1732994"]},
  "Info3347223944-1385772"->{
    Cell[155942, 3693, 289, 5, 63, "Print",
      CellTags->"Info3347223944-1385772"]},
  "Info3347223944-8600115"->{
    Cell[156234, 3700, 233, 4, 44, "Print",
      CellTags->"Info3347223944-8600115"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3347223940-6631621", 157113, 3724},
  {"Info3347223940-4294206", 157228, 3727},
  {"Info3347223940-6810511", 157343, 3730},
  {"Info3347223940-7389295", 157458, 3733},
  {"Info3347223940-2382490", 157573, 3736},
  {"Info3347223940-6023529", 157688, 3739},
  {"Info3347223940-6503571", 157803, 3742},
  {"Info3347223940-5379615", 157918, 3745},
  {"Info3347223940-1834069", 158033, 3748},
  {"Info3347223940-7924268", 158148, 3751},
  {"Info3347223940-7939632", 158263, 3754},
  {"Info3347223940-6833855", 158378, 3757},
  {"Info3347223940-1189387", 158493, 3760},
  {"Info3347223940-1293541", 158608, 3763},
  {"Info3347223940-8692552", 158807, 3768},
  {"Info3347223940-9972450", 158924, 3771},
  {"Info3347223940-4605738", 159039, 3774},
  {"Info3347223940-4732625", 159155, 3777},
  {"Info3347223940-4167237", 159270, 3780},
  {"Info3347223940-9087758", 159387, 3783},
  {"Info3347223940-5926772", 159503, 3786},
  {"Info3347223940-8501482", 159621, 3789},
  {"Info3347223940-7144037", 159738, 3792},
  {"Info3347223940-2011507", 159854, 3795},
  {"Info3347223940-6339513", 159970, 3798},
  {"Info3347223940-5174597", 160086, 3801},
  {"Info3347223940-1062849", 160202, 3804},
  {"Info3347223940-3542961", 160319, 3807},
  {"Info3347223940-1600426", 160435, 3810},
  {"Info3347223940-4337716", 160551, 3813},
  {"Info3347223941-1813366", 160667, 3816},
  {"Info3347223941-1118594", 160784, 3819},
  {"Info3347223941-5737972", 160900, 3822},
  {"Info3347223941-7410441", 161016, 3825},
  {"Info3347223941-8640170", 161132, 3828},
  {"Info3347223941-1951187", 161248, 3831},
  {"Info3347223941-8197922", 161364, 3834},
  {"Info3347223941-2611265", 161480, 3837},
  {"Info3347223941-9442840", 161596, 3840},
  {"Info3347223941-7245219", 161712, 3843},
  {"Info3347223941-5798128", 161828, 3846},
  {"Info3347223941-1459018", 161944, 3849},
  {"Info3347223941-1589458", 162062, 3852},
  {"Info3347223941-8534708", 162179, 3855},
  {"Info3347223941-7553760", 162295, 3858},
  {"Info3347223941-9188284", 162413, 3861},
  {"Info3347223941-7542695", 162529, 3864},
  {"Info3347223941-2715154", 162645, 3867},
  {"Info3347223941-2795720", 162761, 3870},
  {"Info3347223941-9823357", 162877, 3873},
  {"Info3347223941-8020983", 162993, 3876},
  {"Info3347223941-4999920", 163109, 3879},
  {"Info3347223941-6637905", 163226, 3882},
  {"Info3347223941-9601905", 163342, 3885},
  {"Info3347223941-1464798", 163458, 3888},
  {"Info3347223941-1770110", 163575, 3891},
  {"Info3347223941-2471642", 163692, 3894},
  {"Info3347223941-7586356", 163809, 3897},
  {"Info3347223941-4155620", 163926, 3900},
  {"Info3347223941-3197855", 164043, 3903},
  {"Info3347223941-8920274", 164160, 3906},
  {"Info3347223941-2580618", 164276, 3909},
  {"Info3347223941-5009207", 164392, 3912},
  {"Info3347223941-1486463", 164508, 3915},
  {"Info3347223941-2487122", 164624, 3918},
  {"Info3347223941-6450972", 164740, 3921},
  {"Info3347223941-4162216", 164856, 3924},
  {"Info3347223941-6354640", 164972, 3927},
  {"Info3347223941-5746827", 165088, 3930},
  {"Info3347223941-2691935", 165204, 3933},
  {"Info3347223941-7877067", 165320, 3936},
  {"Info3347223941-7749989", 165436, 3939},
  {"Info3347223941-3231106", 165552, 3942},
  {"Info3347223941-3377092", 165668, 3945},
  {"Info3347223941-4876077", 165784, 3948},
  {"Info3347223941-3439479", 165901, 3951},
  {"Info3347223941-7653090", 166017, 3954},
  {"Info3347223941-7874582", 166133, 3957},
  {"Info3347223941-5235115", 166249, 3960},
  {"Info3347223941-7704576", 166368, 3963},
  {"Info3347223941-4043808", 166484, 3966},
  {"Info3347223941-3418109", 166600, 3969},
  {"Info3347223941-6580237", 166716, 3972},
  {"Info3347223941-6852624", 166832, 3975},
  {"Info3347223941-1422078", 166948, 3978},
  {"Info3347223941-2029304", 167065, 3981},
  {"Info3347223941-8989917", 167182, 3984},
  {"Info3347223941-3552733", 167301, 3987},
  {"Info3347223941-6176457", 167417, 3990},
  {"Info3347223941-8109493", 167534, 3993},
  {"Info3347223941-6089851", 167650, 3996},
  {"Info3347223941-7134049", 167768, 3999},
  {"Info3347223941-7244468", 167886, 4002},
  {"Info3347223941-4415755", 168004, 4005},
  {"Info3347223941-9094170", 168121, 4008},
  {"Info3347223941-3611725", 168237, 4011},
  {"Info3347223941-9967462", 168353, 4014},
  {"Info3347223941-4309295", 168469, 4017},
  {"Info3347223941-8260624", 168585, 4020},
  {"Info3347223941-8492284", 168702, 4023},
  {"Info3347223941-8438704", 168818, 4026},
  {"Info3347223941-3285558", 168934, 4029},
  {"Info3347223941-1354509", 169050, 4032},
  {"Info3347223941-1355904", 169167, 4035},
  {"Info3347223941-8370622", 169283, 4038},
  {"Info3347223941-2291614", 169399, 4041},
  {"Info3347223941-7771765", 169515, 4044},
  {"Info3347223941-7568170", 169631, 4047},
  {"Info3347223941-5343679", 169747, 4050},
  {"Info3347223941-5864838", 169863, 4053},
  {"Info3347223941-7809650", 169979, 4056},
  {"Info3347223941-2458221", 170095, 4059},
  {"Info3347223941-1974298", 170211, 4062},
  {"Info3347223941-7595909", 170327, 4065},
  {"Info3347223941-2077596", 170445, 4068},
  {"Info3347223941-6833115", 170562, 4071},
  {"Info3347223941-8415350", 170678, 4074},
  {"Info3347223941-7920837", 170796, 4077},
  {"Info3347223941-5070483", 170912, 4080},
  {"Info3347223941-1032206", 171028, 4083},
  {"Info3347223941-1376349", 171145, 4086},
  {"Info3347223941-7407861", 171262, 4089},
  {"Info3347223941-2948475", 171379, 4092},
  {"Info3347223941-8742318", 171496, 4095},
  {"Info3347223941-9656730", 171614, 4098},
  {"Info3347223941-1145073", 171731, 4101},
  {"Info3347223941-4193583", 171848, 4104},
  {"Info3347223941-6993551", 171966, 4107},
  {"Info3347223941-6453383", 172084, 4110},
  {"Info3347223941-7559587", 172202, 4113},
  {"Info3347223941-5358822", 172320, 4116},
  {"Info3347223941-6682568", 172438, 4119},
  {"Info3347223941-3512651", 172556, 4122},
  {"Info3347223941-8850662", 172673, 4125},
  {"Info3347223941-7730051", 172790, 4128},
  {"Info3347223941-2942451", 172907, 4131},
  {"Info3347223941-3089129", 173024, 4134},
  {"Info3347223941-3186031", 173141, 4137},
  {"Info3347223941-4802215", 173258, 4140},
  {"Info3347223941-8163804", 173375, 4143},
  {"Info3347223941-6931229", 173492, 4146},
  {"Info3347223941-9964984", 173609, 4149},
  {"Info3347223941-4270299", 173726, 4152},
  {"Info3347223941-7308454", 173843, 4155},
  {"Info3347223941-7750860", 173960, 4158},
  {"Info3347223941-3895549", 174077, 4161},
  {"Info3347223941-4236356", 174194, 4164},
  {"Info3347223941-2245144", 174312, 4167},
  {"Info3347223941-8159017", 174429, 4170},
  {"Info3347223941-8125029", 174546, 4173},
  {"Info3347223941-5725470", 174663, 4176},
  {"Info3347223941-8114379", 174783, 4179},
  {"Info3347223941-7760450", 174900, 4182},
  {"Info3347223941-7609199", 175017, 4185},
  {"Info3347223941-8492301", 175134, 4188},
  {"Info3347223941-8350572", 175251, 4191},
  {"Info3347223941-7702967", 175368, 4194},
  {"Info3347223941-7628927", 175486, 4197},
  {"Info3347223941-2550021", 175604, 4200},
  {"Info3347223941-9246453", 175723, 4203},
  {"Info3347223941-6719514", 175840, 4206},
  {"Info3347223941-3075263", 175958, 4209},
  {"Info3347223941-1794145", 176075, 4212},
  {"Info3347223941-2809827", 176194, 4215},
  {"Info3347223941-3602638", 176312, 4218},
  {"Info3347223941-4062804", 176431, 4221},
  {"Info3347223941-8484718", 176549, 4224},
  {"Info3347223941-8368394", 176666, 4227},
  {"Info3347223941-5771336", 176783, 4230},
  {"Info3347223941-5718574", 176900, 4233},
  {"Info3347223941-9029670", 177017, 4236},
  {"Info3347223941-8579298", 177135, 4239},
  {"Info3347223941-4116126", 177252, 4242},
  {"Info3347223942-6124645", 177369, 4245},
  {"Info3347223942-3619064", 177486, 4248},
  {"Info3347223942-4004828", 177604, 4251},
  {"Info3347223942-3596063", 177721, 4254},
  {"Info3347223942-5797197", 177838, 4257},
  {"Info3347223942-2688418", 177955, 4260},
  {"Info3347223942-4889550", 178072, 4263},
  {"Info3347223942-4775645", 178189, 4266},
  {"Info3347223942-9433219", 178306, 4269},
  {"Info3347223942-1224636", 178423, 4272},
  {"Info3347223942-4362745", 178540, 4275},
  {"Info3347223942-3956808", 178657, 4278},
  {"Info3347223942-7340812", 178774, 4281},
  {"Info3347223942-7747929", 178893, 4284},
  {"Info3347223942-1072148", 179011, 4287},
  {"Info3347223942-4833943", 179128, 4290},
  {"Info3347223942-3215298", 179247, 4293},
  {"Info3347223942-3062770", 179364, 4296},
  {"Info3347223942-1478151", 179481, 4299},
  {"Info3347223942-4873634", 179598, 4302},
  {"Info3347223942-1405457", 179715, 4305},
  {"Info3347223942-3777925", 179832, 4308},
  {"Info3347223942-2152760", 179949, 4311},
  {"Info3347223942-5073193", 180067, 4314},
  {"Info3347223942-3551327", 180184, 4317},
  {"Info3347223942-9096541", 180301, 4320},
  {"Info3347223942-2626858", 180419, 4323},
  {"Info3347223942-9568268", 180537, 4326},
  {"Info3347223942-6949674", 180655, 4329},
  {"Info3347223942-3601001", 180773, 4332},
  {"Info3347223942-6609419", 180891, 4335},
  {"Info3347223942-9958241", 181009, 4338},
  {"Info3347223942-7543440", 181126, 4341},
  {"Info3347223942-5025554", 181243, 4344},
  {"Info3347223942-6965775", 181360, 4347},
  {"Info3347223942-3888279", 181477, 4350},
  {"Info3347223942-5334754", 181594, 4353},
  {"Info3347223942-2217087", 181711, 4356},
  {"Info3347223942-6944643", 181828, 4359},
  {"Info3347223942-3967660", 181945, 4362},
  {"Info3347223942-9812128", 182062, 4365},
  {"Info3347223942-9428271", 182179, 4368},
  {"Info3347223942-5196408", 182296, 4371},
  {"Info3347223942-3765753", 182413, 4374},
  {"Info3347223942-7435369", 182530, 4377},
  {"Info3347223942-9408926", 182647, 4380},
  {"Info3347223942-8756152", 182765, 4383},
  {"Info3347223942-5512214", 182882, 4386},
  {"Info3347223942-4592327", 182999, 4389},
  {"Info3347223942-2467846", 183116, 4392},
  {"Info3347223942-6619667", 183236, 4395},
  {"Info3347223942-8743872", 183353, 4398},
  {"Info3347223942-7645405", 183470, 4401},
  {"Info3347223942-9313603", 183587, 4404},
  {"Info3347223942-6658559", 183704, 4407},
  {"Info3347223942-2489674", 183821, 4410},
  {"Info3347223942-2698508", 183939, 4413},
  {"Info3347223942-1174016", 184057, 4416},
  {"Info3347223942-3337860", 184177, 4419},
  {"Info3347223942-7875248", 184294, 4422},
  {"Info3347223942-3565351", 184414, 4425},
  {"Info3347223942-9575072", 184531, 4428},
  {"Info3347223942-1161328", 184648, 4431},
  {"Info3347223942-6641394", 184765, 4434},
  {"Info3347223942-3253559", 184882, 4437},
  {"Info3347223942-5222545", 185001, 4440},
  {"Info3347223942-6345755", 185119, 4443},
  {"Info3347223942-3683202", 185236, 4446},
  {"Info3347223942-7858990", 185356, 4449},
  {"Info3347223942-3699623", 185474, 4452},
  {"Info3347223942-4895320", 185591, 4455},
  {"Info3347223942-9354952", 185708, 4458},
  {"Info3347223942-8866994", 185825, 4461},
  {"Info3347223942-7974690", 185942, 4464},
  {"Info3347223942-7718741", 186060, 4467},
  {"Info3347223942-6265237", 186177, 4470},
  {"Info3347223942-2127838", 186294, 4473},
  {"Info3347223942-8061335", 186411, 4476},
  {"Info3347223942-2612802", 186529, 4479},
  {"Info3347223942-3525955", 186646, 4482},
  {"Info3347223942-9298280", 186763, 4485},
  {"Info3347223942-3205867", 186880, 4488},
  {"Info3347223942-2715408", 186997, 4491},
  {"Info3347223942-1902193", 187114, 4494},
  {"Info3347223942-6712612", 187231, 4497},
  {"Info3347223942-4802586", 187348, 4500},
  {"Info3347223942-6636810", 187465, 4503},
  {"Info3347223942-4840162", 187582, 4506},
  {"Info3347223942-7491570", 187699, 4509},
  {"Info3347223942-1473756", 187817, 4512},
  {"Info3347223942-1735460", 187936, 4515},
  {"Info3347223942-2227327", 188053, 4518},
  {"Info3347223942-4747170", 188171, 4521},
  {"Info3347223942-2286321", 188288, 4524},
  {"Info3347223942-8963834", 188405, 4527},
  {"Info3347223942-9305092", 188522, 4530},
  {"Info3347223942-6456408", 188639, 4533},
  {"Info3347223942-3630767", 188756, 4536},
  {"Info3347223942-8451424", 188873, 4539},
  {"Info3347223942-9036334", 188991, 4542},
  {"Info3347223942-8833736", 189108, 4545},
  {"Info3347223942-7130020", 189225, 4548},
  {"Info3347223942-7499705", 189343, 4551},
  {"Info3347223942-7334860", 189461, 4554},
  {"Info3347223942-3929142", 189579, 4557},
  {"Info3347223942-4675478", 189697, 4560},
  {"Info3347223942-6544225", 189815, 4563},
  {"Info3347223942-4841605", 189933, 4566},
  {"Info3347223942-6260931", 190050, 4569},
  {"Info3347223942-2933636", 190167, 4572},
  {"Info3347223942-6299238", 190284, 4575},
  {"Info3347223942-8455083", 190401, 4578},
  {"Info3347223942-2761304", 190518, 4581},
  {"Info3347223942-7582796", 190635, 4584},
  {"Info3347223942-3568316", 190752, 4587},
  {"Info3347223942-8381002", 190869, 4590},
  {"Info3347223942-6455526", 190986, 4593},
  {"Info3347223942-4808313", 191103, 4596},
  {"Info3347223942-2972084", 191220, 4599},
  {"Info3347223942-3404091", 191337, 4602},
  {"Info3347223942-5570118", 191454, 4605},
  {"Info3347223942-9710485", 191571, 4608},
  {"Info3347223942-3212477", 191689, 4611},
  {"Info3347223942-7052201", 191806, 4614},
  {"Info3347223942-1274397", 191923, 4617},
  {"Info3347223942-6291660", 192041, 4620},
  {"Info3347223942-1780589", 192162, 4623},
  {"Info3347223942-7289647", 192280, 4626},
  {"Info3347223942-3206676", 192398, 4629},
  {"Info3347223942-9428676", 192516, 4632},
  {"Info3347223942-7629229", 192634, 4635},
  {"Info3347223942-1442542", 192752, 4638},
  {"Info3347223942-1702933", 192871, 4641},
  {"Info3347223942-5078785", 192990, 4644},
  {"Info3347223942-1556017", 193108, 4647},
  {"Info3347223942-3937423", 193227, 4650},
  {"Info3347223942-1584120", 193345, 4653},
  {"Info3347223942-8122127", 193463, 4656},
  {"Info3347223942-6550982", 193582, 4659},
  {"Info3347223942-4006352", 193700, 4662},
  {"Info3347223943-7268328", 193818, 4665},
  {"Info3347223943-9145937", 193937, 4668},
  {"Info3347223943-9840448", 194056, 4671},
  {"Info3347223943-7986648", 194176, 4674},
  {"Info3347223943-7429312", 194294, 4677},
  {"Info3347223943-7412679", 194413, 4680},
  {"Info3347223943-4063720", 194531, 4683},
  {"Info3347223943-2445563", 194649, 4686},
  {"Info3347223943-6984034", 194767, 4689},
  {"Info3347223943-7106080", 194885, 4692},
  {"Info3347223943-3775443", 195003, 4695},
  {"Info3347223943-8151160", 195122, 4698},
  {"Info3347223943-8563191", 195240, 4701},
  {"Info3347223943-7693835", 195359, 4704},
  {"Info3347223943-2142348", 195477, 4707},
  {"Info3347223943-4698659", 195595, 4710},
  {"Info3347223943-1610739", 195713, 4713},
  {"Info3347223943-4515092", 195831, 4716},
  {"Info3347223943-2547445", 195949, 4719},
  {"Info3347223943-5690018", 196067, 4722},
  {"Info3347223943-2070076", 196185, 4725},
  {"Info3347223943-5398885", 196303, 4728},
  {"Info3347223943-3534432", 196421, 4731},
  {"Info3347223943-2811507", 196539, 4734},
  {"Info3347223943-3089526", 196657, 4737},
  {"Info3347223943-4050909", 196775, 4740},
  {"Info3347223943-2256146", 196893, 4743},
  {"Info3347223943-2578274", 197011, 4746},
  {"Info3347223943-1967258", 197129, 4749},
  {"Info3347223943-3803042", 197247, 4752},
  {"Info3347223943-8980657", 197365, 4755},
  {"Info3347223943-4021916", 197483, 4758},
  {"Info3347223943-4519082", 197601, 4761},
  {"Info3347223943-1421647", 197719, 4764},
  {"Info3347223943-4876034", 197837, 4767},
  {"Info3347223943-4053978", 197955, 4770},
  {"Info3347223943-8562188", 198073, 4773},
  {"Info3347223943-7158326", 198191, 4776},
  {"Info3347223943-1889904", 198309, 4779},
  {"Info3347223943-5722087", 198427, 4782},
  {"Info3347223943-6066732", 198545, 4785},
  {"Info3347223943-7540695", 198664, 4788},
  {"Info3347223943-8356363", 198782, 4791},
  {"Info3347223943-2610039", 198900, 4794},
  {"Info3347223943-9333251", 199019, 4797},
  {"Info3347223943-5741528", 199137, 4800},
  {"Info3347223943-2058617", 199255, 4803},
  {"Info3347223943-6061612", 199374, 4806},
  {"Info3347223943-5839947", 199493, 4809},
  {"Info3347223943-6964670", 199614, 4812},
  {"Info3347223943-7045062", 199732, 4815},
  {"Info3347223943-3156769", 199851, 4818},
  {"Info3347223943-6001645", 199969, 4821},
  {"Info3347223943-4852106", 200087, 4824},
  {"Info3347223943-2532118", 200205, 4827},
  {"Info3347223943-7067293", 200323, 4830},
  {"Info3347223943-9641375", 200442, 4833},
  {"Info3347223943-7839447", 200560, 4836},
  {"Info3347223943-3277276", 200679, 4839},
  {"Info3347223943-1779400", 200797, 4842},
  {"Info3347223943-8626447", 200915, 4845},
  {"Info3347223943-1614004", 201033, 4848},
  {"Info3347223943-1756910", 201151, 4851},
  {"Info3347223943-7953603", 201269, 4854},
  {"Info3347223943-7285242", 201387, 4857},
  {"Info3347223943-3710641", 201505, 4860},
  {"Info3347223943-6496722", 201623, 4863},
  {"Info3347223943-4583684", 201741, 4866},
  {"Info3347223943-5150566", 201859, 4869},
  {"Info3347223943-5115022", 201977, 4872},
  {"Info3347223943-6296956", 202095, 4875},
  {"Info3347223943-1006138", 202213, 4878},
  {"Info3347223943-3228834", 202331, 4881},
  {"Info3347223943-1888747", 202449, 4884},
  {"Info3347223943-7381528", 202567, 4887},
  {"Info3347223943-8122874", 202685, 4890},
  {"Info3347223943-6416613", 202803, 4893},
  {"Info3347223943-1079780", 202921, 4896},
  {"Info3347223943-5972664", 203039, 4899},
  {"Info3347223943-4112961", 203157, 4902},
  {"Info3347223943-2709084", 203275, 4905},
  {"Info3347223943-8970379", 203393, 4908},
  {"Info3347223943-7602098", 203511, 4911},
  {"Info3347223943-2781622", 203629, 4914},
  {"Info3347223943-1412650", 203747, 4917},
  {"Info3347223943-9876552", 203865, 4920},
  {"Info3347223943-9911280", 203984, 4923},
  {"Info3347223943-6335135", 204102, 4926},
  {"Info3347223943-9595876", 204220, 4929},
  {"Info3347223943-5396991", 204339, 4932},
  {"Info3347223943-6581954", 204457, 4935},
  {"Info3347223943-8464511", 204575, 4938},
  {"Info3347223943-4874601", 204695, 4941},
  {"Info3347223943-5629661", 204814, 4944},
  {"Info3347223943-4925532", 204935, 4947},
  {"Info3347223943-5246270", 205053, 4950},
  {"Info3347223943-1445452", 205174, 4953},
  {"Info3347223943-4450436", 205292, 4956},
  {"Info3347223943-3881981", 205410, 4959},
  {"Info3347223943-7228078", 205528, 4962},
  {"Info3347223943-4602624", 205646, 4965},
  {"Info3347223943-8450963", 205765, 4968},
  {"Info3347223943-6220742", 205883, 4971},
  {"Info3347223943-7000860", 206002, 4974},
  {"Info3347223943-5567665", 206120, 4977},
  {"Info3347223943-5586590", 206238, 4980},
  {"Info3347223943-2736516", 206356, 4983},
  {"Info3347223943-4561819", 206474, 4986},
  {"Info3347223943-9200808", 206592, 4989},
  {"Info3347223943-4835101", 206710, 4992},
  {"Info3347223943-7355272", 206828, 4995},
  {"Info3347223943-1181112", 206946, 4998},
  {"Info3347223943-2215272", 207064, 5001},
  {"Info3347223943-1923535", 207182, 5004},
  {"Info3347223943-8093696", 207300, 5007},
  {"Info3347223943-6910008", 207418, 5010},
  {"Info3347223943-1493678", 207536, 5013},
  {"Info3347223943-3117515", 207654, 5016},
  {"Info3347223943-4832411", 207772, 5019},
  {"Info3347223943-8404433", 207890, 5022},
  {"Info3347223943-7328827", 208008, 5025},
  {"Info3347223943-4746551", 208126, 5028},
  {"Info3347223943-8409741", 208244, 5031},
  {"Info3347223943-8817053", 208362, 5034},
  {"Info3347223943-3716282", 208480, 5037},
  {"Info3347223943-8999170", 208598, 5040},
  {"Info3347223943-5709094", 208716, 5043},
  {"Info3347223943-3657880", 208834, 5046},
  {"Info3347223943-6348310", 208952, 5049},
  {"Info3347223943-5622619", 209070, 5052},
  {"Info3347223943-3212639", 209188, 5055},
  {"Info3347223944-7593278", 209307, 5058},
  {"Info3347223944-1223543", 209425, 5061},
  {"Info3347223944-6433330", 209543, 5064},
  {"Info3347223944-8548286", 209662, 5067},
  {"Info3347223944-5636726", 209780, 5070},
  {"Info3347223944-6212195", 209898, 5073},
  {"Info3347223944-2446185", 210019, 5076},
  {"Info3347223944-4819550", 210138, 5079},
  {"Info3347223944-6414604", 210258, 5082},
  {"Info3347223944-6619072", 210377, 5085},
  {"Info3347223944-4082389", 210497, 5088},
  {"Info3347223944-3243349", 210615, 5091},
  {"Info3347223944-9833440", 210733, 5094},
  {"Info3347223944-9033299", 210851, 5097},
  {"Info3347223944-7106424", 210969, 5100},
  {"Info3347223944-2091162", 211087, 5103},
  {"Info3347223944-1590385", 211205, 5106},
  {"Info3347223944-5449929", 211323, 5109},
  {"Info3347223944-5484391", 211441, 5112},
  {"Info3347223944-8026549", 211559, 5115},
  {"Info3347223944-6509291", 211678, 5118},
  {"Info3347223944-9854803", 211796, 5121},
  {"Info3347223944-4587203", 211916, 5124},
  {"Info3347223944-6627152", 212034, 5127},
  {"Info3347223944-9677027", 212152, 5130},
  {"Info3347223944-7882672", 212270, 5133},
  {"Info3347223944-5172316", 212388, 5136},
  {"Info3347223944-1205732", 212506, 5139},
  {"Info3347223944-8443384", 212624, 5142},
  {"Info3347223944-8424884", 212742, 5145},
  {"Info3347223944-9112071", 212860, 5148},
  {"Info3347223944-5725100", 212978, 5151},
  {"Info3347223944-3763668", 213096, 5154},
  {"Info3347223944-5023528", 213214, 5157},
  {"Info3347223944-6332496", 213332, 5160},
  {"Info3347223944-1601766", 213450, 5163},
  {"Info3347223944-9984544", 213568, 5166},
  {"Info3347223944-8912656", 213686, 5169},
  {"Info3347223944-6144805", 213804, 5172},
  {"Info3347223944-4339604", 213922, 5175},
  {"Info3347223944-7164196", 214040, 5178},
  {"Info3347223944-7748027", 214158, 5181},
  {"Info3347223944-7495296", 214276, 5184},
  {"Info3347223944-8982714", 214394, 5187},
  {"Info3347223944-8993898", 214512, 5190},
  {"Info3347223944-1732994", 214630, 5193},
  {"Info3347223944-1385772", 214748, 5196},
  {"Info3347223944-8600115", 214866, 5199}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 215, 6, 183, "Subtitle"],

Cell[CellGroupData[{
Cell[2016, 63, 41, 0, 59, "Section"],
Cell[2060, 65, 1650, 28, 432, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3747, 98, 84, 2, 59, "Section"],
Cell[3834, 102, 172, 3, 44, "Print",
  CellTags->"Info3347223940-6631621"],
Cell[4009, 107, 174, 3, 44, "Print",
  CellTags->"Info3347223940-4294206"],
Cell[4186, 112, 359, 5, 82, "Print",
  CellTags->"Info3347223940-6810511"],
Cell[4548, 119, 145, 3, 25, "Print",
  CellTags->"Info3347223940-7389295"],
Cell[4696, 124, 126, 2, 25, "Print",
  CellTags->"Info3347223940-2382490"],
Cell[4825, 128, 135, 3, 25, "Print",
  CellTags->"Info3347223940-6023529"],
Cell[4963, 133, 116, 2, 25, "Print",
  CellTags->"Info3347223940-6503571"],
Cell[5082, 137, 123, 2, 25, "Print",
  CellTags->"Info3347223940-5379615"],
Cell[5208, 141, 154, 3, 25, "Print",
  CellTags->"Info3347223940-1834069"],
Cell[5365, 146, 249, 4, 44, "Print",
  CellTags->"Info3347223940-7924268"],
Cell[5617, 152, 148, 3, 25, "Print",
  CellTags->"Info3347223940-7939632"],
Cell[5768, 157, 275, 4, 63, "Print",
  CellTags->"Info3347223940-6833855"],
Cell[6046, 163, 143, 3, 25, "Print",
  CellTags->"Info3347223940-1189387"],
Cell[6192, 168, 67, 1, 25, "Print",
  CellTags->"Info3347223940-1293541"],
Cell[6262, 171, 568, 15, 25, "Print",
  CellTags->"Info3347223940-1293541"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6867, 191, 98, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[6990, 197, 108, 2, 47, "Subsection"],
Cell[7101, 201, 786, 11, 234, "Print",
  CellTags->"Info3347223940-8692552"],
Cell[7890, 214, 377, 6, 82, "Print",
  CellTags->"Info3347223940-9972450"],
Cell[8270, 222, 349, 5, 101, "Print",
  CellTags->"Info3347223940-4605738"],
Cell[8622, 229, 248, 4, 63, "Print",
  CellTags->"Info3347223940-4732625"],
Cell[8873, 235, 732, 10, 215, "Print",
  CellTags->"Info3347223940-4167237"],
Cell[9608, 247, 643, 9, 177, "Print",
  CellTags->"Info3347223940-9087758"],
Cell[10254, 258, 697, 10, 158, "Print",
  CellTags->"Info3347223940-5926772"],
Cell[10954, 270, 553, 8, 139, "Print",
  CellTags->"Info3347223940-8501482"],
Cell[11510, 280, 166, 3, 25, "Print",
  CellTags->"Info3347223940-7144037"],
Cell[11679, 285, 167, 3, 44, "Print",
  CellTags->"Info3347223940-2011507"],
Cell[11849, 290, 163, 3, 25, "Print",
  CellTags->"Info3347223940-6339513"],
Cell[12015, 295, 163, 3, 25, "Print",
  CellTags->"Info3347223940-5174597"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12215, 303, 95, 2, 47, "Subsection"],
Cell[12313, 307, 558, 8, 139, "Print",
  CellTags->"Info3347223940-1062849"],
Cell[12874, 317, 183, 3, 44, "Print",
  CellTags->"Info3347223940-3542961"],
Cell[13060, 322, 157, 3, 44, "Print",
  CellTags->"Info3347223940-1600426"],
Cell[13220, 327, 271, 4, 82, "Print",
  CellTags->"Info3347223940-4337716"],
Cell[13494, 333, 583, 9, 158, "Print",
  CellTags->"Info3347223941-1813366"],
Cell[14080, 344, 273, 4, 82, "Print",
  CellTags->"Info3347223941-1118594"],
Cell[14356, 350, 212, 4, 44, "Print",
  CellTags->"Info3347223941-5737972"],
Cell[14571, 356, 236, 4, 44, "Print",
  CellTags->"Info3347223941-7410441"],
Cell[14810, 362, 289, 5, 82, "Print",
  CellTags->"Info3347223941-8640170"],
Cell[15102, 369, 203, 3, 44, "Print",
  CellTags->"Info3347223941-1951187"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15342, 377, 105, 2, 47, "Subsection"],
Cell[15450, 381, 192, 3, 63, "Print",
  CellTags->"Info3347223941-8197922"],
Cell[15645, 386, 261, 4, 63, "Print",
  CellTags->"Info3347223941-2611265"],
Cell[15909, 392, 182, 3, 44, "Print",
  CellTags->"Info3347223941-9442840"],
Cell[16094, 397, 173, 3, 44, "Print",
  CellTags->"Info3347223941-7245219"],
Cell[16270, 402, 182, 3, 44, "Print",
  CellTags->"Info3347223941-5798128"],
Cell[16455, 407, 805, 11, 215, "Print",
  CellTags->"Info3347223941-1459018"],
Cell[17263, 420, 485, 7, 139, "Print",
  CellTags->"Info3347223941-1589458"],
Cell[17751, 429, 403, 6, 82, "Print",
  CellTags->"Info3347223941-8534708"],
Cell[18157, 437, 716, 10, 196, "Print",
  CellTags->"Info3347223941-7553760"],
Cell[18876, 449, 121, 2, 25, "Print",
  CellTags->"Info3347223941-9188284"],
Cell[19000, 453, 139, 3, 25, "Print",
  CellTags->"Info3347223941-7542695"],
Cell[19142, 458, 134, 3, 25, "Print",
  CellTags->"Info3347223941-2715154"],
Cell[19279, 463, 124, 2, 25, "Print",
  CellTags->"Info3347223941-2795720"],
Cell[19406, 467, 132, 3, 25, "Print",
  CellTags->"Info3347223941-9823357"],
Cell[19541, 472, 153, 3, 25, "Print",
  CellTags->"Info3347223941-8020983"],
Cell[19697, 477, 666, 9, 158, "Print",
  CellTags->"Info3347223941-4999920"],
Cell[20366, 488, 244, 4, 44, "Print",
  CellTags->"Info3347223941-6637905"],
Cell[20613, 494, 248, 4, 63, "Print",
  CellTags->"Info3347223941-9601905"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20898, 503, 89, 2, 47, "Subsection"],
Cell[20990, 507, 494, 7, 158, "Print",
  CellTags->"Info3347223941-1464798"],
Cell[21487, 516, 442, 7, 139, "Print",
  CellTags->"Info3347223941-1770110"],
Cell[21932, 525, 437, 7, 120, "Print",
  CellTags->"Info3347223941-2471642"],
Cell[22372, 534, 437, 7, 139, "Print",
  CellTags->"Info3347223941-7586356"],
Cell[22812, 543, 362, 5, 120, "Print",
  CellTags->"Info3347223941-4155620"],
Cell[23177, 550, 431, 6, 120, "Print",
  CellTags->"Info3347223941-3197855"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23645, 561, 89, 2, 47, "Subsection"],
Cell[23737, 565, 303, 5, 63, "Print",
  CellTags->"Info3347223941-8920274"],
Cell[24043, 572, 110, 2, 25, "Print",
  CellTags->"Info3347223941-2580618"],
Cell[24156, 576, 128, 2, 25, "Print",
  CellTags->"Info3347223941-5009207"],
Cell[24287, 580, 103, 2, 25, "Print",
  CellTags->"Info3347223941-1486463"],
Cell[24393, 584, 139, 3, 25, "Print",
  CellTags->"Info3347223941-2487122"],
Cell[24535, 589, 149, 3, 25, "Print",
  CellTags->"Info3347223941-6450972"],
Cell[24687, 594, 175, 3, 44, "Print",
  CellTags->"Info3347223941-4162216"],
Cell[24865, 599, 109, 2, 25, "Print",
  CellTags->"Info3347223941-6354640"],
Cell[24977, 603, 111, 2, 25, "Print",
  CellTags->"Info3347223941-5746827"],
Cell[25091, 607, 296, 5, 82, "Print",
  CellTags->"Info3347223941-2691935"],
Cell[25390, 614, 114, 2, 25, "Print",
  CellTags->"Info3347223941-7877067"],
Cell[25507, 618, 141, 3, 25, "Print",
  CellTags->"Info3347223941-7749989"],
Cell[25651, 623, 114, 2, 25, "Print",
  CellTags->"Info3347223941-3231106"],
Cell[25768, 627, 241, 4, 44, "Print",
  CellTags->"Info3347223941-3377092"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26046, 636, 88, 2, 47, "Subsection"],
Cell[26137, 640, 370, 6, 101, "Print",
  CellTags->"Info3347223941-4876077"],
Cell[26510, 648, 150, 3, 25, "Print",
  CellTags->"Info3347223941-3439479"],
Cell[26663, 653, 275, 4, 63, "Print",
  CellTags->"Info3347223941-7653090"],
Cell[26941, 659, 162, 3, 25, "Print",
  CellTags->"Info3347223941-7874582"],
Cell[27106, 664, 1033, 14, 234, "Print",
  CellTags->"Info3347223941-5235115"],
Cell[28142, 680, 165, 3, 25, "Print",
  CellTags->"Info3347223941-7704576"],
Cell[28310, 685, 114, 2, 25, "Print",
  CellTags->"Info3347223941-4043808"],
Cell[28427, 689, 228, 4, 44, "Print",
  CellTags->"Info3347223941-3418109"],
Cell[28658, 695, 276, 4, 63, "Print",
  CellTags->"Info3347223941-6580237"],
Cell[28937, 701, 289, 5, 63, "Print",
  CellTags->"Info3347223941-6852624"],
Cell[29229, 708, 414, 6, 158, "Print",
  CellTags->"Info3347223941-1422078"],
Cell[29646, 716, 500, 7, 101, "Print",
  CellTags->"Info3347223941-2029304"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30195, 729, 93, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[30313, 735, 108, 2, 47, "Subsection"],
Cell[30424, 739, 1018, 14, 272, "Print",
  CellTags->"Info3347223941-8989917"],
Cell[31445, 755, 388, 6, 82, "Print",
  CellTags->"Info3347223941-3552733"],
Cell[31836, 763, 358, 6, 101, "Print",
  CellTags->"Info3347223941-6176457"],
Cell[32197, 771, 252, 4, 63, "Print",
  CellTags->"Info3347223941-8109493"],
Cell[32452, 777, 793, 11, 253, "Print",
  CellTags->"Info3347223941-6089851"],
Cell[33248, 790, 659, 10, 177, "Print",
  CellTags->"Info3347223941-7134049"],
Cell[33910, 802, 704, 10, 177, "Print",
  CellTags->"Info3347223941-7244468"],
Cell[34617, 814, 558, 8, 158, "Print",
  CellTags->"Info3347223941-4415755"],
Cell[35178, 824, 166, 3, 25, "Print",
  CellTags->"Info3347223941-9094170"],
Cell[35347, 829, 167, 3, 44, "Print",
  CellTags->"Info3347223941-3611725"],
Cell[35517, 834, 163, 3, 25, "Print",
  CellTags->"Info3347223941-9967462"],
Cell[35683, 839, 163, 3, 25, "Print",
  CellTags->"Info3347223941-4309295"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35883, 847, 95, 2, 47, "Subsection"],
Cell[35981, 851, 558, 8, 139, "Print",
  CellTags->"Info3347223941-8260624"],
Cell[36542, 861, 183, 3, 44, "Print",
  CellTags->"Info3347223941-8492284"],
Cell[36728, 866, 157, 3, 44, "Print",
  CellTags->"Info3347223941-8438704"],
Cell[36888, 871, 271, 4, 82, "Print",
  CellTags->"Info3347223941-3285558"],
Cell[37162, 877, 576, 8, 139, "Print",
  CellTags->"Info3347223941-1354509"],
Cell[37741, 887, 273, 4, 82, "Print",
  CellTags->"Info3347223941-1355904"],
Cell[38017, 893, 212, 4, 44, "Print",
  CellTags->"Info3347223941-8370622"],
Cell[38232, 899, 236, 4, 44, "Print",
  CellTags->"Info3347223941-2291614"],
Cell[38471, 905, 289, 5, 82, "Print",
  CellTags->"Info3347223941-7771765"],
Cell[38763, 912, 203, 3, 44, "Print",
  CellTags->"Info3347223941-7568170"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39003, 920, 105, 2, 47, "Subsection"],
Cell[39111, 924, 192, 3, 63, "Print",
  CellTags->"Info3347223941-5343679"],
Cell[39306, 929, 261, 4, 63, "Print",
  CellTags->"Info3347223941-5864838"],
Cell[39570, 935, 182, 3, 44, "Print",
  CellTags->"Info3347223941-7809650"],
Cell[39755, 940, 173, 3, 44, "Print",
  CellTags->"Info3347223941-2458221"],
Cell[39931, 945, 182, 3, 44, "Print",
  CellTags->"Info3347223941-1974298"],
Cell[40116, 950, 805, 11, 215, "Print",
  CellTags->"Info3347223941-7595909"],
Cell[40924, 963, 485, 7, 139, "Print",
  CellTags->"Info3347223941-2077596"],
Cell[41412, 972, 403, 6, 82, "Print",
  CellTags->"Info3347223941-6833115"],
Cell[41818, 980, 716, 10, 196, "Print",
  CellTags->"Info3347223941-8415350"],
Cell[42537, 992, 121, 2, 25, "Print",
  CellTags->"Info3347223941-7920837"],
Cell[42661, 996, 139, 3, 25, "Print",
  CellTags->"Info3347223941-5070483"],
Cell[42803, 1001, 134, 3, 25, "Print",
  CellTags->"Info3347223941-1032206"],
Cell[42940, 1006, 124, 2, 25, "Print",
  CellTags->"Info3347223941-1376349"],
Cell[43067, 1010, 132, 3, 25, "Print",
  CellTags->"Info3347223941-7407861"],
Cell[43202, 1015, 153, 3, 25, "Print",
  CellTags->"Info3347223941-2948475"],
Cell[43358, 1020, 666, 9, 158, "Print",
  CellTags->"Info3347223941-8742318"],
Cell[44027, 1031, 244, 4, 44, "Print",
  CellTags->"Info3347223941-9656730"],
Cell[44274, 1037, 248, 4, 63, "Print",
  CellTags->"Info3347223941-1145073"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44559, 1046, 89, 2, 47, "Subsection"],
Cell[44651, 1050, 494, 7, 158, "Print",
  CellTags->"Info3347223941-4193583"],
Cell[45148, 1059, 442, 7, 139, "Print",
  CellTags->"Info3347223941-6993551"],
Cell[45593, 1068, 437, 7, 120, "Print",
  CellTags->"Info3347223941-6453383"],
Cell[46033, 1077, 437, 7, 139, "Print",
  CellTags->"Info3347223941-7559587"],
Cell[46473, 1086, 362, 5, 120, "Print",
  CellTags->"Info3347223941-5358822"],
Cell[46838, 1093, 431, 6, 120, "Print",
  CellTags->"Info3347223941-6682568"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47306, 1104, 89, 2, 47, "Subsection"],
Cell[47398, 1108, 303, 5, 63, "Print",
  CellTags->"Info3347223941-3512651"],
Cell[47704, 1115, 110, 2, 25, "Print",
  CellTags->"Info3347223941-8850662"],
Cell[47817, 1119, 123, 2, 25, "Print",
  CellTags->"Info3347223941-7730051"],
Cell[47943, 1123, 103, 2, 25, "Print",
  CellTags->"Info3347223941-2942451"],
Cell[48049, 1127, 139, 3, 25, "Print",
  CellTags->"Info3347223941-3089129"],
Cell[48191, 1132, 149, 3, 25, "Print",
  CellTags->"Info3347223941-3186031"],
Cell[48343, 1137, 175, 3, 44, "Print",
  CellTags->"Info3347223941-4802215"],
Cell[48521, 1142, 109, 2, 25, "Print",
  CellTags->"Info3347223941-8163804"],
Cell[48633, 1146, 111, 2, 25, "Print",
  CellTags->"Info3347223941-6931229"],
Cell[48747, 1150, 296, 5, 82, "Print",
  CellTags->"Info3347223941-9964984"],
Cell[49046, 1157, 114, 2, 25, "Print",
  CellTags->"Info3347223941-4270299"],
Cell[49163, 1161, 141, 3, 25, "Print",
  CellTags->"Info3347223941-7308454"],
Cell[49307, 1166, 114, 2, 25, "Print",
  CellTags->"Info3347223941-7750860"],
Cell[49424, 1170, 236, 4, 44, "Print",
  CellTags->"Info3347223941-3895549"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49697, 1179, 88, 2, 47, "Subsection"],
Cell[49788, 1183, 365, 6, 101, "Print",
  CellTags->"Info3347223941-4236356"],
Cell[50156, 1191, 150, 3, 25, "Print",
  CellTags->"Info3347223941-2245144"],
Cell[50309, 1196, 275, 4, 63, "Print",
  CellTags->"Info3347223941-8159017"],
Cell[50587, 1202, 162, 3, 25, "Print",
  CellTags->"Info3347223941-8125029"],
Cell[50752, 1207, 1033, 14, 234, "Print",
  CellTags->"Info3347223941-5725470"],
Cell[51788, 1223, 165, 3, 25, "Print",
  CellTags->"Info3347223941-8114379"],
Cell[51956, 1228, 114, 2, 25, "Print",
  CellTags->"Info3347223941-7760450"],
Cell[52073, 1232, 228, 4, 44, "Print",
  CellTags->"Info3347223941-7609199"],
Cell[52304, 1238, 276, 4, 63, "Print",
  CellTags->"Info3347223941-8492301"],
Cell[52583, 1244, 289, 5, 63, "Print",
  CellTags->"Info3347223941-8350572"],
Cell[52875, 1251, 414, 6, 158, "Print",
  CellTags->"Info3347223941-7702967"],
Cell[53292, 1259, 490, 7, 101, "Print",
  CellTags->"Info3347223941-7628927"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53831, 1272, 98, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[53954, 1278, 108, 2, 47, "Subsection"],
Cell[54065, 1282, 799, 11, 234, "Print",
  CellTags->"Info3347223941-2550021"],
Cell[54867, 1295, 378, 6, 82, "Print",
  CellTags->"Info3347223941-9246453"],
Cell[55248, 1303, 565, 8, 158, "Print",
  CellTags->"Info3347223941-6719514"],
Cell[55816, 1313, 248, 4, 63, "Print",
  CellTags->"Info3347223941-3075263"],
Cell[56067, 1319, 745, 10, 234, "Print",
  CellTags->"Info3347223941-1794145"],
Cell[56815, 1331, 645, 9, 177, "Print",
  CellTags->"Info3347223941-2809827"],
Cell[57463, 1342, 922, 13, 253, "Print",
  CellTags->"Info3347223941-3602638"],
Cell[58388, 1357, 546, 8, 158, "Print",
  CellTags->"Info3347223941-4062804"],
Cell[58937, 1367, 166, 3, 25, "Print",
  CellTags->"Info3347223941-8484718"],
Cell[59106, 1372, 167, 3, 44, "Print",
  CellTags->"Info3347223941-8368394"],
Cell[59276, 1377, 163, 3, 25, "Print",
  CellTags->"Info3347223941-5771336"],
Cell[59442, 1382, 163, 3, 25, "Print",
  CellTags->"Info3347223941-5718574"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59642, 1390, 95, 2, 47, "Subsection"],
Cell[59740, 1394, 558, 8, 139, "Print",
  CellTags->"Info3347223941-9029670"],
Cell[60301, 1404, 183, 3, 44, "Print",
  CellTags->"Info3347223941-8579298"],
Cell[60487, 1409, 157, 3, 44, "Print",
  CellTags->"Info3347223941-4116126"],
Cell[60647, 1414, 271, 4, 82, "Print",
  CellTags->"Info3347223942-6124645"],
Cell[60921, 1420, 574, 8, 139, "Print",
  CellTags->"Info3347223942-3619064"],
Cell[61498, 1430, 273, 4, 82, "Print",
  CellTags->"Info3347223942-4004828"],
Cell[61774, 1436, 212, 4, 44, "Print",
  CellTags->"Info3347223942-3596063"],
Cell[61989, 1442, 236, 4, 44, "Print",
  CellTags->"Info3347223942-5797197"],
Cell[62228, 1448, 289, 5, 82, "Print",
  CellTags->"Info3347223942-2688418"],
Cell[62520, 1455, 203, 3, 44, "Print",
  CellTags->"Info3347223942-4889550"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62760, 1463, 105, 2, 47, "Subsection"],
Cell[62868, 1467, 192, 3, 63, "Print",
  CellTags->"Info3347223942-4775645"],
Cell[63063, 1472, 261, 4, 63, "Print",
  CellTags->"Info3347223942-9433219"],
Cell[63327, 1478, 182, 3, 44, "Print",
  CellTags->"Info3347223942-1224636"],
Cell[63512, 1483, 173, 3, 44, "Print",
  CellTags->"Info3347223942-4362745"],
Cell[63688, 1488, 182, 3, 44, "Print",
  CellTags->"Info3347223942-3956808"],
Cell[63873, 1493, 805, 11, 215, "Print",
  CellTags->"Info3347223942-7340812"],
Cell[64681, 1506, 485, 7, 139, "Print",
  CellTags->"Info3347223942-7747929"],
Cell[65169, 1515, 403, 6, 82, "Print",
  CellTags->"Info3347223942-1072148"],
Cell[65575, 1523, 716, 10, 196, "Print",
  CellTags->"Info3347223942-4833943"],
Cell[66294, 1535, 121, 2, 25, "Print",
  CellTags->"Info3347223942-3215298"],
Cell[66418, 1539, 139, 3, 25, "Print",
  CellTags->"Info3347223942-3062770"],
Cell[66560, 1544, 134, 3, 25, "Print",
  CellTags->"Info3347223942-1478151"],
Cell[66697, 1549, 124, 2, 25, "Print",
  CellTags->"Info3347223942-4873634"],
Cell[66824, 1553, 132, 3, 25, "Print",
  CellTags->"Info3347223942-1405457"],
Cell[66959, 1558, 153, 3, 25, "Print",
  CellTags->"Info3347223942-3777925"],
Cell[67115, 1563, 666, 9, 158, "Print",
  CellTags->"Info3347223942-2152760"],
Cell[67784, 1574, 244, 4, 44, "Print",
  CellTags->"Info3347223942-5073193"],
Cell[68031, 1580, 248, 4, 63, "Print",
  CellTags->"Info3347223942-3551327"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68316, 1589, 89, 2, 47, "Subsection"],
Cell[68408, 1593, 494, 7, 158, "Print",
  CellTags->"Info3347223942-9096541"],
Cell[68905, 1602, 442, 7, 139, "Print",
  CellTags->"Info3347223942-2626858"],
Cell[69350, 1611, 437, 7, 120, "Print",
  CellTags->"Info3347223942-9568268"],
Cell[69790, 1620, 437, 7, 139, "Print",
  CellTags->"Info3347223942-6949674"],
Cell[70230, 1629, 362, 5, 120, "Print",
  CellTags->"Info3347223942-3601001"],
Cell[70595, 1636, 431, 6, 120, "Print",
  CellTags->"Info3347223942-6609419"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71063, 1647, 89, 2, 47, "Subsection"],
Cell[71155, 1651, 303, 5, 63, "Print",
  CellTags->"Info3347223942-9958241"],
Cell[71461, 1658, 110, 2, 25, "Print",
  CellTags->"Info3347223942-7543440"],
Cell[71574, 1662, 121, 2, 25, "Print",
  CellTags->"Info3347223942-5025554"],
Cell[71698, 1666, 103, 2, 25, "Print",
  CellTags->"Info3347223942-6965775"],
Cell[71804, 1670, 139, 3, 25, "Print",
  CellTags->"Info3347223942-3888279"],
Cell[71946, 1675, 149, 3, 25, "Print",
  CellTags->"Info3347223942-5334754"],
Cell[72098, 1680, 175, 3, 44, "Print",
  CellTags->"Info3347223942-2217087"],
Cell[72276, 1685, 109, 2, 25, "Print",
  CellTags->"Info3347223942-6944643"],
Cell[72388, 1689, 111, 2, 25, "Print",
  CellTags->"Info3347223942-3967660"],
Cell[72502, 1693, 296, 5, 82, "Print",
  CellTags->"Info3347223942-9812128"],
Cell[72801, 1700, 114, 2, 25, "Print",
  CellTags->"Info3347223942-9428271"],
Cell[72918, 1704, 141, 3, 25, "Print",
  CellTags->"Info3347223942-5196408"],
Cell[73062, 1709, 114, 2, 25, "Print",
  CellTags->"Info3347223942-3765753"],
Cell[73179, 1713, 234, 4, 44, "Print",
  CellTags->"Info3347223942-7435369"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73450, 1722, 88, 2, 47, "Subsection"],
Cell[73541, 1726, 361, 5, 101, "Print",
  CellTags->"Info3347223942-9408926"],
Cell[73905, 1733, 150, 3, 25, "Print",
  CellTags->"Info3347223942-8756152"],
Cell[74058, 1738, 275, 4, 63, "Print",
  CellTags->"Info3347223942-5512214"],
Cell[74336, 1744, 162, 3, 25, "Print",
  CellTags->"Info3347223942-4592327"],
Cell[74501, 1749, 1114, 15, 253, "Print",
  CellTags->"Info3347223942-2467846"],
Cell[75618, 1766, 165, 3, 25, "Print",
  CellTags->"Info3347223942-6619667"],
Cell[75786, 1771, 114, 2, 25, "Print",
  CellTags->"Info3347223942-8743872"],
Cell[75903, 1775, 228, 4, 44, "Print",
  CellTags->"Info3347223942-7645405"],
Cell[76134, 1781, 276, 4, 63, "Print",
  CellTags->"Info3347223942-9313603"],
Cell[76413, 1787, 289, 5, 63, "Print",
  CellTags->"Info3347223942-6658559"],
Cell[76705, 1794, 414, 6, 158, "Print",
  CellTags->"Info3347223942-2489674"],
Cell[77122, 1802, 486, 7, 101, "Print",
  CellTags->"Info3347223942-2698508"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[77657, 1815, 93, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[77775, 1821, 108, 2, 47, "Subsection"],
Cell[77886, 1825, 1031, 14, 291, "Print",
  CellTags->"Info3347223942-1174016"],
Cell[78920, 1841, 357, 6, 82, "Print",
  CellTags->"Info3347223942-3337860"],
Cell[79280, 1849, 1427, 20, 386, "Print",
  CellTags->"Info3347223942-7875248"],
Cell[80710, 1871, 259, 4, 63, "Print",
  CellTags->"Info3347223942-3565351"],
Cell[80972, 1877, 205, 3, 44, "Print",
  CellTags->"Info3347223942-9575072"],
Cell[81180, 1882, 198, 3, 44, "Print",
  CellTags->"Info3347223942-1161328"],
Cell[81381, 1887, 348, 5, 82, "Print",
  CellTags->"Info3347223942-6641394"],
Cell[81732, 1894, 946, 13, 405, "Print",
  CellTags->"Info3347223942-3253559"],
Cell[82681, 1909, 584, 8, 158, "Print",
  CellTags->"Info3347223942-5222545"],
Cell[83268, 1919, 233, 4, 44, "Print",
  CellTags->"Info3347223942-6345755"],
Cell[83504, 1925, 1165, 16, 329, "Print",
  CellTags->"Info3347223942-3683202"],
Cell[84672, 1943, 598, 9, 177, "Print",
  CellTags->"Info3347223942-7858990"],
Cell[85273, 1954, 166, 3, 25, "Print",
  CellTags->"Info3347223942-3699623"],
Cell[85442, 1959, 159, 3, 25, "Print",
  CellTags->"Info3347223942-4895320"],
Cell[85604, 1964, 163, 3, 25, "Print",
  CellTags->"Info3347223942-9354952"],
Cell[85770, 1969, 163, 3, 25, "Print",
  CellTags->"Info3347223942-8866994"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85970, 1977, 95, 2, 47, "Subsection"],
Cell[86068, 1981, 558, 8, 139, "Print",
  CellTags->"Info3347223942-7974690"],
Cell[86629, 1991, 183, 3, 44, "Print",
  CellTags->"Info3347223942-7718741"],
Cell[86815, 1996, 157, 3, 44, "Print",
  CellTags->"Info3347223942-6265237"],
Cell[86975, 2001, 271, 4, 82, "Print",
  CellTags->"Info3347223942-2127838"],
Cell[87249, 2007, 583, 9, 158, "Print",
  CellTags->"Info3347223942-8061335"],
Cell[87835, 2018, 273, 4, 82, "Print",
  CellTags->"Info3347223942-2612802"],
Cell[88111, 2024, 212, 4, 44, "Print",
  CellTags->"Info3347223942-3525955"],
Cell[88326, 2030, 236, 4, 44, "Print",
  CellTags->"Info3347223942-9298280"],
Cell[88565, 2036, 289, 5, 82, "Print",
  CellTags->"Info3347223942-3205867"],
Cell[88857, 2043, 203, 3, 44, "Print",
  CellTags->"Info3347223942-2715408"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89097, 2051, 105, 2, 47, "Subsection"],
Cell[89205, 2055, 192, 3, 63, "Print",
  CellTags->"Info3347223942-1902193"],
Cell[89400, 2060, 261, 4, 63, "Print",
  CellTags->"Info3347223942-6712612"],
Cell[89664, 2066, 182, 3, 44, "Print",
  CellTags->"Info3347223942-4802586"],
Cell[89849, 2071, 173, 3, 44, "Print",
  CellTags->"Info3347223942-6636810"],
Cell[90025, 2076, 182, 3, 44, "Print",
  CellTags->"Info3347223942-4840162"],
Cell[90210, 2081, 415, 6, 120, "Print",
  CellTags->"Info3347223942-7491570"],
Cell[90628, 2089, 791, 11, 215, "Print",
  CellTags->"Info3347223942-1473756"],
Cell[91422, 2102, 199, 3, 44, "Print",
  CellTags->"Info3347223942-1735460"],
Cell[91624, 2107, 578, 8, 158, "Print",
  CellTags->"Info3347223942-2227327"],
Cell[92205, 2117, 121, 2, 25, "Print",
  CellTags->"Info3347223942-4747170"],
Cell[92329, 2121, 139, 3, 25, "Print",
  CellTags->"Info3347223942-2286321"],
Cell[92471, 2126, 134, 3, 25, "Print",
  CellTags->"Info3347223942-8963834"],
Cell[92608, 2131, 124, 2, 25, "Print",
  CellTags->"Info3347223942-9305092"],
Cell[92735, 2135, 132, 3, 25, "Print",
  CellTags->"Info3347223942-6456408"],
Cell[92870, 2140, 153, 3, 25, "Print",
  CellTags->"Info3347223942-3630767"],
Cell[93026, 2145, 666, 9, 158, "Print",
  CellTags->"Info3347223942-8451424"],
Cell[93695, 2156, 244, 4, 44, "Print",
  CellTags->"Info3347223942-9036334"],
Cell[93942, 2162, 248, 4, 63, "Print",
  CellTags->"Info3347223942-8833736"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94227, 2171, 87, 2, 47, "Subsection"],
Cell[94317, 2175, 494, 7, 158, "Print",
  CellTags->"Info3347223942-7130020"],
Cell[94814, 2184, 442, 7, 139, "Print",
  CellTags->"Info3347223942-7499705"],
Cell[95259, 2193, 437, 7, 120, "Print",
  CellTags->"Info3347223942-7334860"],
Cell[95699, 2202, 437, 7, 139, "Print",
  CellTags->"Info3347223942-3929142"],
Cell[96139, 2211, 362, 5, 120, "Print",
  CellTags->"Info3347223942-4675478"],
Cell[96504, 2218, 431, 6, 120, "Print",
  CellTags->"Info3347223942-6544225"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96972, 2229, 89, 2, 47, "Subsection"],
Cell[97064, 2233, 303, 5, 63, "Print",
  CellTags->"Info3347223942-4841605"],
Cell[97370, 2240, 110, 2, 25, "Print",
  CellTags->"Info3347223942-6260931"],
Cell[97483, 2244, 128, 2, 25, "Print",
  CellTags->"Info3347223942-2933636"],
Cell[97614, 2248, 103, 2, 25, "Print",
  CellTags->"Info3347223942-6299238"],
Cell[97720, 2252, 139, 3, 25, "Print",
  CellTags->"Info3347223942-8455083"],
Cell[97862, 2257, 149, 3, 25, "Print",
  CellTags->"Info3347223942-2761304"],
Cell[98014, 2262, 175, 3, 44, "Print",
  CellTags->"Info3347223942-7582796"],
Cell[98192, 2267, 109, 2, 25, "Print",
  CellTags->"Info3347223942-3568316"],
Cell[98304, 2271, 111, 2, 25, "Print",
  CellTags->"Info3347223942-8381002"],
Cell[98418, 2275, 296, 5, 82, "Print",
  CellTags->"Info3347223942-6455526"],
Cell[98717, 2282, 114, 2, 25, "Print",
  CellTags->"Info3347223942-4808313"],
Cell[98834, 2286, 141, 3, 25, "Print",
  CellTags->"Info3347223942-2972084"],
Cell[98978, 2291, 114, 2, 25, "Print",
  CellTags->"Info3347223942-3404091"],
Cell[99095, 2295, 241, 4, 44, "Print",
  CellTags->"Info3347223942-5570118"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99373, 2304, 88, 2, 47, "Subsection"],
Cell[99464, 2308, 365, 6, 101, "Print",
  CellTags->"Info3347223942-9710485"],
Cell[99832, 2316, 150, 3, 25, "Print",
  CellTags->"Info3347223942-3212477"],
Cell[99985, 2321, 275, 4, 63, "Print",
  CellTags->"Info3347223942-7052201"],
Cell[100263, 2327, 162, 3, 25, "Print",
  CellTags->"Info3347223942-1274397"],
Cell[100428, 2332, 1125, 15, 272, "Print",
  CellTags->"Info3347223942-6291660"],
Cell[101556, 2349, 165, 3, 25, "Print",
  CellTags->"Info3347223942-1780589"],
Cell[101724, 2354, 114, 2, 25, "Print",
  CellTags->"Info3347223942-7289647"],
Cell[101841, 2358, 228, 4, 44, "Print",
  CellTags->"Info3347223942-3206676"],
Cell[102072, 2364, 276, 4, 63, "Print",
  CellTags->"Info3347223942-9428676"],
Cell[102351, 2370, 289, 5, 63, "Print",
  CellTags->"Info3347223942-7629229"],
Cell[102643, 2377, 414, 6, 158, "Print",
  CellTags->"Info3347223942-1442542"],
Cell[103060, 2385, 500, 7, 101, "Print",
  CellTags->"Info3347223942-1702933"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[103609, 2398, 99, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[103733, 2404, 104, 2, 47, "Subsection"],
Cell[103840, 2408, 255, 4, 63, "Print",
  CellTags->"Info3347223942-5078785"],
Cell[104098, 2414, 544, 8, 120, "Print",
  CellTags->"Info3347223942-1556017"],
Cell[104645, 2424, 126, 2, 25, "Print",
  CellTags->"Info3347223942-3937423"],
Cell[104774, 2428, 184, 3, 44, "Print",
  CellTags->"Info3347223942-1584120"],
Cell[104961, 2433, 494, 7, 120, "Print",
  CellTags->"Info3347223942-8122127"],
Cell[105458, 2442, 266, 4, 63, "Print",
  CellTags->"Info3347223942-6550982"],
Cell[105727, 2448, 122, 2, 25, "Print",
  CellTags->"Info3347223942-4006352"],
Cell[105852, 2452, 496, 7, 215, "Print",
  CellTags->"Info3347223943-7268328"],
Cell[106351, 2461, 417, 6, 177, "Print",
  CellTags->"Info3347223943-9145937"],
Cell[106771, 2469, 976, 13, 310, "Print",
  CellTags->"Info3347223943-9840448"],
Cell[107750, 2484, 312, 5, 63, "Print",
  CellTags->"Info3347223943-7986648"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108099, 2494, 84, 2, 47, "Subsection"],
Cell[108186, 2498, 657, 9, 234, "Print",
  CellTags->"Info3347223943-7429312"],
Cell[108846, 2509, 161, 3, 44, "Print",
  CellTags->"Info3347223943-7412679"],
Cell[109010, 2514, 214, 4, 63, "Print",
  CellTags->"Info3347223943-4063720"],
Cell[109227, 2520, 217, 4, 63, "Print",
  CellTags->"Info3347223943-2445563"],
Cell[109447, 2526, 203, 3, 63, "Print",
  CellTags->"Info3347223943-6984034"],
Cell[109653, 2531, 210, 4, 63, "Print",
  CellTags->"Info3347223943-7106080"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109900, 2540, 89, 2, 47, "Subsection"],
Cell[109992, 2544, 377, 6, 101, "Print",
  CellTags->"Info3347223943-3775443"],
Cell[110372, 2552, 137, 3, 25, "Print",
  CellTags->"Info3347223943-8151160"],
Cell[110512, 2557, 587, 8, 158, "Print",
  CellTags->"Info3347223943-8563191"],
Cell[111102, 2567, 137, 3, 25, "Print",
  CellTags->"Info3347223943-7693835"],
Cell[111242, 2572, 299, 5, 63, "Print",
  CellTags->"Info3347223943-2142348"],
Cell[111544, 2579, 110, 2, 25, "Print",
  CellTags->"Info3347223943-4698659"],
Cell[111657, 2583, 155, 3, 25, "Print",
  CellTags->"Info3347223943-1610739"],
Cell[111815, 2588, 103, 2, 25, "Print",
  CellTags->"Info3347223943-4515092"],
Cell[111921, 2592, 156, 3, 25, "Print",
  CellTags->"Info3347223943-2547445"],
Cell[112080, 2597, 149, 3, 25, "Print",
  CellTags->"Info3347223943-5690018"],
Cell[112232, 2602, 184, 3, 44, "Print",
  CellTags->"Info3347223943-2070076"],
Cell[112419, 2607, 150, 3, 25, "Print",
  CellTags->"Info3347223943-5398885"],
Cell[112572, 2612, 167, 3, 44, "Print",
  CellTags->"Info3347223943-3534432"],
Cell[112742, 2617, 230, 4, 44, "Print",
  CellTags->"Info3347223943-2811507"],
Cell[112975, 2623, 232, 4, 44, "Print",
  CellTags->"Info3347223943-3089526"],
Cell[113210, 2629, 109, 2, 25, "Print",
  CellTags->"Info3347223943-4050909"],
Cell[113322, 2633, 111, 2, 25, "Print",
  CellTags->"Info3347223943-2256146"],
Cell[113436, 2637, 296, 5, 82, "Print",
  CellTags->"Info3347223943-2578274"],
Cell[113735, 2644, 114, 2, 25, "Print",
  CellTags->"Info3347223943-1967258"],
Cell[113852, 2648, 141, 3, 25, "Print",
  CellTags->"Info3347223943-3803042"],
Cell[113996, 2653, 114, 2, 25, "Print",
  CellTags->"Info3347223943-8980657"],
Cell[114113, 2657, 114, 2, 25, "Print",
  CellTags->"Info3347223943-4021916"],
Cell[114230, 2661, 242, 4, 44, "Print",
  CellTags->"Info3347223943-4519082"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114509, 2670, 85, 2, 47, "Subsection"],
Cell[114597, 2674, 136, 3, 25, "Print",
  CellTags->"Info3347223943-1421647"],
Cell[114736, 2679, 244, 4, 44, "Print",
  CellTags->"Info3347223943-4876034"],
Cell[114983, 2685, 133, 3, 25, "Print",
  CellTags->"Info3347223943-4053978"],
Cell[115119, 2690, 276, 4, 63, "Print",
  CellTags->"Info3347223943-8562188"],
Cell[115398, 2696, 289, 5, 63, "Print",
  CellTags->"Info3347223943-7158326"],
Cell[115690, 2703, 233, 4, 44, "Print",
  CellTags->"Info3347223943-1889904"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[115972, 2713, 94, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[116091, 2719, 104, 2, 47, "Subsection"],
Cell[116198, 2723, 255, 4, 63, "Print",
  CellTags->"Info3347223943-5722087"],
Cell[116456, 2729, 544, 8, 120, "Print",
  CellTags->"Info3347223943-6066732"],
Cell[117003, 2739, 126, 2, 25, "Print",
  CellTags->"Info3347223943-7540695"],
Cell[117132, 2743, 184, 3, 44, "Print",
  CellTags->"Info3347223943-8356363"],
Cell[117319, 2748, 494, 7, 120, "Print",
  CellTags->"Info3347223943-2610039"],
Cell[117816, 2757, 266, 4, 63, "Print",
  CellTags->"Info3347223943-9333251"],
Cell[118085, 2763, 122, 2, 25, "Print",
  CellTags->"Info3347223943-5741528"],
Cell[118210, 2767, 429, 6, 177, "Print",
  CellTags->"Info3347223943-2058617"],
Cell[118642, 2775, 415, 6, 158, "Print",
  CellTags->"Info3347223943-6061612"],
Cell[119060, 2783, 1007, 14, 310, "Print",
  CellTags->"Info3347223943-5839947"],
Cell[120070, 2799, 319, 5, 63, "Print",
  CellTags->"Info3347223943-6964670"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120426, 2809, 84, 2, 47, "Subsection"],
Cell[120513, 2813, 640, 9, 215, "Print",
  CellTags->"Info3347223943-7045062"],
Cell[121156, 2824, 165, 3, 44, "Print",
  CellTags->"Info3347223943-3156769"],
Cell[121324, 2829, 212, 4, 63, "Print",
  CellTags->"Info3347223943-6001645"],
Cell[121539, 2835, 208, 3, 63, "Print",
  CellTags->"Info3347223943-4852106"],
Cell[121750, 2840, 213, 4, 63, "Print",
  CellTags->"Info3347223943-2532118"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122000, 2849, 89, 2, 47, "Subsection"],
Cell[122092, 2853, 377, 6, 101, "Print",
  CellTags->"Info3347223943-7067293"],
Cell[122472, 2861, 137, 3, 25, "Print",
  CellTags->"Info3347223943-9641375"],
Cell[122612, 2866, 591, 8, 158, "Print",
  CellTags->"Info3347223943-7839447"],
Cell[123206, 2876, 137, 3, 25, "Print",
  CellTags->"Info3347223943-3277276"],
Cell[123346, 2881, 299, 5, 63, "Print",
  CellTags->"Info3347223943-1779400"],
Cell[123648, 2888, 110, 2, 25, "Print",
  CellTags->"Info3347223943-8626447"],
Cell[123761, 2892, 150, 3, 25, "Print",
  CellTags->"Info3347223943-1614004"],
Cell[123914, 2897, 103, 2, 25, "Print",
  CellTags->"Info3347223943-1756910"],
Cell[124020, 2901, 151, 3, 25, "Print",
  CellTags->"Info3347223943-7953603"],
Cell[124174, 2906, 149, 3, 25, "Print",
  CellTags->"Info3347223943-7285242"],
Cell[124326, 2911, 179, 3, 44, "Print",
  CellTags->"Info3347223943-3710641"],
Cell[124508, 2916, 150, 3, 25, "Print",
  CellTags->"Info3347223943-6496722"],
Cell[124661, 2921, 162, 3, 25, "Print",
  CellTags->"Info3347223943-4583684"],
Cell[124826, 2926, 230, 4, 44, "Print",
  CellTags->"Info3347223943-5150566"],
Cell[125059, 2932, 232, 4, 44, "Print",
  CellTags->"Info3347223943-5115022"],
Cell[125294, 2938, 109, 2, 25, "Print",
  CellTags->"Info3347223943-6296956"],
Cell[125406, 2942, 111, 2, 25, "Print",
  CellTags->"Info3347223943-1006138"],
Cell[125520, 2946, 296, 5, 82, "Print",
  CellTags->"Info3347223943-3228834"],
Cell[125819, 2953, 114, 2, 25, "Print",
  CellTags->"Info3347223943-1888747"],
Cell[125936, 2957, 141, 3, 25, "Print",
  CellTags->"Info3347223943-7381528"],
Cell[126080, 2962, 114, 2, 25, "Print",
  CellTags->"Info3347223943-8122874"],
Cell[126197, 2966, 114, 2, 25, "Print",
  CellTags->"Info3347223943-6416613"],
Cell[126314, 2970, 237, 4, 44, "Print",
  CellTags->"Info3347223943-1079780"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126588, 2979, 85, 2, 47, "Subsection"],
Cell[126676, 2983, 136, 3, 25, "Print",
  CellTags->"Info3347223943-5972664"],
Cell[126815, 2988, 244, 4, 44, "Print",
  CellTags->"Info3347223943-4112961"],
Cell[127062, 2994, 126, 2, 25, "Print",
  CellTags->"Info3347223943-2709084"],
Cell[127191, 2998, 276, 4, 63, "Print",
  CellTags->"Info3347223943-8970379"],
Cell[127470, 3004, 289, 5, 63, "Print",
  CellTags->"Info3347223943-7602098"],
Cell[127762, 3011, 233, 4, 44, "Print",
  CellTags->"Info3347223943-2781622"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[128044, 3021, 97, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[128166, 3027, 104, 2, 47, "Subsection"],
Cell[128273, 3031, 255, 4, 63, "Print",
  CellTags->"Info3347223943-1412650"],
Cell[128531, 3037, 544, 8, 120, "Print",
  CellTags->"Info3347223943-9876552"],
Cell[129078, 3047, 126, 2, 25, "Print",
  CellTags->"Info3347223943-9911280"],
Cell[129207, 3051, 184, 3, 44, "Print",
  CellTags->"Info3347223943-6335135"],
Cell[129394, 3056, 494, 7, 120, "Print",
  CellTags->"Info3347223943-9595876"],
Cell[129891, 3065, 266, 4, 63, "Print",
  CellTags->"Info3347223943-5396991"],
Cell[130160, 3071, 122, 2, 25, "Print",
  CellTags->"Info3347223943-6581954"],
Cell[130285, 3075, 926, 13, 310, "Print",
  CellTags->"Info3347223943-8464511"],
Cell[131214, 3090, 430, 6, 196, "Print",
  CellTags->"Info3347223943-4874601"],
Cell[131647, 3098, 1320, 18, 424, "Print",
  CellTags->"Info3347223943-5629661"],
Cell[132970, 3118, 313, 5, 63, "Print",
  CellTags->"Info3347223943-4925532"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133320, 3128, 84, 2, 47, "Subsection"],
Cell[133407, 3132, 1146, 16, 367, "Print",
  CellTags->"Info3347223943-5246270"],
Cell[134556, 3150, 161, 3, 44, "Print",
  CellTags->"Info3347223943-1445452"],
Cell[134720, 3155, 206, 3, 63, "Print",
  CellTags->"Info3347223943-4450436"],
Cell[134929, 3160, 208, 4, 63, "Print",
  CellTags->"Info3347223943-3881981"],
Cell[135140, 3166, 217, 4, 63, "Print",
  CellTags->"Info3347223943-7228078"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135394, 3175, 89, 2, 47, "Subsection"],
Cell[135486, 3179, 377, 6, 101, "Print",
  CellTags->"Info3347223943-4602624"],
Cell[135866, 3187, 137, 3, 25, "Print",
  CellTags->"Info3347223943-8450963"],
Cell[136006, 3192, 655, 9, 310, "Print",
  CellTags->"Info3347223943-6220742"],
Cell[136664, 3203, 137, 3, 25, "Print",
  CellTags->"Info3347223943-7000860"],
Cell[136804, 3208, 299, 5, 63, "Print",
  CellTags->"Info3347223943-5567665"],
Cell[137106, 3215, 110, 2, 25, "Print",
  CellTags->"Info3347223943-5586590"],
Cell[137219, 3219, 148, 3, 25, "Print",
  CellTags->"Info3347223943-2736516"],
Cell[137370, 3224, 103, 2, 25, "Print",
  CellTags->"Info3347223943-4561819"],
Cell[137476, 3228, 149, 3, 25, "Print",
  CellTags->"Info3347223943-9200808"],
Cell[137628, 3233, 149, 3, 25, "Print",
  CellTags->"Info3347223943-4835101"],
Cell[137780, 3238, 177, 3, 44, "Print",
  CellTags->"Info3347223943-7355272"],
Cell[137960, 3243, 150, 3, 25, "Print",
  CellTags->"Info3347223943-1181112"],
Cell[138113, 3248, 160, 3, 25, "Print",
  CellTags->"Info3347223943-2215272"],
Cell[138276, 3253, 230, 4, 44, "Print",
  CellTags->"Info3347223943-1923535"],
Cell[138509, 3259, 232, 4, 44, "Print",
  CellTags->"Info3347223943-8093696"],
Cell[138744, 3265, 109, 2, 25, "Print",
  CellTags->"Info3347223943-6910008"],
Cell[138856, 3269, 111, 2, 25, "Print",
  CellTags->"Info3347223943-1493678"],
Cell[138970, 3273, 296, 5, 82, "Print",
  CellTags->"Info3347223943-3117515"],
Cell[139269, 3280, 114, 2, 25, "Print",
  CellTags->"Info3347223943-4832411"],
Cell[139386, 3284, 141, 3, 25, "Print",
  CellTags->"Info3347223943-8404433"],
Cell[139530, 3289, 114, 2, 25, "Print",
  CellTags->"Info3347223943-7328827"],
Cell[139647, 3293, 114, 2, 25, "Print",
  CellTags->"Info3347223943-4746551"],
Cell[139764, 3297, 227, 4, 44, "Print",
  CellTags->"Info3347223943-8409741"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140028, 3306, 85, 2, 47, "Subsection"],
Cell[140116, 3310, 136, 3, 25, "Print",
  CellTags->"Info3347223943-8817053"],
Cell[140255, 3315, 244, 4, 44, "Print",
  CellTags->"Info3347223943-3716282"],
Cell[140502, 3321, 116, 2, 25, "Print",
  CellTags->"Info3347223943-8999170"],
Cell[140621, 3325, 276, 4, 63, "Print",
  CellTags->"Info3347223943-5709094"],
Cell[140900, 3331, 289, 5, 63, "Print",
  CellTags->"Info3347223943-3657880"],
Cell[141192, 3338, 233, 4, 44, "Print",
  CellTags->"Info3347223943-6348310"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[141474, 3348, 94, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[141593, 3354, 104, 2, 47, "Subsection"],
Cell[141700, 3358, 262, 4, 63, "Print",
  CellTags->"Info3347223943-5622619"],
Cell[141965, 3364, 549, 8, 120, "Print",
  CellTags->"Info3347223943-3212639"],
Cell[142517, 3374, 126, 2, 25, "Print",
  CellTags->"Info3347223944-7593278"],
Cell[142646, 3378, 184, 3, 44, "Print",
  CellTags->"Info3347223944-1223543"],
Cell[142833, 3383, 494, 7, 120, "Print",
  CellTags->"Info3347223944-6433330"],
Cell[143330, 3392, 266, 4, 63, "Print",
  CellTags->"Info3347223944-8548286"],
Cell[143599, 3398, 122, 2, 25, "Print",
  CellTags->"Info3347223944-5636726"],
Cell[143724, 3402, 1257, 17, 519, "Print",
  CellTags->"Info3347223944-6212195"],
Cell[144984, 3421, 662, 9, 196, "Print",
  CellTags->"Info3347223944-2446185"],
Cell[145649, 3432, 887, 12, 348, "Print",
  CellTags->"Info3347223944-4819550"],
Cell[146539, 3446, 590, 9, 158, "Print",
  CellTags->"Info3347223944-6414604"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147166, 3460, 84, 2, 47, "Subsection"],
Cell[147253, 3464, 782, 11, 310, "Print",
  CellTags->"Info3347223944-6619072"],
Cell[148038, 3477, 289, 5, 82, "Print",
  CellTags->"Info3347223944-4082389"],
Cell[148330, 3484, 214, 4, 63, "Print",
  CellTags->"Info3347223944-3243349"],
Cell[148547, 3490, 217, 4, 63, "Print",
  CellTags->"Info3347223944-9833440"],
Cell[148767, 3496, 178, 3, 63, "Print",
  CellTags->"Info3347223944-9033299"],
Cell[148948, 3501, 216, 4, 63, "Print",
  CellTags->"Info3347223944-7106424"],
Cell[149167, 3507, 187, 3, 63, "Print",
  CellTags->"Info3347223944-2091162"],
Cell[149357, 3512, 209, 3, 63, "Print",
  CellTags->"Info3347223944-1590385"],
Cell[149569, 3517, 199, 3, 63, "Print",
  CellTags->"Info3347223944-5449929"],
Cell[149771, 3522, 216, 4, 63, "Print",
  CellTags->"Info3347223944-5484391"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150024, 3531, 89, 2, 47, "Subsection"],
Cell[150116, 3535, 526, 8, 158, "Print",
  CellTags->"Info3347223944-8026549"],
Cell[150645, 3545, 137, 3, 25, "Print",
  CellTags->"Info3347223944-6509291"],
Cell[150785, 3550, 891, 12, 234, "Print",
  CellTags->"Info3347223944-9854803"],
Cell[151679, 3564, 137, 3, 25, "Print",
  CellTags->"Info3347223944-4587203"],
Cell[151819, 3569, 299, 5, 63, "Print",
  CellTags->"Info3347223944-6627152"],
Cell[152121, 3576, 110, 2, 25, "Print",
  CellTags->"Info3347223944-9677027"],
Cell[152234, 3580, 155, 3, 25, "Print",
  CellTags->"Info3347223944-7882672"],
Cell[152392, 3585, 103, 2, 25, "Print",
  CellTags->"Info3347223944-5172316"],
Cell[152498, 3589, 156, 3, 25, "Print",
  CellTags->"Info3347223944-1205732"],
Cell[152657, 3594, 149, 3, 25, "Print",
  CellTags->"Info3347223944-8443384"],
Cell[152809, 3599, 184, 3, 44, "Print",
  CellTags->"Info3347223944-8424884"],
Cell[152996, 3604, 150, 3, 25, "Print",
  CellTags->"Info3347223944-9112071"],
Cell[153149, 3609, 167, 3, 44, "Print",
  CellTags->"Info3347223944-5725100"],
Cell[153319, 3614, 230, 4, 44, "Print",
  CellTags->"Info3347223944-3763668"],
Cell[153552, 3620, 232, 4, 44, "Print",
  CellTags->"Info3347223944-5023528"],
Cell[153787, 3626, 109, 2, 25, "Print",
  CellTags->"Info3347223944-6332496"],
Cell[153899, 3630, 111, 2, 25, "Print",
  CellTags->"Info3347223944-1601766"],
Cell[154013, 3634, 296, 5, 82, "Print",
  CellTags->"Info3347223944-9984544"],
Cell[154312, 3641, 114, 2, 25, "Print",
  CellTags->"Info3347223944-8912656"],
Cell[154429, 3645, 141, 3, 25, "Print",
  CellTags->"Info3347223944-6144805"],
Cell[154573, 3650, 114, 2, 25, "Print",
  CellTags->"Info3347223944-4339604"],
Cell[154690, 3654, 114, 2, 25, "Print",
  CellTags->"Info3347223944-7164196"],
Cell[154807, 3658, 242, 4, 44, "Print",
  CellTags->"Info3347223944-7748027"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155086, 3667, 85, 2, 47, "Subsection"],
Cell[155174, 3671, 136, 3, 25, "Print",
  CellTags->"Info3347223944-7495296"],
Cell[155313, 3676, 211, 4, 44, "Print",
  CellTags->"Info3347223944-8982714"],
Cell[155527, 3682, 133, 3, 25, "Print",
  CellTags->"Info3347223944-8993898"],
Cell[155663, 3687, 276, 4, 63, "Print",
  CellTags->"Info3347223944-1732994"],
Cell[155942, 3693, 289, 5, 63, "Print",
  CellTags->"Info3347223944-1385772"],
Cell[156234, 3700, 233, 4, 44, "Print",
  CellTags->"Info3347223944-8600115"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

